@@ -7,7 +7,7 @@
 #include <vector>
 #include <odbc/Config.h>
 //------------------------------------------------------------------------------
-namespace odbc {
+NS_ODBC_START
 //------------------------------------------------------------------------------
 /**
  *  Specifies the type of an ODBC DSN.
@@ -175,6 +175,8 @@ public:
     static constexpr int TypeTime = 92;
     /// Year, month, day, hour, minute, and second fields.
     static constexpr int TypeTimestamp = 93;
+    /// Unknown data type.
+    static constexpr int Unknown = 0;
     /// Variable length binary data.
     static constexpr int VarBinary = -3;
     /// Variable-length character string.
@@ -1046,6 +1048,6 @@ inline std::ostream& operator<<(std::ostream& out, const Binary& val)
     return out;
 }
 //------------------------------------------------------------------------------
-} // namespace odbc
+NS_ODBC_END
 //------------------------------------------------------------------------------
 #endif
