@@ -57,6 +57,9 @@ std::string QgisUntwine::errorMessage() const
 {
     readPipe();
 
+    if ( m_errorMsg.empty() && m_exitCode != 0 )
+        m_errorMsg = "Untwine exited with code: " + std::to_string( m_exitCode );
+
     return m_errorMsg;
 }
 
