@@ -15,94 +15,125 @@
 ***************************************************************************
 """
 
-__author__ = 'Alexander Bruy'
-__date__ = 'August 2012'
-__copyright__ = '(C) 2012, Victor Olaya'
+__author__ = "Alexander Bruy"
+__date__ = "August 2012"
+__copyright__ = "(C) 2012, Victor Olaya"
 
 import math
 
 from qgis.PyQt.QtCore import QCoreApplication
-from qgis.core import (NULL,
-                       QgsWkbTypes,
-                       QgsFeature,
-                       QgsFeatureSink,
-                       QgsGeometry,
-                       QgsPointXY,
-                       QgsProcessing,
-                       QgsProcessingException,
-                       QgsProcessingAlgorithm,
-                       QgsProcessingParameterField,
-                       QgsProcessingParameterFeatureSource,
-                       QgsProcessingParameterEnum,
-                       QgsProcessingParameterNumber,
-                       QgsProcessingParameterFeatureSink)
+from qgis.core import (
+    NULL,
+    QgsWkbTypes,
+    QgsFeature,
+    QgsFeatureSink,
+    QgsGeometry,
+    QgsPointXY,
+    QgsProcessing,
+    QgsProcessingException,
+    QgsProcessingAlgorithm,
+    QgsProcessingParameterField,
+    QgsProcessingParameterFeatureSource,
+    QgsProcessingParameterEnum,
+    QgsProcessingParameterNumber,
+    QgsProcessingParameterFeatureSink,
+)
 
 from processing.algs.qgis.QgisAlgorithm import QgisAlgorithm
 
 
 class RectanglesOvalsDiamondsVariable(QgisAlgorithm):
-    INPUT = 'INPUT'
-    SHAPE = 'SHAPE'
-    WIDTH = 'WIDTH'
-    HEIGHT = 'HEIGHT'
-    ROTATION = 'ROTATION'
-    SEGMENTS = 'SEGMENTS'
-    OUTPUT = 'OUTPUT'
+    INPUT = "INPUT"
+    SHAPE = "SHAPE"
+    WIDTH = "WIDTH"
+    HEIGHT = "HEIGHT"
+    ROTATION = "ROTATION"
+    SEGMENTS = "SEGMENTS"
+    OUTPUT = "OUTPUT"
 
     def group(self):
-        return self.tr('Vector geometry')
+        return self.tr("Vector geometry")
 
     def groupId(self):
-        return 'vectorgeometry'
+        return "vectorgeometry"
 
     def __init__(self):
         super().__init__()
 
     def flags(self):
-        return super().flags() | QgsProcessingAlgorithm.FlagDeprecated
+        return super().flags() | QgsProcessingAlgorithm.Flag.FlagDeprecated
 
     def initAlgorithm(self, config=None):
-        self.shapes = [self.tr('Rectangles'), self.tr('Diamonds'), self.tr('Ovals')]
+        self.shapes = [self.tr("Rectangles"), self.tr("Diamonds"), self.tr("Ovals")]
 
-        self.addParameter(QgsProcessingParameterFeatureSource(self.INPUT,
-                                                              self.tr('Input layer'),
-                                                              [QgsProcessing.TypeVectorPoint]))
+        self.addParameter(
+            QgsProcessingParameterFeatureSource(
+                self.INPUT,
+                self.tr("Input layer"),
+                [QgsProcessing.SourceType.TypeVectorPoint],
+            )
+        )
 
-        self.addParameter(QgsProcessingParameterEnum(self.SHAPE,
-                                                     self.tr('Buffer shape'), options=self.shapes))
+        self.addParameter(
+            QgsProcessingParameterEnum(
+                self.SHAPE, self.tr("Buffer shape"), options=self.shapes
+            )
+        )
 
-        self.addParameter(QgsProcessingParameterField(self.WIDTH,
-                                                      self.tr('Width field'),
-                                                      parentLayerParameterName=self.INPUT,
-                                                      type=QgsProcessingParameterField.Numeric))
-        self.addParameter(QgsProcessingParameterField(self.HEIGHT,
-                                                      self.tr('Height field'),
-                                                      parentLayerParameterName=self.INPUT,
-                                                      type=QgsProcessingParameterField.Numeric))
-        self.addParameter(QgsProcessingParameterField(self.ROTATION,
-                                                      self.tr('Rotation field'),
-                                                      parentLayerParameterName=self.INPUT,
-                                                      type=QgsProcessingParameterField.Numeric,
-                                                      optional=True))
-        self.addParameter(QgsProcessingParameterNumber(self.SEGMENTS,
-                                                       self.tr('Number of segments'),
-                                                       minValue=1,
-                                                       defaultValue=36))
+        self.addParameter(
+            QgsProcessingParameterField(
+                self.WIDTH,
+                self.tr("Width field"),
+                parentLayerParameterName=self.INPUT,
+                type=QgsProcessingParameterField.DataType.Numeric,
+            )
+        )
+        self.addParameter(
+            QgsProcessingParameterField(
+                self.HEIGHT,
+                self.tr("Height field"),
+                parentLayerParameterName=self.INPUT,
+                type=QgsProcessingParameterField.DataType.Numeric,
+            )
+        )
+        self.addParameter(
+            QgsProcessingParameterField(
+                self.ROTATION,
+                self.tr("Rotation field"),
+                parentLayerParameterName=self.INPUT,
+                type=QgsProcessingParameterField.DataType.Numeric,
+                optional=True,
+            )
+        )
+        self.addParameter(
+            QgsProcessingParameterNumber(
+                self.SEGMENTS,
+                self.tr("Number of segments"),
+                minValue=1,
+                defaultValue=36,
+            )
+        )
 
-        self.addParameter(QgsProcessingParameterFeatureSink(self.OUTPUT,
-                                                            self.tr('Output'),
-                                                            type=QgsProcessing.TypeVectorPolygon))
+        self.addParameter(
+            QgsProcessingParameterFeatureSink(
+                self.OUTPUT,
+                self.tr("Output"),
+                type=QgsProcessing.SourceType.TypeVectorPolygon,
+            )
+        )
 
     def name(self):
-        return 'rectanglesovalsdiamondsvariable'
+        return "rectanglesovalsdiamondsvariable"
 
     def displayName(self):
-        return self.tr('Rectangles, ovals, diamonds (variable)')
+        return self.tr("Rectangles, ovals, diamonds (variable)")
 
     def processAlgorithm(self, parameters, context, feedback):
         source = self.parameterAsSource(parameters, self.INPUT, context)
         if source is None:
-            raise QgsProcessingException(self.invalidSourceError(parameters, self.INPUT))
+            raise QgsProcessingException(
+                self.invalidSourceError(parameters, self.INPUT)
+            )
 
         shape = self.parameterAsEnum(parameters, self.SHAPE, context)
 
@@ -111,8 +142,14 @@ class RectanglesOvalsDiamondsVariable(QgisAlgorithm):
         rotation_field = self.parameterAsString(parameters, self.ROTATION, context)
         segments = self.parameterAsInt(parameters, self.SEGMENTS, context)
 
-        (sink, dest_id) = self.parameterAsSink(parameters, self.OUTPUT, context,
-                                               source.fields(), QgsWkbTypes.Polygon, source.sourceCrs())
+        (sink, dest_id) = self.parameterAsSink(
+            parameters,
+            self.OUTPUT,
+            context,
+            source.fields(),
+            QgsWkbTypes.Type.Polygon,
+            source.sourceCrs(),
+        )
         if sink is None:
             raise QgsProcessingException(self.invalidSinkError(parameters, self.OUTPUT))
 
@@ -147,14 +184,20 @@ class RectanglesOvalsDiamondsVariable(QgisAlgorithm):
                 angle = feat[rotation]
                 # block 0/NULL width or height, but allow 0 as angle value
                 if not w or not h:
-                    feedback.pushInfo(QCoreApplication.translate('RectanglesOvalsDiamondsVariable', 'Feature {} has empty '
-                                                                 'width or height. '
-                                                                 'Skipping…').format(feat.id()))
+                    feedback.pushInfo(
+                        QCoreApplication.translate(
+                            "RectanglesOvalsDiamondsVariable",
+                            "Feature {} has empty " "width or height. " "Skipping…",
+                        ).format(feat.id())
+                    )
                     continue
                 if angle is NULL:
-                    feedback.pushInfo(QCoreApplication.translate('RectanglesOvalsDiamondsVariable', 'Feature {} has empty '
-                                                                 'angle. '
-                                                                 'Skipping…').format(feat.id()))
+                    feedback.pushInfo(
+                        QCoreApplication.translate(
+                            "RectanglesOvalsDiamondsVariable",
+                            "Feature {} has empty " "angle. " "Skipping…",
+                        ).format(feat.id())
+                    )
                     continue
 
                 xOffset = w / 2.0
@@ -164,13 +207,25 @@ class RectanglesOvalsDiamondsVariable(QgisAlgorithm):
                 point = feat.geometry().asPoint()
                 x = point.x()
                 y = point.y()
-                points = [(-xOffset, -yOffset), (-xOffset, yOffset), (xOffset, yOffset), (xOffset, -yOffset)]
-                polygon = [[QgsPointXY(i[0] * math.cos(phi) + i[1] * math.sin(phi) + x,
-                                       -i[0] * math.sin(phi) + i[1] * math.cos(phi) + y) for i in points]]
+                points = [
+                    (-xOffset, -yOffset),
+                    (-xOffset, yOffset),
+                    (xOffset, yOffset),
+                    (xOffset, -yOffset),
+                ]
+                polygon = [
+                    [
+                        QgsPointXY(
+                            i[0] * math.cos(phi) + i[1] * math.sin(phi) + x,
+                            -i[0] * math.sin(phi) + i[1] * math.cos(phi) + y,
+                        )
+                        for i in points
+                    ]
+                ]
 
                 ft.setGeometry(QgsGeometry.fromPolygonXY(polygon))
                 ft.setAttributes(feat.attributes())
-                sink.addFeature(ft, QgsFeatureSink.FastInsert)
+                sink.addFeature(ft, QgsFeatureSink.Flag.FastInsert)
 
                 feedback.setProgress(int(current * total))
         else:
@@ -184,9 +239,12 @@ class RectanglesOvalsDiamondsVariable(QgisAlgorithm):
                 w = feat[width]
                 h = feat[height]
                 if not w or not h:
-                    feedback.pushInfo(QCoreApplication.translate('RectanglesOvalsDiamondsVariable', 'Feature {} has empty '
-                                                                 'width or height. '
-                                                                 'Skipping…').format(feat.id()))
+                    feedback.pushInfo(
+                        QCoreApplication.translate(
+                            "RectanglesOvalsDiamondsVariable",
+                            "Feature {} has empty " "width or height. " "Skipping…",
+                        ).format(feat.id())
+                    )
                     continue
 
                 xOffset = w / 2.0
@@ -195,12 +253,17 @@ class RectanglesOvalsDiamondsVariable(QgisAlgorithm):
                 point = feat.geometry().asPoint()
                 x = point.x()
                 y = point.y()
-                points = [(-xOffset, -yOffset), (-xOffset, yOffset), (xOffset, yOffset), (xOffset, -yOffset)]
+                points = [
+                    (-xOffset, -yOffset),
+                    (-xOffset, yOffset),
+                    (xOffset, yOffset),
+                    (xOffset, -yOffset),
+                ]
                 polygon = [[QgsPointXY(i[0] + x, i[1] + y) for i in points]]
 
                 ft.setGeometry(QgsGeometry.fromPolygonXY(polygon))
                 ft.setAttributes(feat.attributes())
-                sink.addFeature(ft, QgsFeatureSink.FastInsert)
+                sink.addFeature(ft, QgsFeatureSink.Flag.FastInsert)
 
                 feedback.setProgress(int(current * total))
 
@@ -222,14 +285,20 @@ class RectanglesOvalsDiamondsVariable(QgisAlgorithm):
                 angle = feat[rotation]
                 # block 0/NULL width or height, but allow 0 as angle value
                 if not w or not h:
-                    feedback.pushInfo(QCoreApplication.translate('RectanglesOvalsDiamondsVariable', 'Feature {} has empty '
-                                                                 'width or height. '
-                                                                 'Skipping…').format(feat.id()))
+                    feedback.pushInfo(
+                        QCoreApplication.translate(
+                            "RectanglesOvalsDiamondsVariable",
+                            "Feature {} has empty " "width or height. " "Skipping…",
+                        ).format(feat.id())
+                    )
                     continue
                 if angle is NULL:
-                    feedback.pushInfo(QCoreApplication.translate('RectanglesOvalsDiamondsVariable', 'Feature {} has empty '
-                                                                 'angle. '
-                                                                 'Skipping…').format(feat.id()))
+                    feedback.pushInfo(
+                        QCoreApplication.translate(
+                            "RectanglesOvalsDiamondsVariable",
+                            "Feature {} has empty " "angle. " "Skipping…",
+                        ).format(feat.id())
+                    )
                     continue
 
                 xOffset = w / 2.0
@@ -239,13 +308,25 @@ class RectanglesOvalsDiamondsVariable(QgisAlgorithm):
                 point = feat.geometry().asPoint()
                 x = point.x()
                 y = point.y()
-                points = [(0.0, -yOffset), (-xOffset, 0.0), (0.0, yOffset), (xOffset, 0.0)]
-                polygon = [[QgsPointXY(i[0] * math.cos(phi) + i[1] * math.sin(phi) + x,
-                                       -i[0] * math.sin(phi) + i[1] * math.cos(phi) + y) for i in points]]
+                points = [
+                    (0.0, -yOffset),
+                    (-xOffset, 0.0),
+                    (0.0, yOffset),
+                    (xOffset, 0.0),
+                ]
+                polygon = [
+                    [
+                        QgsPointXY(
+                            i[0] * math.cos(phi) + i[1] * math.sin(phi) + x,
+                            -i[0] * math.sin(phi) + i[1] * math.cos(phi) + y,
+                        )
+                        for i in points
+                    ]
+                ]
 
                 ft.setGeometry(QgsGeometry.fromPolygonXY(polygon))
                 ft.setAttributes(feat.attributes())
-                sink.addFeature(ft, QgsFeatureSink.FastInsert)
+                sink.addFeature(ft, QgsFeatureSink.Flag.FastInsert)
                 feedback.setProgress(int(current * total))
         else:
             for current, feat in enumerate(features):
@@ -258,9 +339,12 @@ class RectanglesOvalsDiamondsVariable(QgisAlgorithm):
                 w = feat[width]
                 h = feat[height]
                 if not w or not h:
-                    feedback.pushInfo(QCoreApplication.translate('RectanglesOvalsDiamondsVariable', 'Feature {} has empty '
-                                                                 'width or height. '
-                                                                 'Skipping…').format(feat.id()))
+                    feedback.pushInfo(
+                        QCoreApplication.translate(
+                            "RectanglesOvalsDiamondsVariable",
+                            "Feature {} has empty " "width or height. " "Skipping…",
+                        ).format(feat.id())
+                    )
                     continue
 
                 xOffset = w / 2.0
@@ -269,12 +353,17 @@ class RectanglesOvalsDiamondsVariable(QgisAlgorithm):
                 point = feat.geometry().asPoint()
                 x = point.x()
                 y = point.y()
-                points = [(0.0, -yOffset), (-xOffset, 0.0), (0.0, yOffset), (xOffset, 0.0)]
+                points = [
+                    (0.0, -yOffset),
+                    (-xOffset, 0.0),
+                    (0.0, yOffset),
+                    (xOffset, 0.0),
+                ]
                 polygon = [[QgsPointXY(i[0] + x, i[1] + y) for i in points]]
 
                 ft.setGeometry(QgsGeometry.fromPolygonXY(polygon))
                 ft.setAttributes(feat.attributes())
-                sink.addFeature(ft, QgsFeatureSink.FastInsert)
+                sink.addFeature(ft, QgsFeatureSink.Flag.FastInsert)
                 feedback.setProgress(int(current * total))
 
     def ovals(self, sink, source, width, height, rotation, segments, feedback):
@@ -295,14 +384,20 @@ class RectanglesOvalsDiamondsVariable(QgisAlgorithm):
                 angle = feat[rotation]
                 # block 0/NULL width or height, but allow 0 as angle value
                 if not w or not h:
-                    feedback.pushInfo(QCoreApplication.translate('RectanglesOvalsDiamondsVariable', 'Feature {} has empty '
-                                                                 'width or height. '
-                                                                 'Skipping…').format(feat.id()))
+                    feedback.pushInfo(
+                        QCoreApplication.translate(
+                            "RectanglesOvalsDiamondsVariable",
+                            "Feature {} has empty " "width or height. " "Skipping…",
+                        ).format(feat.id())
+                    )
                     continue
                 if angle == NULL:
-                    feedback.pushInfo(QCoreApplication.translate('RectanglesOvalsDiamondsVariable', 'Feature {} has empty '
-                                                                 'angle. '
-                                                                 'Skipping…').format(feat.id()))
+                    feedback.pushInfo(
+                        QCoreApplication.translate(
+                            "RectanglesOvalsDiamondsVariable",
+                            "Feature {} has empty " "angle. " "Skipping…",
+                        ).format(feat.id())
+                    )
                     continue
 
                 xOffset = w / 2.0
@@ -317,12 +412,19 @@ class RectanglesOvalsDiamondsVariable(QgisAlgorithm):
                     for t in [(2 * math.pi) / segments * i for i in range(segments)]
                 ]
 
-                polygon = [[QgsPointXY(i[0] * math.cos(phi) + i[1] * math.sin(phi) + x,
-                                       -i[0] * math.sin(phi) + i[1] * math.cos(phi) + y) for i in points]]
+                polygon = [
+                    [
+                        QgsPointXY(
+                            i[0] * math.cos(phi) + i[1] * math.sin(phi) + x,
+                            -i[0] * math.sin(phi) + i[1] * math.cos(phi) + y,
+                        )
+                        for i in points
+                    ]
+                ]
 
                 ft.setGeometry(QgsGeometry.fromPolygonXY(polygon))
                 ft.setAttributes(feat.attributes())
-                sink.addFeature(ft, QgsFeatureSink.FastInsert)
+                sink.addFeature(ft, QgsFeatureSink.Flag.FastInsert)
                 feedback.setProgress(int(current * total))
         else:
             for current, feat in enumerate(features):
@@ -335,9 +437,12 @@ class RectanglesOvalsDiamondsVariable(QgisAlgorithm):
                 w = feat[width]
                 h = feat[height]
                 if not w or not h:
-                    feedback.pushInfo(QCoreApplication.translate('RectanglesOvalsDiamondsVariable', 'Feature {} has empty '
-                                                                 'width or height. '
-                                                                 'Skipping…').format(feat.id()))
+                    feedback.pushInfo(
+                        QCoreApplication.translate(
+                            "RectanglesOvalsDiamondsVariable",
+                            "Feature {} has empty " "width or height. " "Skipping…",
+                        ).format(feat.id())
+                    )
                     continue
 
                 xOffset = w / 2.0
@@ -355,5 +460,5 @@ class RectanglesOvalsDiamondsVariable(QgisAlgorithm):
 
                 ft.setGeometry(QgsGeometry.fromPolygonXY(polygon))
                 ft.setAttributes(feat.attributes())
-                sink.addFeature(ft, QgsFeatureSink.FastInsert)
+                sink.addFeature(ft, QgsFeatureSink.Flag.FastInsert)
                 feedback.setProgress(int(current * total))
