@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """
 ***************************************************************************
     CreateNewModelAction.py
@@ -17,9 +15,9 @@
 ***************************************************************************
 """
 
-__author__ = 'Victor Olaya'
-__date__ = 'August 2012'
-__copyright__ = '(C) 2012, Victor Olaya'
+__author__ = "Victor Olaya"
+__date__ = "August 2012"
+__copyright__ = "(C) 2012, Victor Olaya"
 
 import os
 
@@ -37,8 +35,10 @@ pluginPath = os.path.split(os.path.dirname(__file__))[0]
 class CreateNewModelAction(ToolboxAction):
 
     def __init__(self):
-        self.name = QCoreApplication.translate('CreateNewModelAction', 'Create New Model…')
-        self.group = self.tr('Tools')
+        self.name = QCoreApplication.translate(
+            "CreateNewModelAction", "Create New Model…"
+        )
+        self.group = self.tr("Tools")
 
     def getIcon(self):
         return QgsApplication.getThemeIcon("/processingModel.svg")
@@ -49,4 +49,4 @@ class CreateNewModelAction(ToolboxAction):
         dlg.show()
 
     def updateModel(self):
-        QgsApplication.processingRegistry().providerById('model').refreshAlgorithms()
+        QgsApplication.processingRegistry().providerById("model").refreshAlgorithms()
