@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """
 ***************************************************************************
     AddScriptFromTemplateAction.py
@@ -17,20 +15,16 @@
 ***************************************************************************
 """
 
-__author__ = 'Matteo Ghetta'
-__date__ = 'March 2018'
-__copyright__ = '(C) 2018, Matteo Ghetta'
-
-# This will get replaced with a git SHA1 when you do a git archive
-
-__revision__ = 'e83d02e2747dd3e4e6940d9d720fee80febe78d9'
+__author__ = "Matteo Ghetta"
+__date__ = "March 2018"
+__copyright__ = "(C) 2018, Matteo Ghetta"
 
 import os
 import codecs
 
 from qgis.PyQt.QtCore import QCoreApplication
 
-from qgis.core import QgsApplication
+from qgis.utils import iface
 
 from processing.gui.ToolboxAction import ToolboxAction
 
@@ -40,17 +34,18 @@ from processing.script.ScriptEditorDialog import ScriptEditorDialog
 class AddScriptFromTemplateAction(ToolboxAction):
 
     def __init__(self):
-        self.name = QCoreApplication.translate("AddScriptFromTemplate", "Create New Script from Template…")
+        self.name = QCoreApplication.translate(
+            "AddScriptFromTemplate", "Create New Script from Template…"
+        )
         self.group = self.tr("Tools")
 
     def execute(self):
-        dlg = ScriptEditorDialog(None)
+        dlg = ScriptEditorDialog(parent=iface.mainWindow())
 
         pluginPath = os.path.split(os.path.dirname(__file__))[0]
-        templatePath = os.path.join(
-            pluginPath, 'script', 'ScriptTemplate.py')
+        templatePath = os.path.join(pluginPath, "script", "ScriptTemplate.py")
 
-        with codecs.open(templatePath, 'r', encoding='utf-8') as f:
+        with codecs.open(templatePath, "r", encoding="utf-8") as f:
             templateTxt = f.read()
             dlg.editor.setText(templateTxt)
 
