@@ -16,9 +16,8 @@
  ***************************************************************************/
 
 #include "qgsmeshtriangulation.h"
+#include "moc_qgsmeshtriangulation.cpp"
 #include "qgsdualedgetriangulation.h"
-#include "qgsvectorlayer.h"
-#include "qgscoordinatetransformcontext.h"
 #include "qgscurve.h"
 #include "qgscurvepolygon.h"
 #include "qgsmultisurface.h"
@@ -26,8 +25,11 @@
 #include "qgsfeedback.h"
 #include "qgslogger.h"
 #include "qgsmesheditor.h"
+#include "qgsfeature.h"
+#include "qgsfeatureiterator.h"
 
-QgsMeshTriangulation::QgsMeshTriangulation(): QObject()
+QgsMeshTriangulation::QgsMeshTriangulation()
+  : QObject()
 {
   mTriangulation.reset( new QgsDualEdgeTriangulation() );
 }
@@ -77,14 +79,14 @@ bool QgsMeshTriangulation::addBreakLines( QgsFeatureIterator &lineFeatureIterato
       i++;
     }
 
-    QgsWkbTypes::GeometryType geomType = feat.geometry().type();
+    Qgis::GeometryType geomType = feat.geometry().type();
     switch ( geomType )
     {
-      case QgsWkbTypes::PointGeometry:
+      case Qgis::GeometryType::Point:
         addVerticesFromFeature( feat, valueAttribute, transform, feedback );
         break;
-      case QgsWkbTypes::LineGeometry:
-      case QgsWkbTypes::PolygonGeometry:
+      case Qgis::GeometryType::Line:
+      case Qgis::GeometryType::Polygon:
         addBreakLinesFromFeature( feat, valueAttribute, transform, feedback );
         break;
       default:
@@ -138,7 +140,7 @@ void QgsMeshTriangulation::addVerticesFromFeature( const QgsFeature &feature, in
       mTriangulation->addPoint( *vit );
     else
     {
-      mTriangulation->addPoint( QgsPoint( QgsWkbTypes::PointZ, ( *vit ).x(), ( *vit ).y(), value ) );
+      mTriangulation->addPoint( QgsPoint( Qgis::WkbType::PointZ, ( *vit ).x(), ( *vit ).y(), value ) );
     }
     ++vit;
   }
@@ -164,20 +166,20 @@ void QgsMeshTriangulation::addBreakLinesFromFeature( const QgsFeature &feature,
     return;
   }
 
-  if ( QgsWkbTypes::geometryType( geom.wkbType() ) == QgsWkbTypes::PolygonGeometry )
+  if ( QgsWkbTypes::geometryType( geom.wkbType() ) == Qgis::GeometryType::Polygon )
   {
-    std::vector< const QgsCurvePolygon * > polygons;
+    std::vector<const QgsCurvePolygon *> polygons;
     if ( geom.isMultipart() )
     {
-      const QgsMultiSurface *ms = qgsgeometry_cast< const QgsMultiSurface * >( geom.constGet() );
+      const QgsMultiSurface *ms = qgsgeometry_cast<const QgsMultiSurface *>( geom.constGet() );
       for ( int i = 0; i < ms->numGeometries(); ++i )
       {
-        polygons.emplace_back( qgsgeometry_cast< const QgsCurvePolygon * >( ms->geometryN( i ) ) );
+        polygons.emplace_back( qgsgeometry_cast<const QgsCurvePolygon *>( ms->geometryN( i ) ) );
       }
     }
     else
     {
-      polygons.emplace_back( qgsgeometry_cast< const QgsCurvePolygon * >( geom.constGet() ) );
+      polygons.emplace_back( qgsgeometry_cast<const QgsCurvePolygon *>( geom.constGet() ) );
     }
 
     for ( const QgsCurvePolygon *polygon : polygons )
@@ -202,17 +204,17 @@ void QgsMeshTriangulation::addBreakLinesFromFeature( const QgsFeature &feature,
   {
     if ( geom.isMultipart() )
     {
-      const QgsMultiCurve *mc = qgsgeometry_cast< const QgsMultiCurve * >( geom.constGet() );
+      const QgsMultiCurve *mc = qgsgeometry_cast<const QgsMultiCurve *>( geom.constGet() );
       for ( int i = 0; i < mc->numGeometries(); ++i )
       {
         if ( feedback && feedback->isCanceled() )
           break;
-        curves.emplace_back( qgsgeometry_cast< const QgsCurve * >( mc->geometryN( i ) ) );
+        curves.emplace_back( qgsgeometry_cast<const QgsCurve *>( mc->geometryN( i ) ) );
       }
     }
     else
     {
-      curves.emplace_back( qgsgeometry_cast< const QgsCurve * >( geom.constGet() ) );
+      curves.emplace_back( qgsgeometry_cast<const QgsCurve *>( geom.constGet() ) );
     }
   }
 
@@ -245,10 +247,10 @@ void QgsMeshTriangulation::addBreakLinesFromFeature( const QgsFeature &feature,
   }
 }
 
-QgsMeshZValueDatasetGroup::QgsMeshZValueDatasetGroup( const QString &datasetGroupName, const QgsMesh &mesh ):
-  QgsMeshDatasetGroup( datasetGroupName, QgsMeshDatasetGroupMetadata::DataOnVertices )
+QgsMeshZValueDatasetGroup::QgsMeshZValueDatasetGroup( const QString &datasetGroupName, const QgsMesh &mesh )
+  : QgsMeshDatasetGroup( datasetGroupName, QgsMeshDatasetGroupMetadata::DataOnVertices )
 {
-  mDataset = std::make_unique< QgsMeshZValueDataset >( mesh );
+  mDataset = std::make_unique<QgsMeshZValueDataset>( mesh );
 }
 
 void QgsMeshZValueDatasetGroup::initialize()
@@ -264,7 +266,7 @@ QgsMeshDatasetMetadata QgsMeshZValueDatasetGroup::datasetMetadata( int datasetIn
   return mDataset->metadata();
 }
 
-int QgsMeshZValueDatasetGroup::datasetCount() const {return 1;}
+int QgsMeshZValueDatasetGroup::datasetCount() const { return 1; }
 
 QgsMeshDataset *QgsMeshZValueDatasetGroup::dataset( int index ) const
 {
@@ -281,7 +283,8 @@ QDomElement QgsMeshZValueDatasetGroup::writeXml( QDomDocument &doc, const QgsRea
   return QDomElement();
 }
 
-QgsMeshZValueDataset::QgsMeshZValueDataset( const QgsMesh &mesh ): mMesh( mesh )
+QgsMeshZValueDataset::QgsMeshZValueDataset( const QgsMesh &mesh )
+  : mMesh( mesh )
 {
   for ( const QgsMeshVertex &vertex : mesh.vertices )
   {
@@ -445,4 +448,3 @@ QgsTopologicalMesh::Changes QgsMeshEditingDelaunayTriangulation::apply( QgsMeshE
   else
     return QgsTopologicalMesh::Changes();
 }
-
