@@ -22,8 +22,6 @@
 
 #include "qgis_sip.h"
 #include "qgsprocessingalgorithm.h"
-#include "qgsvectorlayer.h"
-#include "vector/qgszonalstatistics.h"
 
 ///@cond PRIVATE
 
@@ -32,9 +30,7 @@
  */
 class QgsZonalStatisticsFeatureBasedAlgorithm : public QgsProcessingFeatureBasedAlgorithm
 {
-
   public:
-
     QgsZonalStatisticsFeatureBasedAlgorithm() = default;
     QString name() const override;
     QString displayName() const override;
@@ -43,31 +39,29 @@ class QgsZonalStatisticsFeatureBasedAlgorithm : public QgsProcessingFeatureBased
     QString groupId() const override;
     QString shortHelpString() const override;
     QList<int> inputLayerTypes() const override;
-
+    bool supportInPlaceEdit( const QgsMapLayer *layer ) const override;
     QgsZonalStatisticsFeatureBasedAlgorithm *createInstance() const override SIP_FACTORY;
 
   protected:
-
     void initParameters( const QVariantMap &configuration = QVariantMap() ) override;
     QString outputName() const override;
     QgsFields outputFields( const QgsFields &inputFields ) const override;
 
     bool prepareAlgorithm( const QVariantMap &parameters, QgsProcessingContext &context, QgsProcessingFeedback *feedback ) override;
-    QgsFeatureList processFeature( const QgsFeature &feature,  QgsProcessingContext &context, QgsProcessingFeedback *feedback ) override;
-    bool supportInPlaceEdit( const QgsMapLayer *layer ) const override;
+    QgsFeatureList processFeature( const QgsFeature &feature, QgsProcessingContext &context, QgsProcessingFeedback *feedback ) override;
 
   private:
-    std::unique_ptr< QgsRasterInterface > mRaster;
+    std::unique_ptr<QgsRasterInterface> mRaster;
     int mBand = 1;
     QString mPrefix;
-    QgsZonalStatistics::Statistics mStats = QgsZonalStatistics::All;
+    Qgis::ZonalStatistics mStats = Qgis::ZonalStatistic::All;
     QgsCoordinateReferenceSystem mCrs;
     bool mCreatedTransform = false;
     QgsCoordinateTransform mFeatureToRasterTransform;
     double mPixelSizeX = 0;
     double mPixelSizeY = 0;
     QgsFields mOutputFields;
-    QMap<QgsZonalStatistics::Statistic, int> mStatFieldsMapping;
+    QMap<Qgis::ZonalStatistic, int> mStatFieldsMapping;
 };
 
 ///@endcond PRIVATE
