@@ -21,7 +21,7 @@
 #include <gdalwarper.h>
 #include <vector>
 
-#include"qgis_app.h"
+#include "qgis_app.h"
 #include "qgscoordinatereferencesystem.h"
 #include "qgsogrutils.h"
 #include "qgstaskmanager.h"
@@ -36,7 +36,6 @@ class APP_EXPORT QgsImageWarper
     Q_GADGET
 
   public:
-
     QgsImageWarper();
 
     enum class ResamplingMethod : int
@@ -52,13 +51,13 @@ class APP_EXPORT QgsImageWarper
     //! Task results
     enum class Result
     {
-      Success, //!< Warping completed successfully
-      Canceled, //!< Task was canceled before completion
-      InvalidParameters, //!< Invalid transform parameters
-      SourceError, //!< Error reading source
-      TransformError, //!< Error creating GDAL transformer
+      Success,                  //!< Warping completed successfully
+      Canceled,                 //!< Task was canceled before completion
+      InvalidParameters,        //!< Invalid transform parameters
+      SourceError,              //!< Error reading source
+      TransformError,           //!< Error creating GDAL transformer
       DestinationCreationError, //!< Error creating destination file
-      WarpFailure, //!< Failed warping source
+      WarpFailure,              //!< Failed warping source
     };
     Q_ENUM( Result )
 
@@ -75,28 +74,19 @@ class APP_EXPORT QgsImageWarper
      * \param destResX The desired horizontal resolution of the output file, in target georeferenced units. A value of zero means automatic selection.
      * \param destResY The desired vertical resolution of the output file, in target georeferenced units. A value of zero means automatic selection.
      */
-    Result warpFile( const QString &input,
-                     const QString &output,
-                     const QgsGeorefTransform &georefTransform,
-                     ResamplingMethod resampling,
-                     bool useZeroAsTrans,
-                     const QString &compression,
-                     const QgsCoordinateReferenceSystem &crs,
-                     QgsFeedback *feedback,
-                     double destResX = 0.0, double destResY = 0.0 );
+    Result warpFile( const QString &input, const QString &output, const QgsGeorefTransform &georefTransform, ResamplingMethod resampling, bool useZeroAsTrans, const QString &compression, const QgsCoordinateReferenceSystem &crs, QgsFeedback *feedback, double destResX = 0.0, double destResY = 0.0 );
 
   private:
     struct TransformChain
     {
-      GDALTransformerFunc GDALTransformer;
-      void               *GDALTransformerArg = nullptr;
-      double              adfGeotransform[6];
-      double              adfInvGeotransform[6];
+        GDALTransformerFunc GDALTransformer;
+        void *GDALTransformerArg = nullptr;
+        double adfGeotransform[6];
+        double adfInvGeotransform[6];
     };
 
     //! \sa addGeoToPixelTransform
-    static int GeoToPixelTransform( void *pTransformerArg, int bDstToSrc, int nPointCount,
-                                    double *x, double *y, double *z, int *panSuccess );
+    static int GeoToPixelTransform( void *pTransformerArg, int bDstToSrc, int nPointCount, double *x, double *y, double *z, int *panSuccess );
 
     /**
      * \brief Appends a transform from geocoordinates to pixel/line coordinates to the given GDAL transformer.
@@ -109,12 +99,9 @@ class APP_EXPORT QgsImageWarper
     void *addGeoToPixelTransform( GDALTransformerFunc GDALTransformer, void *GDALTransformerArg, double *padfGeotransform ) const;
     void destroyGeoToPixelTransform( void *GeoToPixelTransformArg ) const;
 
-    bool openSrcDSAndGetWarpOpt( const QString &input, ResamplingMethod resampling,
-                                 const GDALTransformerFunc &pfnTransform, gdal::dataset_unique_ptr &hSrcDS,
-                                 gdal::warp_options_unique_ptr &psWarpOptions ) const;
+    bool openSrcDSAndGetWarpOpt( const QString &input, ResamplingMethod resampling, const GDALTransformerFunc &pfnTransform, gdal::dataset_unique_ptr &hSrcDS, gdal::warp_options_unique_ptr &psWarpOptions ) const;
 
-    bool createDestinationDataset( const QString &outputName, GDALDatasetH hSrcDS, gdal::dataset_unique_ptr &hDstDS, uint resX, uint resY,
-                                   double *adfGeoTransform, bool useZeroAsTrans, const QString &compression, const QgsCoordinateReferenceSystem &crs );
+    bool createDestinationDataset( const QString &outputName, GDALDatasetH hSrcDS, gdal::dataset_unique_ptr &hDstDS, uint resX, uint resY, double *adfGeoTransform, bool useZeroAsTrans, const QString &compression, const QgsCoordinateReferenceSystem &crs );
 
     //! \brief GDAL progress callback, used to display warping progress via a QProgressDialog
     static int CPL_STDCALL updateWarpProgress( double dfComplete, const char *pszMessage, void *pProgressArg );
@@ -128,7 +115,6 @@ class QgsImageWarperTask : public QgsTask
     Q_OBJECT
 
   public:
-
     /**
      * Constructor for QgsImageWarperTask.
      *
@@ -142,14 +128,7 @@ class QgsImageWarperTask : public QgsTask
      * \param destResX The desired horizontal resolution of the output file, in target georeferenced units. A value of zero means automatic selection.
      * \param destResY The desired vertical resolution of the output file, in target georeferenced units. A value of zero means automatic selection.
      */
-    QgsImageWarperTask( const QString &input,
-                        const QString &output,
-                        const QgsGeorefTransform &georefTransform,
-                        QgsImageWarper::ResamplingMethod resampling,
-                        bool useZeroAsTrans,
-                        const QString &compression,
-                        const QgsCoordinateReferenceSystem &crs,
-                        double destResX = 0.0, double destResY = 0.0 );
+    QgsImageWarperTask( const QString &input, const QString &output, const QgsGeorefTransform &georefTransform, QgsImageWarper::ResamplingMethod resampling, bool useZeroAsTrans, const QString &compression, const QgsCoordinateReferenceSystem &crs, double destResX = 0.0, double destResY = 0.0 );
 
     void cancel() override;
 
@@ -159,14 +138,12 @@ class QgsImageWarperTask : public QgsTask
     QgsImageWarper::Result result() const { return mResult; }
 
   protected:
-
     bool run() override;
 
   private:
-
     QString mInput;
     QString mOutput;
-    std::unique_ptr< QgsGeorefTransform > mTransform;
+    std::unique_ptr<QgsGeorefTransform> mTransform;
     QgsImageWarper::ResamplingMethod mResamplingMethod = QgsImageWarper::ResamplingMethod::Bilinear;
     bool mUseZeroAsTrans = false;
     QString mCompression;
@@ -174,10 +151,9 @@ class QgsImageWarperTask : public QgsTask
     double mDestinationResX = 0;
     double mDestinationResY = 0;
 
-    std::unique_ptr< QgsFeedback > mFeedback;
+    std::unique_ptr<QgsFeedback> mFeedback;
 
     QgsImageWarper::Result mResult = QgsImageWarper::Result::Success;
-    double mLastProgress = 0;
 };
 
 
