@@ -18,6 +18,7 @@
 #include <QObject>
 
 #include "qgsgpsbearingitem.h"
+#include "moc_qgsgpsbearingitem.cpp"
 #include "qgscoordinatetransform.h"
 #include "qgsmapcanvas.h"
 #include "qgsexception.h"
@@ -87,8 +88,16 @@ void QgsGpsBearingItem::updateLine()
     QgsDistanceArea da1;
     da1.setSourceCrs( mMapCanvas->mapSettings().destinationCrs(), QgsProject::instance()->transformContext() );
     da1.setEllipsoid( QgsProject::instance()->ellipsoid() );
-    const double totalLength = 2 * da1.measureLine( mMapCanvas->mapSettings().extent().center(), QgsPointXY( mMapCanvas->mapSettings().extent().xMaximum(),
-                               mMapCanvas->mapSettings().extent().yMaximum() ) );
+    double totalLength = 0;
+    try
+    {
+      totalLength = 2 * da1.measureLine( mMapCanvas->mapSettings().extent().center(), QgsPointXY( mMapCanvas->mapSettings().extent().xMaximum(), mMapCanvas->mapSettings().extent().yMaximum() ) );
+    }
+    catch ( QgsCsException & )
+    {
+      // TODO report errors to user
+      QgsDebugError( QStringLiteral( "An error occurred while calculating length" ) );
+    }
 
     QgsDistanceArea da;
     da.setSourceCrs( mWgs84CRS, QgsProject::instance()->transformContext() );
