@@ -25,6 +25,7 @@
 #include "qgsidentifymenu.h"
 #include "qgsmapcanvas.h"
 #include "qgsmaptoolidentifyaction.h"
+#include "moc_qgsmaptoolidentifyaction.cpp"
 #include "qgsmaptoolselectionhandler.h"
 #include "qgsrasterlayer.h"
 #include "qgsvectordataprovider.h"
@@ -35,6 +36,7 @@
 #include "qgsmapmouseevent.h"
 #include "qgslayertreeview.h"
 #include "qgsmaplayeraction.h"
+#include "qgsunittypes.h"
 
 #include <QCursor>
 #include <QPixmap>
@@ -53,7 +55,6 @@ QgsMapToolIdentifyAction::QgsMapToolIdentifyAction( QgsMapCanvas *canvas )
   identifyMenu()->addCustomAction( attrTableAction );
   mSelectionHandler = new QgsMapToolSelectionHandler( canvas, QgsMapToolSelectionHandler::SelectSimple );
   connect( mSelectionHandler, &QgsMapToolSelectionHandler::geometryChanged, this, &QgsMapToolIdentifyAction::identifyFromGeometry );
-
 }
 
 QgsMapToolIdentifyAction::~QgsMapToolIdentifyAction()
@@ -73,8 +74,7 @@ QgsIdentifyResultsDialog *QgsMapToolIdentifyAction::resultsDialog()
 
     connect( mResultsDialog.data(), static_cast<void ( QgsIdentifyResultsDialog::* )( QgsRasterLayer * )>( &QgsIdentifyResultsDialog::formatChanged ), this, &QgsMapToolIdentify::formatChanged );
     connect( mResultsDialog.data(), &QgsIdentifyResultsDialog::copyToClipboard, this, &QgsMapToolIdentifyAction::handleCopyToClipboard );
-    connect( mResultsDialog.data(), &QgsIdentifyResultsDialog::selectionModeChanged, this, [this]
-    {
+    connect( mResultsDialog.data(), &QgsIdentifyResultsDialog::selectionModeChanged, this, [this] {
       mSelectionHandler->setSelectionMode( mResultsDialog->selectionMode() );
     } );
   }
@@ -103,7 +103,6 @@ void QgsMapToolIdentifyAction::showAttributeTable( QgsMapLayer *layer, const QLi
   tableDialog->show();
 }
 
-
 void QgsMapToolIdentifyAction::identifyFromGeometry()
 {
   resultsDialog()->clear();
@@ -133,6 +132,7 @@ void QgsMapToolIdentifyAction::identifyFromGeometry()
   QgsIdentifyContext identifyContext;
   if ( mCanvas->mapSettings().isTemporal() )
     identifyContext.setTemporalRange( mCanvas->temporalRange() );
+  identifyContext.setZRange( mCanvas->zRange() );
   const QList<IdentifyResult> results = QgsMapToolIdentify::identify( geometry, mode, layerList, AllLayers, identifyContext );
 
   disconnect( this, &QgsMapToolIdentifyAction::identifyMessage, QgisApp::instance(), &QgisApp::showStatusMessage );
@@ -222,7 +222,7 @@ void QgsMapToolIdentifyAction::clearResults()
 void QgsMapToolIdentifyAction::showResultsForFeature( QgsVectorLayer *vlayer, QgsFeatureId fid, const QgsPoint &pt )
 {
   const QgsFeature feature = vlayer->getFeature( fid );
-  const QMap< QString, QString > derivedAttributes = derivedAttributesForPoint( pt );
+  const QMap<QString, QString> derivedAttributes = derivedAttributesForPoint( pt );
   // TODO: private in QgsMapToolIdentify
   //derivedAttributes.unite( featureDerivedAttributes( feature, vlayer, QgsPointXY( pt ) ) );
 
@@ -234,12 +234,24 @@ void QgsMapToolIdentifyAction::showResultsForFeature( QgsVectorLayer *vlayer, Qg
 
 Qgis::DistanceUnit QgsMapToolIdentifyAction::displayDistanceUnits() const
 {
-  return QgsProject::instance()->distanceUnits();
+  Qgis::DistanceUnit units = QgsProject::instance()->distanceUnits();
+  // unknown units used as a placeholder for map units
+  if ( units == Qgis::DistanceUnit::Unknown )
+  {
+    return QgsProject::instance()->crs().mapUnits();
+  }
+  return units;
 }
 
 Qgis::AreaUnit QgsMapToolIdentifyAction::displayAreaUnits() const
 {
-  return QgsProject::instance()->areaUnits();
+  Qgis::AreaUnit units = QgsProject::instance()->areaUnits();
+  // unknown units used as a placeholder for map units
+  if ( units == Qgis::AreaUnit::Unknown )
+  {
+    return QgsUnitTypes::distanceToAreaUnit( QgsProject::instance()->crs().mapUnits() );
+  }
+  return units;
 }
 
 void QgsMapToolIdentifyAction::handleCopyToClipboard( QgsFeatureStore &featureStore )
@@ -262,15 +274,22 @@ void QgsMapToolIdentifyAction::setClickContextScope( const QgsPointXY &point )
   }
 }
 
-
 void QgsMapToolIdentifyAction::keyReleaseEvent( QKeyEvent *e )
 {
   if ( mSelectionHandler->keyReleaseEvent( e ) )
     return;
 
-  QgsMapTool::keyReleaseEvent( e );
-}
+  switch ( e->key() )
+  {
+    case Qt::Key_Escape:
+    {
+      clearResults();
+      return;
+    }
+  }
 
+  QgsMapToolIdentify::keyReleaseEvent( e );
+}
 
 void QgsMapToolIdentifyAction::showIdentifyResults( const QList<IdentifyResult> &identifyResults )
 {
