@@ -24,6 +24,8 @@
 #include "qgsvectorlayer.h"
 #include "qgisapp.h"
 #include "qgsmapmouseevent.h"
+#include "qgsvectorlayereditutils.h"
+#include "qgsmultipoint.h"
 
 QgsMapToolReshape::QgsMapToolReshape( QgsMapCanvas *canvas )
   : QgsMapToolCapture( canvas, QgisApp::instance()->cadDockWidget(), QgsMapToolCapture::CaptureLine )
@@ -65,15 +67,11 @@ void QgsMapToolReshape::cadCanvasReleaseEvent( QgsMapMouseEvent *e )
   {
     deleteTempRubberBand();
 
-    //find out bounding box of mCaptureList
-    if ( size() < 1 )
+    if ( size() > 1 )
     {
-      stopCapturing();
-      return;
+      reshape( vlayer );
     }
 
-    reshape( vlayer );
-
     stopCapturing();
   }
 }
@@ -162,12 +160,11 @@ void QgsMapToolReshape::reshape( QgsVectorLayer *vlayer )
   QgsAvoidIntersectionsOperation avoidIntersections;
   connect( &avoidIntersections, &QgsAvoidIntersectionsOperation::messageEmitted, this, &QgsMapTool::messageEmitted );
 
-  vlayer->beginEditCommand( tr( "Reshape" ) );
+  QHash<QgsFeatureId, QgsGeometry> reshapedGeometries;
+
+  // we first gather the features that are actually going to be reshaped and the reshaped results
   while ( fit.nextFeature( f ) )
   {
-    //query geometry
-    //call geometry->reshape(mCaptureList)
-    //register changed geometry in vector layer
     QgsGeometry geom = f.geometry();
     if ( !geom.isNull() )
     {
@@ -179,50 +176,54 @@ void QgsMapToolReshape::reshape( QgsVectorLayer *vlayer )
       reshapeReturn = geom.reshapeGeometry( reshapeLineString );
       if ( reshapeReturn == Qgis::GeometryOperationResult::Success )
       {
-        //avoid intersections on polygon layers
-        if ( vlayer->geometryType() == Qgis::GeometryType::Polygon )
-        {
-          //ignore all current layer features as they should be reshaped too
-          QHash<QgsVectorLayer *, QSet<QgsFeatureId>> ignoreFeatures;
-          ignoreFeatures.insert( vlayer, vlayer->allFeatureIds() );
-
-          const QgsAvoidIntersectionsOperation::Result res = avoidIntersections.apply( vlayer, f.id(), geom, ignoreFeatures );
-          if ( res.operationResult == Qgis::GeometryOperationResult::InvalidInputGeometryType )
-          {
-            emit messageEmitted( tr( "An error was reported during intersection removal" ), Qgis::MessageLevel::Warning );
-            vlayer->destroyEditCommand();
-            stopCapturing();
-            return;
-          }
-
-          if ( geom.isEmpty() ) //intersection removal might have removed the whole geometry
-          {
-            emit messageEmitted( tr( "The feature cannot be reshaped because the resulting geometry is empty" ), Qgis::MessageLevel::Critical );
-            vlayer->destroyEditCommand();
-            return;
-          }
-        }
-
-        vlayer->changeGeometry( f.id(), geom );
-        reshapeDone = true;
+        reshapedGeometries.insert( f.id(), geom );
       }
     }
   }
+  // ignore features that are going to be reshaped
+  // some intersected features may not be reshaped because of active selection or reshape line geometry
+  const QHash<QgsVectorLayer *, QSet<QgsFeatureId>> ignoreFeatures { { vlayer, qgis::listToSet( reshapedGeometries.keys() ) } };
+
+  // then we can apply intersection avoidance logic and eventually update the layer
+  vlayer->beginEditCommand( tr( "Reshape" ) );
+  for ( auto it = reshapedGeometries.begin(); it != reshapedGeometries.end(); ++it )
+  {
+    QgsFeatureId fid = it.key();
+    QgsGeometry geom = it.value();
+
+    //avoid intersections on polygon layers
+    if ( vlayer->geometryType() == Qgis::GeometryType::Polygon )
+    {
+      const QgsAvoidIntersectionsOperation::Result res = avoidIntersections.apply( vlayer, fid, geom, ignoreFeatures );
+      if ( res.operationResult == Qgis::GeometryOperationResult::InvalidInputGeometryType )
+      {
+        emit messageEmitted( tr( "An error was reported during intersection removal" ), Qgis::MessageLevel::Warning );
+        vlayer->destroyEditCommand();
+        stopCapturing();
+        return;
+      }
+
+      if ( geom.isEmpty() ) //intersection removal might have removed the whole geometry
+      {
+        emit messageEmitted( tr( "The feature cannot be reshaped because the resulting geometry is empty" ), Qgis::MessageLevel::Critical );
+        vlayer->destroyEditCommand();
+        return;
+      }
+    }
+
+    vlayer->changeGeometry( fid, geom );
+    reshapeDone = true;
+  }
 
   if ( reshapeDone )
   {
-    // Add topological points due to snapping
+    // Add topological points
     if ( QgsProject::instance()->topologicalEditing() )
     {
-      const QList<QgsPointLocator::Match> sm = snappingMatches();
-      Q_ASSERT( pts.size() == sm.size() );
-      for ( int i = 0; i < sm.size(); ++i )
-      {
-        if ( sm.at( i ).layer() )
-        {
-          sm.at( i ).layer()->addTopologicalPoints( pts.at( i ) );
-        }
-      }
+      //check if we need to add topological points to other layers
+      const QList<QgsMapLayer *> layers = canvas()->layers( true );
+      QgsGeometry pointsAsGeom( new QgsMultiPoint( pts ) );
+      QgsVectorLayerEditUtils::addTopologicalPointsToLayers( pointsAsGeom, vlayer, layers, mToolName );
     }
 
     vlayer->endEditCommand();
