@@ -13,14 +13,15 @@
  ***************************************************************************/
 
 #include "qgso2.h"
+#include "moc_qgso2.cpp"
 
 #include "o0globals.h"
 #include "o0settingsstore.h"
 #include "o2replyserver.h"
-#include "qgsapplication.h"
 #include "qgsauthoauth2config.h"
 #include "qgslogger.h"
 #include "qgsnetworkaccessmanager.h"
+#include "qgssetrequestinitiator_p.h"
 #include "qgsblockingnetworkrequest.h"
 
 #include <QDir>
@@ -30,20 +31,40 @@
 #include <QUrl>
 #include <QUrlQuery>
 #include <QCryptographicHash>
-
-#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
 #include <QRandomGenerator>
-#endif
 
 QString QgsO2::O2_OAUTH2_STATE = QStringLiteral( "state" );
 
-QgsO2::QgsO2( const QString &authcfg, QgsAuthOAuth2Config *oauth2config,
-              QObject *parent, QNetworkAccessManager *manager )
+QgsO2::QgsO2( const QString &authcfg, QgsAuthOAuth2Config *oauth2config, QObject *parent, QNetworkAccessManager *manager )
   : O2( parent, manager )
   , mTokenCacheFile( QString() )
   , mAuthcfg( authcfg )
   , mOAuth2Config( oauth2config )
 {
+  static std::once_flag initialized;
+  std::call_once( initialized, [=]() {
+    setLoggingFunction( []( const QString &message, LogLevel level ) {
+#ifdef QGISDEBUG
+      switch ( level )
+      {
+        case O0BaseAuth::LogLevel::Debug:
+          QgsDebugMsgLevel( message, 2 );
+          break;
+        case O0BaseAuth::LogLevel::Warning:
+        case O0BaseAuth::LogLevel::Critical:
+          QgsDebugError( message );
+          break;
+      }
+#else
+                                         ( void ) message;
+                                         ( void ) level;
+#endif
+    } );
+  } );
+
+  if ( mOAuth2Config )
+    mOAuth2Config->setParent( this );
+
   initOAuthConfig();
 }
 
@@ -71,7 +92,7 @@ void QgsO2::initOAuthConfig()
   }
 
   // common properties to all grant flows
-  const QString localpolicy = QStringLiteral( "http://127.0.0.1:% 1/%1" ).arg( mOAuth2Config->redirectUrl() ).replace( QLatin1String( "% 1" ), QLatin1String( "%1" ) );
+  const QString localpolicy = QStringLiteral( "http://%1:% 1/%2" ).arg( mOAuth2Config->redirectHost(), mOAuth2Config->redirectUrl() ).replace( QLatin1String( "% 1" ), QLatin1String( "%1" ) );
   QgsDebugMsgLevel( QStringLiteral( "localpolicy(w/port): %1" ).arg( localpolicy.arg( mOAuth2Config->redirectPort() ) ), 2 );
   setLocalhostPolicy( localpolicy );
   setLocalPort( mOAuth2Config->redirectPort() );
@@ -141,7 +162,12 @@ void QgsO2::setVerificationResponseContent()
   QFile verhtml( QStringLiteral( ":/oauth2method/oauth2_verification_finished.html" ) );
   if ( verhtml.open( QIODevice::ReadOnly | QIODevice::Text ) )
   {
-    setReplyContent( verhtml.readAll() );
+    setReplyContent( QString::fromUtf8( verhtml.readAll() )
+                       .replace( QStringLiteral( "{{ H2_TITLE }}" ), tr( "QGIS OAuth2 verification has finished" ) )
+                       .replace( QStringLiteral( "{{ H3_TITLE }}" ), tr( "If you have not been returned to QGIS, bring the application to the forefront." ) )
+                       .replace( QStringLiteral( "{{ CLOSE_WINDOW }}" ), tr( "Close window" ) )
+                       .toUtf8()
+    );
   }
 }
 
@@ -169,8 +195,23 @@ void QgsO2::onSetAuthCode( const QString &code )
 
 void QgsO2::link()
 {
+  Q_ASSERT( thread() == QThread::currentThread() );
+
   QgsDebugMsgLevel( QStringLiteral( "QgsO2::link" ), 4 );
 
+  // Create the reply server if it doesn't exist
+  // and we don't use an external web interceptor
+  if ( !useExternalWebInterceptor_ )
+  {
+    if ( replyServer() == NULL )
+    {
+      O2ReplyServer *replyServer = new O2ReplyServer( this );
+      connect( replyServer, &O2ReplyServer::verificationReceived, this, &QgsO2::onVerificationReceived );
+      connect( replyServer, &O2ReplyServer::serverClosed, this, &QgsO2::serverHasClosed );
+      setReplyServer( replyServer );
+    }
+  }
+
   if ( linked() )
   {
     QgsDebugMsgLevel( QStringLiteral( "QgsO2::link: Linked already" ), 4 );
@@ -187,28 +228,44 @@ void QgsO2::link()
 
   if ( grantFlow_ == GrantFlowAuthorizationCode || grantFlow_ == GrantFlowImplicit || grantFlow_ == GrantFlowPkce )
   {
-    if ( mIsLocalHost )
+    if ( useExternalWebInterceptor_ )
     {
-      // Start listening to authentication replies
-      replyServer_->listen( QHostAddress::Any, localPort_ );
-
       // Save redirect URI, as we have to reuse it when requesting the access token
-      redirectUri_ = localhostPolicy_.arg( replyServer_->serverPort() );
+      redirectUri_ = localhostPolicy_.arg( localPort() );
+    }
+    else
+    {
+      if ( mIsLocalHost )
+      {
+        if ( !replyServer()->isListening() )
+        {
+          // Start listening to authentication replies
+          if ( replyServer()->listen( QHostAddress::Any, localPort_ ) )
+          {
+            QgsDebugMsgLevel( QStringLiteral( "O2::link: Reply server listening on port %1" ).arg( localPort() ), 2 );
+          }
+          else
+          {
+            QgsDebugError( QStringLiteral( "O2::link: Reply server failed to start listening on port %1" ).arg( localPort() ) );
+            emit linkingFailed();
+            return;
+          }
+        }
+
+        // Save redirect URI, as we have to reuse it when requesting the access token
+        redirectUri_ = localhostPolicy_.arg( replyServer()->serverPort() );
+      }
     }
     // Assemble initial authentication URL
-    QList<QPair<QString, QString> > parameters;
-    parameters.append( qMakePair( QString( O2_OAUTH2_RESPONSE_TYPE ), ( grantFlow_ == GrantFlowAuthorizationCode || grantFlow_ == GrantFlowPkce ) ?
-                                  QString( O2_OAUTH2_GRANT_TYPE_CODE ) :
-                                  QString( O2_OAUTH2_GRANT_TYPE_TOKEN ) ) );
+    QList<QPair<QString, QString>> parameters;
+    parameters.append( qMakePair( QString( O2_OAUTH2_RESPONSE_TYPE ), ( grantFlow_ == GrantFlowAuthorizationCode || grantFlow_ == GrantFlowPkce ) ? QString( O2_OAUTH2_GRANT_TYPE_CODE ) : QString( O2_OAUTH2_GRANT_TYPE_TOKEN ) ) );
     parameters.append( qMakePair( QString( O2_OAUTH2_CLIENT_ID ), clientId_ ) );
     parameters.append( qMakePair( QString( O2_OAUTH2_REDIRECT_URI ), redirectUri_ ) );
 
     if ( grantFlow_ == GrantFlowPkce )
     {
-      pkceCodeVerifier_ = ( QUuid::createUuid().toString( QUuid::WithoutBraces ) +
-                            QUuid::createUuid().toString( QUuid::WithoutBraces ) ).toLatin1();
-      pkceCodeChallenge_ = QCryptographicHash::hash( pkceCodeVerifier_, QCryptographicHash::Sha256 ).toBase64(
-                             QByteArray::Base64UrlEncoding | QByteArray::OmitTrailingEquals );
+      pkceCodeVerifier_ = ( QUuid::createUuid().toString( QUuid::WithoutBraces ) + QUuid::createUuid().toString( QUuid::WithoutBraces ) ).toLatin1();
+      pkceCodeChallenge_ = QCryptographicHash::hash( pkceCodeVerifier_, QCryptographicHash::Sha256 ).toBase64( QByteArray::Base64UrlEncoding | QByteArray::OmitTrailingEquals );
       parameters.append( qMakePair( QString( O2_OAUTH2_PKCE_CODE_CHALLENGE_PARAM ), pkceCodeChallenge_ ) );
       parameters.append( qMakePair( QString( O2_OAUTH2_PKCE_CODE_CHALLENGE_METHOD_PARAM ), QString( O2_OAUTH2_PKCE_CODE_CHALLENGE_METHOD_S256 ) ) );
     }
@@ -250,13 +307,11 @@ void QgsO2::link()
     if ( !apiKey_.isEmpty() )
       parameters.append( O0RequestParameter( O2_OAUTH2_API_KEY, apiKey_.toUtf8() ) );
 
-
     for ( auto iter = extraReqParams_.constBegin(); iter != extraReqParams_.constEnd(); ++iter )
     {
       parameters.append( O0RequestParameter( iter.key().toUtf8(), iter.value().toString().toUtf8() ) );
     }
 
-
     const QByteArray payload = O0BaseAuth::createQueryParameters( parameters );
 
     const QUrl url( tokenUrl_ );
@@ -265,24 +320,17 @@ void QgsO2::link()
     tokenRequest.setHeader( QNetworkRequest::ContentTypeHeader, QLatin1String( "application/x-www-form-urlencoded" ) );
     QNetworkReply *tokenReply = getManager()->post( tokenRequest, payload );
 
-    connect( tokenReply, SIGNAL( finished() ), this, SLOT( onTokenReplyFinished() ), Qt::QueuedConnection );
-    connect( tokenReply, SIGNAL( error( QNetworkReply::NetworkError ) ), this, SLOT( onTokenReplyError( QNetworkReply::NetworkError ) ), Qt::QueuedConnection );
+    connect( tokenReply, &QNetworkReply::finished, this, &QgsO2::onTokenReplyFinished, Qt::QueuedConnection );
+    connect( tokenReply, &QNetworkReply::errorOccurred, this, &QgsO2::onTokenReplyError, Qt::QueuedConnection );
   }
 }
 
-
 void QgsO2::setState( const QString & )
 {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-  qsrand( QTime::currentTime().msec() );
-  state_ = QString::number( qrand() );
-#else
   state_ = QString::number( QRandomGenerator::system()->generate() );
-#endif
   Q_EMIT stateChanged();
 }
 
-
 void QgsO2::onVerificationReceived( QMap<QString, QString> response )
 {
   QgsDebugMsgLevel( QStringLiteral( "QgsO2::onVerificationReceived: Emitting closeBrowser()" ), 4 );
@@ -303,7 +351,7 @@ void QgsO2::onVerificationReceived( QMap<QString, QString> response )
       {
         if ( response.value( QStringLiteral( "state" ), QStringLiteral( "ignore" ) ) != state_ )
         {
-          QgsDebugMsgLevel( QStringLiteral( "QgsO2::onVerificationReceived: Verification failed: (Response returned wrong state)" ), 3 ) ;
+          QgsDebugMsgLevel( QStringLiteral( "QgsO2::onVerificationReceived: Verification failed: (Response returned wrong state)" ), 3 );
           emit linkingFailed();
           return;
         }
@@ -321,7 +369,6 @@ void QgsO2::onVerificationReceived( QMap<QString, QString> response )
 
   if ( grantFlow_ == GrantFlowAuthorizationCode || grantFlow_ == GrantFlowPkce )
   {
-
     // Exchange access code for access/refresh tokens
     QString query;
     if ( !apiKey_.isEmpty() )
@@ -347,18 +394,14 @@ void QgsO2::onVerificationReceived( QMap<QString, QString> response )
     QNetworkReply *tokenReply = getManager()->post( tokenRequest, data );
     timedReplies_.add( tokenReply );
     connect( tokenReply, &QNetworkReply::finished, this, &QgsO2::onTokenReplyFinished, Qt::QueuedConnection );
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    connect( tokenReply, qOverload<QNetworkReply::NetworkError>( &QNetworkReply::error ), this, &QgsO2::onTokenReplyError, Qt::QueuedConnection );
-#else
     connect( tokenReply, &QNetworkReply::errorOccurred, this, &QgsO2::onTokenReplyError, Qt::QueuedConnection );
-#endif
   }
   else if ( grantFlow_ == GrantFlowImplicit )
   {
     // Check for mandatory tokens
     if ( response.contains( O2_OAUTH2_ACCESS_TOKEN ) )
     {
-      qDebug() << "O2::onVerificationReceived: Access token returned for implicit flow";
+      QgsDebugMsgLevel( QStringLiteral( "O2::onVerificationReceived: Access token returned for implicit flow" ), 2 );
       setToken( response.value( O2_OAUTH2_ACCESS_TOKEN ) );
       if ( response.contains( O2_OAUTH2_EXPIRES_IN ) )
       {
@@ -366,8 +409,8 @@ void QgsO2::onVerificationReceived( QMap<QString, QString> response )
         const int expiresIn = response.value( O2_OAUTH2_EXPIRES_IN ).toInt( &ok );
         if ( ok )
         {
-          qDebug() << "O2::onVerificationReceived: Token expires in" << expiresIn << "seconds";
-          setExpires( QDateTime::currentMSecsSinceEpoch() / 1000 + expiresIn );
+          QgsDebugMsgLevel( QStringLiteral( "O2::onVerificationReceived: Token expires in %1 seconds" ).arg( expiresIn ), 2 );
+          setExpires( QDateTime::currentMSecsSinceEpoch() / 1000 + static_cast<qint64>( expiresIn ) );
         }
       }
       setLinked( true );
@@ -375,7 +418,7 @@ void QgsO2::onVerificationReceived( QMap<QString, QString> response )
     }
     else
     {
-      qWarning() << "O2::onVerificationReceived: Access token missing from response for implicit flow";
+      QgsDebugError( QStringLiteral( "O2::onVerificationReceived: Access token missing from response for implicit flow" ) );
       Q_EMIT linkingFailed();
     }
   }
@@ -398,13 +441,13 @@ static QVariantMap parseTokenResponse( const QByteArray &data )
   const QJsonDocument doc = QJsonDocument::fromJson( data, &err );
   if ( err.error != QJsonParseError::NoError )
   {
-    qWarning() << "parseTokenResponse: Failed to parse token response due to err:" << err.errorString();
+    QgsDebugError( QStringLiteral( "parseTokenResponse: Failed to parse token response due to err: %1" ).arg( err.errorString() ) );
     return QVariantMap();
   }
 
   if ( !doc.isObject() )
   {
-    qWarning() << "parseTokenResponse: Token response is not an object";
+    QgsDebugError( QStringLiteral( "parseTokenResponse: Token response is not an object" ) );
     return QVariantMap();
   }
 
@@ -414,17 +457,17 @@ static QVariantMap parseTokenResponse( const QByteArray &data )
 // Code adapted from O2::refresh(), but using QgsBlockingNetworkRequest
 void QgsO2::refreshSynchronous()
 {
-  qDebug() << "O2::refresh: Token: ..." << refreshToken().right( 7 );
+  QgsDebugMsgLevel( QStringLiteral( "O2::refresh: Token: ... %1" ).arg( refreshToken().right( 7 ) ), 2 );
 
   if ( refreshToken().isEmpty() )
   {
-    qWarning() << "O2::refresh: No refresh token";
+    QgsDebugError( QStringLiteral( "O2::refresh: No refresh token" ) );
     onRefreshError( QNetworkReply::AuthenticationRequiredError );
     return;
   }
   if ( refreshTokenUrl_.isEmpty() )
   {
-    qWarning() << "O2::refresh: Refresh token URL not set";
+    QgsDebugError( QStringLiteral( "O2::refresh: Refresh token URL not set" ) );
     onRefreshError( QNetworkReply::AuthenticationRequiredError );
     return;
   }
@@ -451,18 +494,19 @@ void QgsO2::refreshSynchronous()
     const QVariantMap tokens = parseTokenResponse( reply );
     if ( tokens.contains( QStringLiteral( "error" ) ) )
     {
-      qDebug() << " Error refreshing token" << tokens.value( QStringLiteral( "error" ) ).toMap().value( QStringLiteral( "message" ) ).toString().toLocal8Bit().constData();
+      QgsDebugError( QStringLiteral( "Error refreshing token %1" ).arg( tokens.value( QStringLiteral( "error" ) ).toMap().value( QStringLiteral( "message" ) ).toString().toLocal8Bit().constData() ) );
       unlink();
     }
     else
     {
       setToken( tokens.value( O2_OAUTH2_ACCESS_TOKEN ).toString() );
-      setExpires( QDateTime::currentMSecsSinceEpoch() / 1000 + tokens.value( O2_OAUTH2_EXPIRES_IN ).toInt() );
+      const int expiresIn = tokens.value( O2_OAUTH2_EXPIRES_IN ).toInt();
+      setExpires( QDateTime::currentMSecsSinceEpoch() / 1000 + static_cast<qint64>( expiresIn ) );
       const QString refreshToken = tokens.value( O2_OAUTH2_REFRESH_TOKEN ).toString();
       if ( !refreshToken.isEmpty() )
         setRefreshToken( refreshToken );
       setLinked( true );
-      qDebug() << " New token expires in" << expires() << "seconds";
+      QgsDebugMsgLevel( QStringLiteral( "New token expires in %1 seconds" ).arg( expiresIn ), 2 );
       emit linkingSucceeded();
     }
     emit refreshFinished( QNetworkReply::NoError );
@@ -470,13 +514,13 @@ void QgsO2::refreshSynchronous()
   else
   {
     unlink();
-    qDebug() << "O2::onRefreshFinished: Error" << blockingRequest.errorMessage();
+    QgsDebugError( QStringLiteral( "O2::onRefreshFinished: Error %1" ).arg( blockingRequest.errorMessage() ) );
     emit refreshFinished( blockingRequest.reply().error() );
   }
 }
 
 void QgsO2::computeExpirationDelay()
 {
-  const int lExpires = expires();
-  mExpirationDelay = lExpires > 0 ? lExpires - static_cast<int>( QDateTime::currentMSecsSinceEpoch() / 1000 ) : 0;
+  const qint64 lExpires = expires();
+  mExpirationDelay = static_cast<int>( lExpires > 0 ? lExpires - static_cast<qint64>( QDateTime::currentMSecsSinceEpoch() / 1000 ) : 0 );
 }
