@@ -23,6 +23,9 @@
 #include "qgsrenderer.h"
 #include "qgsvectorlayerlabeling.h"
 #include "qgslabelsink.h"
+#include "qgsmaplayerstyle.h"
+#include "qgsrendercontext.h"
+#include "qgsdxfexport.h"
 
 /**
  * Holds information about each layer in a DXF job.
@@ -30,7 +33,7 @@
  */
 struct DxfLayerJob
 {
-    DxfLayerJob( QgsVectorLayer *vl, const QString &layerStyleOverride, QgsRenderContext &renderContext, QgsDxfExport *dxfExport, const QString &splitLayerAttribute )
+    DxfLayerJob( QgsVectorLayer *vl, const QString &layerStyleOverride, QgsRenderContext &renderContext, QgsDxfExport *dxfExport, const QString &splitLayerAttribute, const QString &layerDerivedName )
       : renderContext( renderContext )
       , styleOverride( vl )
       , featureSource( vl )
@@ -38,16 +41,16 @@ struct DxfLayerJob
       , crs( vl->crs() )
       , layerName( vl->name() )
       , splitLayerAttribute( splitLayerAttribute )
-      , layerTitle( vl->title().isEmpty() ? vl->name() : vl->title() )
+      , layerDerivedName( layerDerivedName )
     {
-      fields = vl->fields();
-      renderer.reset( vl->renderer()->clone() );
-      renderContext.expressionContext().appendScope( QgsExpressionContextUtils::layerScope( vl ) );
-
       if ( !layerStyleOverride.isNull() )
       {
         styleOverride.setOverrideStyle( layerStyleOverride );
       }
+      fields = vl->fields();
+      selectedFeatureIds = vl->selectedFeatureIds();
+      renderer.reset( vl->renderer()->clone() );
+      renderContext.expressionContext().appendScope( QgsExpressionContextUtils::layerScope( vl ) );
 
       labeling.reset( vl->labelsEnabled() ? vl->labeling()->clone() : nullptr );
 
@@ -91,6 +94,7 @@ struct DxfLayerJob
 
     QgsRenderContext renderContext;
     QgsFields fields;
+    QgsFeatureIds selectedFeatureIds;
     QgsMapLayerStyleOverride styleOverride;
     QgsVectorLayerFeatureSource featureSource;
     std::unique_ptr< QgsFeatureRenderer > renderer;
@@ -101,7 +105,7 @@ struct DxfLayerJob
     QgsLabelSinkProvider *labelProvider = nullptr;
     QgsRuleBasedLabelSinkProvider *ruleBasedLabelProvider = nullptr;
     QString splitLayerAttribute;
-    QString layerTitle;
+    QString layerDerivedName;  // Obtained from overridden name, title or layer name
     QSet<QString> attributes;
 
   private:
