@@ -70,8 +70,8 @@ double QgsDxfPaintDevice::widthScaleFactor() const
     return 1.0;
   }
 
-  double widthFactor = mRectangle.width() / mDrawingSize.width();
-  double heightFactor = mRectangle.height() / mDrawingSize.height();
+  const double widthFactor = mRectangle.width() / mDrawingSize.width();
+  const double heightFactor = mRectangle.height() / mDrawingSize.height();
   return ( widthFactor + heightFactor ) / 2.0;
 }
 
@@ -82,8 +82,8 @@ QPointF QgsDxfPaintDevice::dxfCoordinates( QPointF pt ) const
     return QPointF( pt.x(), pt.y() );
   }
 
-  double x = mRectangle.left() + pt.x() * ( mRectangle.width() / mDrawingSize.width() );
-  double y = mRectangle.bottom() - pt.y() * ( mRectangle.height() / mDrawingSize.height() );
+  const double x = mRectangle.left() + pt.x() * ( mRectangle.width() / mDrawingSize.width() );
+  const double y = mRectangle.bottom() - pt.y() * ( mRectangle.height() / mDrawingSize.height() );
   return QPointF( x, y );
 }
 
