@@ -369,10 +369,10 @@ bool QgsGeoPackageProjectStorage::removeProject( const QString &uri )
     errCause = QObject::tr( "Could not remove project %1: %2" ).arg( uri, errCause );
     QgsMessageLog::logMessage( errCause, QStringLiteral( "OGR" ), Qgis::MessageLevel::Warning );
   }
-  else if ( QgsProject::instance()->fileName() == uri )
+  else if ( QgsProject::instance()->fileName() == uri ) // skip-keyword-check
   {
     QgsMessageLog::logMessage( QStringLiteral( "Current project was removed from storage, marking it dirty." ), QStringLiteral( "OGR" ), Qgis::MessageLevel::Warning );
-    QgsProject::instance()->setDirty( true );
+    QgsProject::instance()->setDirty( true ); // skip-keyword-check
   }
   return errCause.isEmpty();
 }
