@@ -19,6 +19,7 @@
 
 #include <QByteArray>
 #include <QColor>
+#include <QLocale>
 
 #include "qgslogger.h"
 #include "qgsrasterblock.h"
@@ -75,7 +76,7 @@ bool QgsRasterBlock::reset( Qgis::DataType dataType, int width, int height )
     mData = qgsMalloc( tSize * width * height );
     if ( !mData )
     {
-      QgsDebugMsg( QStringLiteral( "Couldn't allocate data memory of %1 bytes" ).arg( tSize * width * height ) );
+      QgsDebugError( QStringLiteral( "Couldn't allocate data memory of %1 bytes" ).arg( tSize * width * height ) );
       return false;
     }
   }
@@ -87,7 +88,7 @@ bool QgsRasterBlock::reset( Qgis::DataType dataType, int width, int height )
   }
   else
   {
-    QgsDebugMsg( QStringLiteral( "Wrong data type" ) );
+    QgsDebugError( QStringLiteral( "Wrong data type" ) );
     return false;
   }
 
@@ -141,6 +142,7 @@ bool QgsRasterBlock::typeIsNumeric( Qgis::DataType dataType )
   switch ( dataType )
   {
     case Qgis::DataType::Byte:
+    case Qgis::DataType::Int8:
     case Qgis::DataType::UInt16:
     case Qgis::DataType::Int16:
     case Qgis::DataType::UInt32:
@@ -171,6 +173,7 @@ bool QgsRasterBlock::typeIsColor( Qgis::DataType dataType )
 
     case Qgis::DataType::UnknownDataType:
     case Qgis::DataType::Byte:
+    case Qgis::DataType::Int8:
     case Qgis::DataType::UInt16:
     case Qgis::DataType::Int16:
     case Qgis::DataType::UInt32:
@@ -188,11 +191,12 @@ bool QgsRasterBlock::typeIsColor( Qgis::DataType dataType )
 
 Qgis::DataType QgsRasterBlock::typeWithNoDataValue( Qgis::DataType dataType, double *noDataValue )
 {
-  Qgis::DataType newDataType;
+  Qgis::DataType newDataType = Qgis::DataType::UnknownDataType;
 
   switch ( dataType )
   {
     case Qgis::DataType::Byte:
+    case Qgis::DataType::Int8:
       *noDataValue = -32768.0;
       newDataType = Qgis::DataType::Int16;
       break;
@@ -211,8 +215,14 @@ Qgis::DataType QgsRasterBlock::typeWithNoDataValue( Qgis::DataType dataType, dou
       *noDataValue = std::numeric_limits<double>::max() * -1.0;
       newDataType = Qgis::DataType::Float64;
       break;
-    default:
-      QgsDebugMsg( QStringLiteral( "Unknown data type %1" ).arg( static_cast< int >( dataType ) ) );
+    case Qgis::DataType::CInt16:
+    case Qgis::DataType::CInt32:
+    case Qgis::DataType::CFloat32:
+    case Qgis::DataType::CFloat64:
+    case Qgis::DataType::ARGB32:
+    case Qgis::DataType::ARGB32_Premultiplied:
+    case Qgis::DataType::UnknownDataType:
+      QgsDebugError( QStringLiteral( "Unknown data type %1" ).arg( static_cast< int >( dataType ) ) );
       return Qgis::DataType::UnknownDataType;
   }
   QgsDebugMsgLevel( QStringLiteral( "newDataType = %1 noDataValue = %2" ).arg( qgsEnumValueToKey< Qgis::DataType >( newDataType ) ).arg( *noDataValue ), 4 );
@@ -241,7 +251,7 @@ bool QgsRasterBlock::setIsNoData()
     {
       if ( !mData )
       {
-        QgsDebugMsg( QStringLiteral( "Data block not allocated" ) );
+        QgsDebugError( QStringLiteral( "Data block not allocated" ) );
         return false;
       }
 
@@ -284,7 +294,7 @@ bool QgsRasterBlock::setIsNoData()
     // image
     if ( !mImage )
     {
-      QgsDebugMsg( QStringLiteral( "Image not allocated" ) );
+      QgsDebugError( QStringLiteral( "Image not allocated" ) );
       return false;
     }
     QgsDebugMsgLevel( QStringLiteral( "Fill image" ), 4 );
@@ -312,7 +322,7 @@ bool QgsRasterBlock::setIsNoDataExcept( QRect exceptRect )
     {
       if ( !mData )
       {
-        QgsDebugMsg( QStringLiteral( "Data block not allocated" ) );
+        QgsDebugError( QStringLiteral( "Data block not allocated" ) );
         return false;
       }
 
@@ -405,13 +415,13 @@ bool QgsRasterBlock::setIsNoDataExcept( QRect exceptRect )
     // image
     if ( !mImage )
     {
-      QgsDebugMsg( QStringLiteral( "Image not allocated" ) );
+      QgsDebugError( QStringLiteral( "Image not allocated" ) );
       return false;
     }
 
     if ( mImage->width() != mWidth ||  mImage->height() != mHeight )
     {
-      QgsDebugMsg( QStringLiteral( "Image and block size differ" ) );
+      QgsDebugError( QStringLiteral( "Image and block size differ" ) );
       return false;
     }
 
@@ -420,7 +430,7 @@ bool QgsRasterBlock::setIsNoDataExcept( QRect exceptRect )
     // TODO: support different depths
     if ( mImage->depth() != 32 )
     {
-      QgsDebugMsg( QStringLiteral( "Unsupported image depth" ) );
+      QgsDebugError( QStringLiteral( "Unsupported image depth" ) );
       return false;
     }
 
@@ -497,9 +507,35 @@ char *QgsRasterBlock::bits( qgssize index )
   {
     return reinterpret_cast< char * >( mData ) + index * mTypeSize;
   }
-  if ( mImage && mImage->bits() )
+  if ( mImage )
   {
-    return reinterpret_cast< char * >( mImage->bits() + index * 4 );
+    if ( uchar *data = mImage->bits() )
+    {
+      return reinterpret_cast< char * >( data + index * 4 );
+    }
+  }
+
+  return nullptr;
+}
+
+const char *QgsRasterBlock::constBits( qgssize index ) const
+{
+  // Not testing type to avoid too much overhead because this method is called per pixel
+  if ( index >= static_cast< qgssize >( mWidth )*mHeight )
+  {
+    QgsDebugMsgLevel( QStringLiteral( "Index %1 out of range (%2 x %3)" ).arg( index ).arg( mWidth ).arg( mHeight ), 4 );
+    return nullptr;
+  }
+  if ( mData )
+  {
+    return reinterpret_cast< const char * >( mData ) + index * mTypeSize;
+  }
+  if ( mImage )
+  {
+    if ( const uchar *data = mImage->constBits() )
+    {
+      return reinterpret_cast< const char * >( data + index * 4 );
+    }
   }
 
   return nullptr;
@@ -516,9 +552,29 @@ char *QgsRasterBlock::bits()
   {
     return reinterpret_cast< char * >( mData );
   }
-  if ( mImage && mImage->bits() )
+  if ( mImage )
   {
-    return reinterpret_cast< char * >( mImage->bits() );
+    if ( uchar *data = mImage->bits() )
+    {
+      return reinterpret_cast< char * >( data );
+    }
+  }
+
+  return nullptr;
+}
+
+const char *QgsRasterBlock::constBits() const
+{
+  if ( mData )
+  {
+    return reinterpret_cast< const char * >( mData );
+  }
+  if ( mImage )
+  {
+    if ( const uchar *data = mImage->constBits() )
+    {
+      return reinterpret_cast< const char * >( data );
+    }
   }
 
   return nullptr;
@@ -535,7 +591,7 @@ bool QgsRasterBlock::convert( Qgis::DataType destDataType )
 
     if ( !data )
     {
-      QgsDebugMsg( QStringLiteral( "Cannot convert raster block" ) );
+      QgsDebugError( QStringLiteral( "Cannot convert raster block" ) );
       return false;
     }
     qgsFree( mData );
@@ -615,7 +671,7 @@ bool QgsRasterBlock::setImage( const QImage *image )
   return true;
 }
 
-QString QgsRasterBlock::printValue( double value )
+QString QgsRasterBlock::printValue( double value, bool localized )
 {
   /*
    *  IEEE 754 double has 15-17 significant digits. It specifies:
@@ -644,17 +700,22 @@ QString QgsRasterBlock::printValue( double value )
   for ( int i = 15; i <= 17; i++ )
   {
     s.setNum( value, 'g', i );
-    if ( qgsDoubleNear( s.toDouble(), value ) )
+    const double doubleValue { s.toDouble( ) };
+    if ( qgsDoubleNear( doubleValue, value ) )
     {
+      if ( localized )
+      {
+        return QLocale().toString( doubleValue, 'g', i );
+      }
       return s;
     }
   }
   // Should not happen
-  QgsDebugMsg( QStringLiteral( "Cannot correctly parse printed value" ) );
+  QgsDebugError( QStringLiteral( "Cannot correctly parse printed value" ) );
   return s;
 }
 
-QString QgsRasterBlock::printValue( float value )
+QString QgsRasterBlock::printValue( float value, bool localized )
 {
   /*
    *  IEEE 754 double has 6-9 significant digits. See printValue(double)
@@ -665,13 +726,18 @@ QString QgsRasterBlock::printValue( float value )
   for ( int i = 6; i <= 9; i++ )
   {
     s.setNum( value, 'g', i );
-    if ( qgsFloatNear( s.toFloat(), value ) )
+    const float floatValue { s.toFloat() };
+    if ( qgsFloatNear( floatValue, value ) )
     {
+      if ( localized )
+      {
+        return QLocale().toString( floatValue, 'g', i );
+      }
       return s;
     }
   }
   // Should not happen
-  QgsDebugMsg( QStringLiteral( "Cannot correctly parse printed value" ) );
+  QgsDebugError( QStringLiteral( "Cannot correctly parse printed value" ) );
   return s;
 }
 
@@ -684,7 +750,7 @@ void *QgsRasterBlock::convert( void *srcData, Qgis::DataType srcDataType, Qgis::
     const double value = readValue( srcData, srcDataType, i );
     writeValue( destData, destDataType, i, value );
     //double newValue = readValue( destData, destDataType, i );
-    //QgsDebugMsg( QStringLiteral("convert %1 type %2 to %3: %4 -> %5").arg(i).arg(srcDataType).arg(destDataType).arg( value ).arg( newValue ) );
+    //QgsDebugMsgLevel( QStringLiteral("convert %1 type %2 to %3: %4 -> %5").arg(i).arg(srcDataType).arg(destDataType).arg( value ).arg( newValue ), 2 );
   }
   return destData;
 }
@@ -708,6 +774,12 @@ QByteArray QgsRasterBlock::valueBytes( Qgis::DataType dataType, double value )
       uc = static_cast< quint8 >( value );
       memcpy( data, &uc, size );
       break;
+    case Qgis::DataType::Int8:
+    {
+      const qint8 myint8 = static_cast< qint8 >( value );
+      memcpy( data, &myint8, size );
+      break;
+    }
     case Qgis::DataType::UInt16:
       us = static_cast< quint16 >( value );
       memcpy( data, &us, size );
@@ -732,8 +804,14 @@ QByteArray QgsRasterBlock::valueBytes( Qgis::DataType dataType, double value )
       d = static_cast< double >( value );
       memcpy( data, &d, size );
       break;
-    default:
-      QgsDebugMsg( QStringLiteral( "Data type is not supported" ) );
+    case Qgis::DataType::CInt16:
+    case Qgis::DataType::CInt32:
+    case Qgis::DataType::CFloat32:
+    case Qgis::DataType::CFloat64:
+    case Qgis::DataType::ARGB32:
+    case Qgis::DataType::ARGB32_Premultiplied:
+    case Qgis::DataType::UnknownDataType:
+      QgsDebugError( QStringLiteral( "Data type is not supported" ) );
   }
   return ba;
 }
@@ -746,7 +824,7 @@ bool QgsRasterBlock::createNoDataBitmap()
   mNoDataBitmap = reinterpret_cast< char * >( qgsMalloc( mNoDataBitmapSize ) );
   if ( !mNoDataBitmap )
   {
-    QgsDebugMsg( QStringLiteral( "Couldn't allocate no data memory of %1 bytes" ).arg( mNoDataBitmapSize ) );
+    QgsDebugError( QStringLiteral( "Couldn't allocate no data memory of %1 bytes" ).arg( mNoDataBitmapSize ) );
     return false;
   }
   memset( mNoDataBitmap, 0, mNoDataBitmapSize );
