@@ -26,6 +26,7 @@
 #include "qgsrasterbandstats.h"
 #include "qgsrasterhistogram.h"
 #include "qgsrasterinterface.h"
+#include "moc_qgsrasterinterface.cpp"
 #include "qgsrectangle.h"
 
 QgsRasterInterface::QgsRasterInterface( QgsRasterInterface *input )
@@ -33,11 +34,16 @@ QgsRasterInterface::QgsRasterInterface( QgsRasterInterface *input )
 {
 }
 
+Qgis::RasterInterfaceCapabilities QgsRasterInterface::capabilities() const
+{
+  return Qgis::RasterInterfaceCapability::NoCapabilities;
+}
+
 void QgsRasterInterface::initStatistics( QgsRasterBandStats &statistics,
     int bandNo,
-    int stats,
+    Qgis::RasterBandStatistics stats,
     const QgsRectangle &boundingBox,
-    int sampleSize )
+    int sampleSize ) const
 {
   QgsDebugMsgLevel( QStringLiteral( "theBandNo = %1 sampleSize = %2" ).arg( bandNo ).arg( sampleSize ), 4 );
 
@@ -62,7 +68,7 @@ void QgsRasterInterface::initStatistics( QgsRasterBandStats &statistics,
     xRes = yRes = std::sqrt( ( finalExtent.width() * finalExtent.height() ) / sampleSize );
 
     // But limit by physical resolution
-    if ( capabilities() & Size )
+    if ( capabilities() & Qgis::RasterInterfaceCapability::Size )
     {
       const double srcXRes = extent().width() / xSize();
       const double srcYRes = extent().height() / ySize();
@@ -76,7 +82,7 @@ void QgsRasterInterface::initStatistics( QgsRasterBandStats &statistics,
   }
   else
   {
-    if ( capabilities() & Size )
+    if ( capabilities() & Qgis::RasterInterfaceCapability::Size )
     {
       statistics.width = xSize();
       statistics.height = ySize();
@@ -91,7 +97,7 @@ void QgsRasterInterface::initStatistics( QgsRasterBandStats &statistics,
 }
 
 bool QgsRasterInterface::hasStatistics( int bandNo,
-                                        int stats,
+                                        Qgis::RasterBandStatistics stats,
                                         const QgsRectangle &extent,
                                         int sampleSize )
 {
@@ -114,7 +120,7 @@ bool QgsRasterInterface::hasStatistics( int bandNo,
 }
 
 QgsRasterBandStats QgsRasterInterface::bandStatistics( int bandNo,
-    int stats,
+    Qgis::RasterBandStatistics stats,
     const QgsRectangle &extent,
     int sampleSize, QgsRasterBlockFeedback *feedback )
 {
@@ -240,12 +246,17 @@ QgsRasterBandStats QgsRasterInterface::bandStatistics( int bandNo,
   QgsDebugMsgLevel( QStringLiteral( "MEAN %1" ).arg( myRasterBandStats.mean ), 4 );
   QgsDebugMsgLevel( QStringLiteral( "STDDEV %1" ).arg( myRasterBandStats.stdDev ), 4 );
 
-  myRasterBandStats.statsGathered = QgsRasterBandStats::All;
+  myRasterBandStats.statsGathered = Qgis::RasterBandStatistic::All;
   mStatistics.append( myRasterBandStats );
 
   return myRasterBandStats;
 }
 
+bool QgsRasterInterface::hasStatistics( int bandNo, int stats, const QgsRectangle &extent, int sampleSize )
+{
+  return hasStatistics( bandNo, static_cast< Qgis::RasterBandStatistics >( stats ), extent, sampleSize );
+}
+
 void QgsRasterInterface::initHistogram( QgsRasterHistogram &histogram,
                                         int bandNo,
                                         int binCount,
@@ -274,7 +285,7 @@ void QgsRasterInterface::initHistogram( QgsRasterHistogram &histogram,
       // We need statistics -> avoid histogramDefaults in hasHistogram if possible
       // TODO: use approximated statistics if approximated histogram is requested
       // (theSampleSize > 0)
-      const QgsRasterBandStats stats = bandStatistics( bandNo, QgsRasterBandStats::Min, boundingBox, sampleSize );
+      const QgsRasterBandStats stats = bandStatistics( bandNo, Qgis::RasterBandStatistic::Min, boundingBox, sampleSize );
       histogram.minimum = stats.minimumValue;
     }
   }
@@ -286,7 +297,7 @@ void QgsRasterInterface::initHistogram( QgsRasterHistogram &histogram,
     }
     else
     {
-      const QgsRasterBandStats stats = bandStatistics( bandNo, QgsRasterBandStats::Max, boundingBox, sampleSize );
+      const QgsRasterBandStats stats = bandStatistics( bandNo, Qgis::RasterBandStatistic::Max, boundingBox, sampleSize );
       histogram.maximum = stats.maximumValue;
     }
   }
@@ -309,7 +320,7 @@ void QgsRasterInterface::initHistogram( QgsRasterHistogram &histogram,
     xRes = yRes = std::sqrt( ( static_cast<double>( finalExtent.width( ) ) * finalExtent.height() ) / sampleSize );
 
     // But limit by physical resolution
-    if ( capabilities() & Size )
+    if ( capabilities() & Qgis::RasterInterfaceCapability::Size )
     {
       const double srcXRes = extent().width() / xSize();
       const double srcYRes = extent().height() / ySize();
@@ -323,7 +334,7 @@ void QgsRasterInterface::initHistogram( QgsRasterHistogram &histogram,
   }
   else
   {
-    if ( capabilities() & Size )
+    if ( capabilities() & Qgis::RasterInterfaceCapability::Size )
     {
       histogram.width = xSize();
       histogram.height = ySize();
@@ -373,6 +384,10 @@ void QgsRasterInterface::initHistogram( QgsRasterHistogram &histogram,
   QgsDebugMsgLevel( QStringLiteral( "theHistogram.binCount = %1" ).arg( histogram.binCount ), 4 );
 }
 
+void QgsRasterInterface::initStatistics( QgsRasterBandStats &statistics, int bandNo, int stats, const QgsRectangle &boundingBox, int binCount ) const
+{
+  initStatistics( statistics, bandNo, static_cast< Qgis::RasterBandStatistics>( stats ), boundingBox, binCount );
+}
 
 bool QgsRasterInterface::hasHistogram( int bandNo,
                                        int binCount,
@@ -535,7 +550,7 @@ void QgsRasterInterface::cumulativeCut( int bandNo,
   upperValue = std::numeric_limits<double>::quiet_NaN();
 
   //get band stats to specify real histogram min/max (fix #9793 Byte bands)
-  const QgsRasterBandStats stats = bandStatistics( bandNo, QgsRasterBandStats::Min, extent, sampleSize );
+  const QgsRasterBandStats stats = bandStatistics( bandNo, Qgis::RasterBandStatistic::Min, extent, sampleSize );
   if ( stats.maximumValue < stats.minimumValue )
     return;
 
@@ -586,28 +601,18 @@ QString QgsRasterInterface::capabilitiesString() const
 {
   QStringList abilitiesList;
 
-  const int abilities = capabilities();
+  const Qgis::RasterInterfaceCapabilities abilities = capabilities();
 
   // Not all all capabilities are here (Size, IdentifyValue, IdentifyText,
   // IdentifyHtml, IdentifyFeature) because those are quite technical and probably
   // would be confusing for users
 
-  if ( abilities & QgsRasterInterface::Identify )
+  if ( abilities & Qgis::RasterInterfaceCapability::Identify )
   {
     abilitiesList += tr( "Identify" );
   }
 
-  if ( abilities & QgsRasterInterface::Create )
-  {
-    abilitiesList += tr( "Create Datasources" );
-  }
-
-  if ( abilities & QgsRasterInterface::Remove )
-  {
-    abilitiesList += tr( "Remove Datasources" );
-  }
-
-  if ( abilities & QgsRasterInterface::BuildPyramids )
+  if ( abilities & Qgis::RasterInterfaceCapability::BuildPyramids )
   {
     abilitiesList += tr( "Build Pyramids" );
   }
@@ -622,7 +627,8 @@ QString QgsRasterInterface::generateBandName( int bandNumber ) const
   if ( mInput )
     return mInput->generateBandName( bandNumber );
 
-  return tr( "Band" ) + QStringLiteral( " %1" ) .arg( bandNumber, 1 + static_cast< int >( std::log10( static_cast< double >( bandCount() ) ) ), 10, QChar( '0' ) );
+  // For bad layers bandCount is 0, no log!
+  return tr( "Band" ) + QStringLiteral( " %1" ) .arg( bandNumber, 1 + ( bandCount() > 0 ? static_cast< int >( std::log10( static_cast< double >( bandCount() ) ) ) : 0 ), 10, QChar( '0' ) );
 }
 
 QString QgsRasterInterface::colorInterpretationName( int bandNo ) const
@@ -637,9 +643,24 @@ QString QgsRasterInterface::displayBandName( int bandNumber ) const
 {
   QString name = generateBandName( bandNumber );
   const QString colorInterp = colorInterpretationName( bandNumber );
-  if ( colorInterp != QLatin1String( "Undefined" ) )
+  if ( colorInterp != tr( "Undefined" ) )
   {
     name.append( QStringLiteral( " (%1)" ).arg( colorInterp ) );
   }
   return name;
 }
+
+QgsRasterBandStats QgsRasterInterface::bandStatistics( int bandNo, int stats, const QgsRectangle &extent, int sampleSize, QgsRasterBlockFeedback *feedback )
+{
+  return bandStatistics( bandNo, static_cast < Qgis::RasterBandStatistics>( stats ), extent, sampleSize, feedback );
+}
+
+QgsRenderContext QgsRasterBlockFeedback::renderContext() const
+{
+  return mRenderContext;
+}
+
+void QgsRasterBlockFeedback::setRenderContext( const QgsRenderContext &renderContext )
+{
+  mRenderContext = renderContext;
+}
