@@ -85,6 +85,34 @@ class CORE_EXPORT QgsRasterRenderer : public QgsRasterInterface
 
     bool setInput( QgsRasterInterface *input ) override;
 
+    /**
+     * Returns the input band for the renderer, or -1 if no input band is available.
+     *
+     * For renderers which utilize multiple input bands -1 will be returned. In these
+     * cases usesBands() will return a list of all utilized bands (including alpha
+     * bands).
+     *
+     * \see setInputBand()
+     * \see usesBands()
+     *
+     * \since QGIS 3.38
+     */
+    virtual int inputBand() const;
+
+    /**
+     * Attempts to set the input \a band for the renderer.
+     *
+     * Returns TRUE if the band was successfully set, or FALSE if the band could not be set.
+     *
+     * \note Not all renderers support setting the input band.
+     *
+     * \see inputBand()
+     * \see usesBands()
+     *
+     * \since QGIS 3.38
+     */
+    virtual bool setInputBand( int band );
+
     QgsRasterBlock *block( int bandNo,
                            const QgsRectangle &extent,
                            int width,
@@ -161,11 +189,14 @@ class CORE_EXPORT QgsRasterRenderer : public QgsRasterInterface
     /**
      * Copies common properties like opacity / transparency data from other renderer.
      * Useful when cloning renderers.
-     * \since QGIS 2.16
      */
     void copyCommonProperties( const QgsRasterRenderer *other, bool copyMinMaxOrigin = true );
 
-    //! Returns a list of band numbers used by the renderer
+    /**
+     * Returns a list of band numbers used by the renderer.
+     *
+     * \see setInputBand()
+     */
     virtual QList<int> usesBands() const { return QList<int>(); }
 
     //! Returns const reference to origin of min/max values
