@@ -34,59 +34,15 @@ class QgsFillSymbol;
  * \ingroup core
  * \brief The QgsScaleBarSettings class stores the appearance and layout settings
  * for scalebar drawing with QgsScaleBarRenderer.
- * \since QGIS 3.0
 */
 class CORE_EXPORT QgsScaleBarSettings
 {
   public:
 
-    /**
-     * Scalebar alignment.
-     */
-    enum Alignment
-    {
-      AlignLeft = 0, //!< Left aligned
-      AlignMiddle, //!< Center aligned
-      AlignRight, //!< Right aligned
-    };
-
-    /**
-     * Modes for setting size for scale bar segments.
-     */
-    enum SegmentSizeMode
-    {
-      SegmentSizeFixed = 0, //!< Scale bar segment size is fixed to a map unit
-      SegmentSizeFitWidth = 1 //!< Scale bar segment size is calculated to fit a size range
-    };
-
-    /**
-     * Label vertical placement.
-     */
-    enum LabelVerticalPlacement
-    {
-      LabelAboveSegment = 0, //!< Labels are drawn above the scalebar
-      LabelBelowSegment, //!< Labels are drawn below the scalebar
-    };
-
-    /**
-     * Label horizontal placement.
-     */
-    enum LabelHorizontalPlacement
-    {
-      LabelCenteredEdge = 0, //!< Labels are drawn centered relative to segment's edge
-      LabelCenteredSegment, //!< Labels are drawn centered relative to segment
-    };
-
-    /**
-     * Constructor for QgsScaleBarSettings.
-     */
     QgsScaleBarSettings();
 
     ~QgsScaleBarSettings();
 
-    /**
-     * Copy constructor
-     */
     QgsScaleBarSettings( const QgsScaleBarSettings &other );
 
     QgsScaleBarSettings &operator=( const QgsScaleBarSettings &other );
@@ -173,7 +129,7 @@ class CORE_EXPORT QgsScaleBarSettings
      * \see minimumBarWidth()
      * \see maximumBarWidth()
      */
-    SegmentSizeMode segmentSizeMode() const { return mSegmentSizeMode; }
+    Qgis::ScaleBarSegmentSizeMode segmentSizeMode() const { return mSegmentSizeMode; }
 
     /**
      * Sets the size \a mode for scale bar segments.
@@ -181,7 +137,7 @@ class CORE_EXPORT QgsScaleBarSettings
      * \see setMinimumBarWidth()
      * \see setMaximumBarWidth()
      */
-    void setSegmentSizeMode( SegmentSizeMode mode ) { mSegmentSizeMode = mode; }
+    void setSegmentSizeMode( Qgis::ScaleBarSegmentSizeMode mode ) { mSegmentSizeMode = mode; }
 
     /**
      * Returns the minimum width (in millimeters) for scale bar segments. This
@@ -283,14 +239,14 @@ class CORE_EXPORT QgsScaleBarSettings
     /**
      * Returns the font used for drawing text in the scalebar.
      * \see setFont()
-     * \deprecated use textFormat() instead
+     * \deprecated QGIS 3.40. Use textFormat() instead.
      */
     Q_DECL_DEPRECATED QFont font() const SIP_DEPRECATED { return mTextFormat.font(); }
 
     /**
      * Sets the \a font used for drawing text in the scalebar.
      * \see font()
-     * \deprecated use setTextFormat() instead
+     * \deprecated QGIS 3.40. Use setTextFormat() instead.
      */
     Q_DECL_DEPRECATED void setFont( const QFont &font ) SIP_DEPRECATED
     {
@@ -311,7 +267,7 @@ class CORE_EXPORT QgsScaleBarSettings
      * Returns the color used for drawing text in the scalebar.
      * \see setFontColor()
      * \see font()
-     * \deprecated use textFormat() instead
+     * \deprecated QGIS 3.40. Use textFormat() instead.
      */
     Q_DECL_DEPRECATED QColor fontColor() const SIP_DEPRECATED { return mTextFormat.color(); }
 
@@ -319,7 +275,7 @@ class CORE_EXPORT QgsScaleBarSettings
      * Sets the \a color used for drawing text in the scalebar.
      * \see fontColor()
      * \see setFont()
-     * \deprecated use textFormat() instead
+     * \deprecated QGIS 3.40. Use textFormat() instead.
      */
     Q_DECL_DEPRECATED void setFontColor( const QColor &color ) SIP_DEPRECATED { mTextFormat.setColor( color ); }
 
@@ -327,7 +283,7 @@ class CORE_EXPORT QgsScaleBarSettings
      * Returns the color used for fills in the scalebar.
      * \see setFillColor()
      * \see fillColor2()
-     * \deprecated use fillSymbol() instead.
+     * \deprecated QGIS 3.40. Use fillSymbol() instead.
      */
     Q_DECL_DEPRECATED QColor fillColor() const SIP_DEPRECATED;
 
@@ -335,7 +291,7 @@ class CORE_EXPORT QgsScaleBarSettings
      * Sets the \a color used for fills in the scalebar.
      * \see fillColor()
      * \see setFillColor2()
-     * \deprecated use setFillSymbol() instead.
+     * \deprecated QGIS 3.40. Use setFillSymbol() instead.
      */
     Q_DECL_DEPRECATED void setFillColor( const QColor &color ) SIP_DEPRECATED;
 
@@ -343,7 +299,7 @@ class CORE_EXPORT QgsScaleBarSettings
      * Returns the secondary color used for fills in the scalebar.
      * \see setFillColor2()
      * \see fillColor()
-     * \deprecated use alternateFillSymbol() instead
+     * \deprecated QGIS 3.40. Use alternateFillSymbol() instead.
      */
     Q_DECL_DEPRECATED QColor fillColor2() const SIP_DEPRECATED;
 
@@ -351,35 +307,35 @@ class CORE_EXPORT QgsScaleBarSettings
      * Sets the secondary \a color used for fills in the scalebar.
      * \see fillColor2()
      * \see setFillColor2()
-     * \deprecated use setAlternateFillSymbol() instead.
+     * \deprecated QGIS 3.40. Use setAlternateFillSymbol() instead.
      */
     Q_DECL_DEPRECATED void setFillColor2( const QColor &color ) SIP_DEPRECATED;
 
     /**
      * Returns the color used for lines in the scalebar.
      * \see setLineColor()
-     * \deprecated use lineSymbol() instead.
+     * \deprecated QGIS 3.40. Use lineSymbol() instead.
      */
     Q_DECL_DEPRECATED QColor lineColor() const SIP_DEPRECATED;
 
     /**
      * Sets the \a color used for lines in the scalebar.
      * \see lineColor()
-     * \deprecated use setLineSymbol() instead.
+     * \deprecated QGIS 3.40. Use setLineSymbol() instead.
      */
     Q_DECL_DEPRECATED void setLineColor( const QColor &color ) SIP_DEPRECATED;
 
     /**
      * Returns the line width in millimeters for lines in the scalebar.
      * \see setLineWidth()
-     * \deprecated use lineSymbol() instead.
+     * \deprecated QGIS 3.40. Use lineSymbol() instead.
      */
     Q_DECL_DEPRECATED double lineWidth() const SIP_DEPRECATED;
 
     /**
      * Sets the line \a width in millimeters for lines in the scalebar.
      * \see lineWidth()
-     * \deprecated use setLineSymbol() instead.
+     * \deprecated QGIS 3.40. Use setLineSymbol() instead.
      */
     Q_DECL_DEPRECATED void setLineWidth( double width ) SIP_DEPRECATED;
 
@@ -387,14 +343,14 @@ class CORE_EXPORT QgsScaleBarSettings
      * Returns the pen used for drawing outlines in the scalebar.
      * \see setPen()
      * \see brush()
-     * \deprecated use lineSymbol() instead.
+     * \deprecated QGIS 3.40. Use lineSymbol() instead.
      */
     Q_DECL_DEPRECATED QPen pen() const SIP_DEPRECATED;
 
     /**
      * Sets the pen used for drawing outlines in the scalebar.
      * \see pen()
-     * \deprecated use setLineSymbol() instead.
+     * \deprecated QGIS 3.40. Use setLineSymbol() instead.
      */
     Q_DECL_DEPRECATED void setPen( const QPen &pen ) SIP_DEPRECATED;
 
@@ -515,14 +471,14 @@ class CORE_EXPORT QgsScaleBarSettings
      * \see setBrush()
      * \see brush2()
      * \see pen()
-     * \deprecated use fillSymbol() instead
+     * \deprecated QGIS 3.40. Use fillSymbol() instead.
      */
     Q_DECL_DEPRECATED QBrush brush() const SIP_DEPRECATED;
 
     /**
      * Sets the primary brush used for filling the scalebar.
      * \see brush()
-     * \deprecated use setFillSymbol() instead
+     * \deprecated QGIS 3.40. Use setFillSymbol() instead.
      */
     Q_DECL_DEPRECATED void setBrush( const QBrush &brush ) SIP_DEPRECATED;
 
@@ -531,14 +487,14 @@ class CORE_EXPORT QgsScaleBarSettings
      * as single and double box styles.
      * \see setBrush2()
      * \see brush()
-     * \deprecated use alternateFillSymbol() instead
+     * \deprecated QGIS 3.40. Use alternateFillSymbol() instead.
      */
     Q_DECL_DEPRECATED QBrush brush2() const SIP_DEPRECATED;
 
     /**
      * Sets the secondary brush used for filling the scalebar.
      * \see brush()
-     * \deprecated use setAlternateFillSymbol() instead
+     * \deprecated QGIS 3.40. Use setAlternateFillSymbol() instead.
      */
     Q_DECL_DEPRECATED void setBrush2( const QBrush &brush ) SIP_DEPRECATED;
 
@@ -571,28 +527,28 @@ class CORE_EXPORT QgsScaleBarSettings
      * \see setLabelVerticalPlacement()
      * \since QGIS 3.10
      */
-    LabelVerticalPlacement labelVerticalPlacement() const { return mLabelVerticalPlacement; }
+    Qgis::ScaleBarDistanceLabelVerticalPlacement labelVerticalPlacement() const { return mLabelVerticalPlacement; }
 
     /**
      * Sets the vertical \a placement of text labels.
      * \see labelVerticalPlacement()
      * \since QGIS 3.10
      */
-    void setLabelVerticalPlacement( LabelVerticalPlacement placement ) { mLabelVerticalPlacement = placement; }
+    void setLabelVerticalPlacement( Qgis::ScaleBarDistanceLabelVerticalPlacement placement ) { mLabelVerticalPlacement = placement; }
 
     /**
      * Returns the horizontal placement of text labels.
      * \see setLabelHorizontalPlacement()
      * \since QGIS 3.10
      */
-    LabelHorizontalPlacement labelHorizontalPlacement() const { return mLabelHorizontalPlacement; }
+    Qgis::ScaleBarDistanceLabelHorizontalPlacement labelHorizontalPlacement() const { return mLabelHorizontalPlacement; }
 
     /**
      * Sets the horizontal \a placement of text labels.
      * \see labelHorizontalPlacement()
      * \since QGIS 3.10
      */
-    void setLabelHorizontalPlacement( LabelHorizontalPlacement placement ) { mLabelHorizontalPlacement = placement; }
+    void setLabelHorizontalPlacement( Qgis::ScaleBarDistanceLabelHorizontalPlacement placement ) { mLabelHorizontalPlacement = placement; }
 
     /**
      * Returns the spacing (margin) between the scalebar box and content in millimeters.
@@ -610,39 +566,39 @@ class CORE_EXPORT QgsScaleBarSettings
      * Returns the scalebar alignment.
      * \see setAlignment()
      */
-    Alignment alignment() const { return mAlignment; }
+    Qgis::ScaleBarAlignment alignment() const { return mAlignment; }
 
     /**
      * Sets the scalebar \a alignment.
      * \see alignment()
      */
-    void setAlignment( Alignment alignment ) { mAlignment = alignment; }
+    void setAlignment( Qgis::ScaleBarAlignment alignment ) { mAlignment = alignment; }
 
     /**
      * Returns the join style used for drawing lines in the scalebar.
      * \see setLineJoinStyle()
-     * \deprecated use lineSymbol() instead
+     * \deprecated QGIS 3.40. Use lineSymbol() instead.
      */
     Q_DECL_DEPRECATED Qt::PenJoinStyle lineJoinStyle() const SIP_DEPRECATED;
 
     /**
      * Sets the join \a style used when drawing the lines in the scalebar
      * \see lineJoinStyle()
-     * \deprecated use setLineSymbol() instead
+     * \deprecated QGIS 3.40. Use setLineSymbol() instead.
      */
     Q_DECL_DEPRECATED void setLineJoinStyle( Qt::PenJoinStyle style ) SIP_DEPRECATED;
 
     /**
      * Returns the cap style used for drawing lines in the scalebar.
      * \see setLineCapStyle()
-     * \deprecated use lineSymbol() instead
+     * \deprecated QGIS 3.40. Use lineSymbol() instead.
      */
     Q_DECL_DEPRECATED Qt::PenCapStyle lineCapStyle() const SIP_DEPRECATED;
 
     /**
      * Sets the cap \a style used when drawing the lines in the scalebar.
      * \see lineCapStyle()
-     * \deprecated use setLineSymbol() instead
+     * \deprecated QGIS 3.40. Use setLineSymbol() instead.
      */
     Q_DECL_DEPRECATED void setLineCapStyle( Qt::PenCapStyle style ) SIP_DEPRECATED;
 
@@ -679,7 +635,7 @@ class CORE_EXPORT QgsScaleBarSettings
     //! Number of map units per scale bar units (e.g. 1000 to have km for a map with m units)
     double mNumMapUnitsPerScaleBarUnit = 1.0;
     //! Either fixed (i.e. mNumUnitsPerSegment) or try to best fit scale bar width (mMinBarWidth, mMaxBarWidth)
-    SegmentSizeMode mSegmentSizeMode = SegmentSizeFixed;
+    Qgis::ScaleBarSegmentSizeMode mSegmentSizeMode = Qgis::ScaleBarSegmentSizeMode::Fixed;
     //! Minimum allowed bar width, when mSegmentSizeMode is FitWidth
     double mMinBarWidth = 50.0;
     //! Maximum allowed bar width, when mSegmentSizeMode is FitWidth
@@ -703,18 +659,17 @@ class CORE_EXPORT QgsScaleBarSettings
     //! Space between bar and Text labels
     double mLabelBarSpace = 3.0;
     //! Label's vertical placement
-    LabelVerticalPlacement mLabelVerticalPlacement = LabelAboveSegment;
+    Qgis::ScaleBarDistanceLabelVerticalPlacement mLabelVerticalPlacement = Qgis::ScaleBarDistanceLabelVerticalPlacement::AboveSegment;
     //! Label's horizontal placement
-    LabelHorizontalPlacement mLabelHorizontalPlacement = LabelCenteredEdge;
+    Qgis::ScaleBarDistanceLabelHorizontalPlacement mLabelHorizontalPlacement = Qgis::ScaleBarDistanceLabelHorizontalPlacement::CenteredEdge;
 
     //! Space between content and item box
     double mBoxContentSpace = 1.0;
 
-    Alignment mAlignment = AlignLeft;
+    Qgis::ScaleBarAlignment mAlignment = Qgis::ScaleBarAlignment::Left;
 
     Qgis::DistanceUnit mUnits = Qgis::DistanceUnit::Meters;
 
-
     std::unique_ptr< QgsNumericFormat > mNumericFormat;
 
 };
