@@ -65,19 +65,19 @@ enum BasicType
   btHresult = 31,
 };
 
-#define WIDEN_(x) L ## x
-#define WIDEN(x) WIDEN_(x)
+#define WIDEN_( x ) L##x
+#define WIDEN( x ) WIDEN_( x )
 
 typedef struct _StackTrace
 {
-  wchar_t message[2 * 1024 * 1024];
-  int written;
-  HANDLE process;
-  HANDLE thread;
-  PCONTEXT contextRecord;
-  STACKFRAME64 currentStackFrame;
-  bool isFirstParameter;
-  LPVOID scratchSpace;
+    wchar_t message[2 * 1024 * 1024];
+    int written;
+    HANDLE process;
+    HANDLE thread;
+    PCONTEXT contextRecord;
+    STACKFRAME64 currentStackFrame;
+    bool isFirstParameter;
+    LPVOID scratchSpace;
 } StackTrace;
 
 bool printBasicType( StackTrace *stackTrace, PSYMBOL_INFOW pSymInfo, ULONG typeIndex, void *valueLocation, bool whilePrintingPointer )
@@ -97,13 +97,11 @@ bool printBasicType( StackTrace *stackTrace, PSYMBOL_INFOW pSymInfo, ULONG typeI
         char value;
         ReadProcessMemory( stackTrace->process, valueLocation, &value, sizeof( value ), NULL );
 
-        stackTrace->written +=
-          swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                      L"'%c'", value );
+        stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"'%c'", value );
       }
       else
       {
-        char *value = ( char * )valueLocation;
+        char *value = ( char * ) valueLocation;
 
         MEMORY_BASIC_INFORMATION pageInfo = { 0 };
         if ( VirtualQueryEx( stackTrace->process, value, &pageInfo, sizeof( pageInfo ) ) == 0 )
@@ -111,15 +109,13 @@ bool printBasicType( StackTrace *stackTrace, PSYMBOL_INFOW pSymInfo, ULONG typeI
           return false;
         }
 
-        PVOID pageEndAddress = ( char * )pageInfo.BaseAddress + pageInfo.RegionSize;
+        PVOID pageEndAddress = ( char * ) pageInfo.BaseAddress + pageInfo.RegionSize;
 
-        stackTrace->written +=
-          swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                      L"\"" );
+        stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"\"" );
 
         for ( int charsWritten = 0; charsWritten < 100; )
         {
-          if ( ( void * )value < pageEndAddress )
+          if ( ( void * ) value < pageEndAddress )
           {
             char next;
             ReadProcessMemory( stackTrace->process, value, &next, sizeof( next ), NULL );
@@ -128,16 +124,12 @@ bool printBasicType( StackTrace *stackTrace, PSYMBOL_INFOW pSymInfo, ULONG typeI
             {
               if ( charsWritten == 100 - 1 )
               {
-                stackTrace->written +=
-                  swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                              L"..." );
+                stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"..." );
                 break;
               }
               else
               {
-                stackTrace->written +=
-                  swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                              L"%c", next );
+                stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"%c", next );
                 charsWritten++;
                 value++;
               }
@@ -151,19 +143,15 @@ bool printBasicType( StackTrace *stackTrace, PSYMBOL_INFOW pSymInfo, ULONG typeI
           {
             if ( VirtualQueryEx( stackTrace->process, pageEndAddress, &pageInfo, sizeof( pageInfo ) ) == 0 )
             {
-              stackTrace->written +=
-                swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                            L"<Bad memory>" );
+              stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"<Bad memory>" );
               break;
             }
 
-            pageEndAddress = ( char * )pageInfo.BaseAddress + pageInfo.RegionSize;
+            pageEndAddress = ( char * ) pageInfo.BaseAddress + pageInfo.RegionSize;
           }
         }
 
-        stackTrace->written +=
-          swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                      L"\"" );
+        stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"\"" );
       }
 
       break;
@@ -176,13 +164,11 @@ bool printBasicType( StackTrace *stackTrace, PSYMBOL_INFOW pSymInfo, ULONG typeI
         wchar_t value;
         ReadProcessMemory( stackTrace->process, valueLocation, &value, sizeof( value ), NULL );
 
-        stackTrace->written +=
-          swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                      L"'%lc'", value );
+        stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"'%lc'", value );
       }
       else
       {
-        wchar_t *value = ( wchar_t * )valueLocation;
+        wchar_t *value = ( wchar_t * ) valueLocation;
 
         MEMORY_BASIC_INFORMATION pageInfo = { 0 };
         if ( VirtualQueryEx( stackTrace->process, value, &pageInfo, sizeof( pageInfo ) ) == 0 )
@@ -190,15 +176,13 @@ bool printBasicType( StackTrace *stackTrace, PSYMBOL_INFOW pSymInfo, ULONG typeI
           return false;
         }
 
-        PVOID pageEndAddress = ( char * )pageInfo.BaseAddress + pageInfo.RegionSize;
+        PVOID pageEndAddress = ( char * ) pageInfo.BaseAddress + pageInfo.RegionSize;
 
-        stackTrace->written +=
-          swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                      L"L\"" );
+        stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"L\"" );
 
         for ( int charsWritten = 0; charsWritten < 100; )
         {
-          if ( ( void * )( ( char * )value + 1 ) < pageEndAddress )
+          if ( ( void * ) ( ( char * ) value + 1 ) < pageEndAddress )
           {
             wchar_t next;
             ReadProcessMemory( stackTrace->process, value, &next, sizeof( next ), NULL );
@@ -207,16 +191,12 @@ bool printBasicType( StackTrace *stackTrace, PSYMBOL_INFOW pSymInfo, ULONG typeI
             {
               if ( charsWritten == 100 - 1 )
               {
-                stackTrace->written +=
-                  swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                              L"..." );
+                stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"..." );
                 break;
               }
               else
               {
-                stackTrace->written +=
-                  swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                              L"%lc", next );
+                stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"%lc", next );
                 charsWritten++;
                 value++;
               }
@@ -230,19 +210,15 @@ bool printBasicType( StackTrace *stackTrace, PSYMBOL_INFOW pSymInfo, ULONG typeI
           {
             if ( VirtualQueryEx( stackTrace->process, pageEndAddress, &pageInfo, sizeof( pageInfo ) ) == 0 )
             {
-              stackTrace->written +=
-                swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                            L"<Bad memory>" );
+              stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"<Bad memory>" );
               break;
             }
 
-            pageEndAddress = ( char * )pageInfo.BaseAddress + pageInfo.RegionSize;
+            pageEndAddress = ( char * ) pageInfo.BaseAddress + pageInfo.RegionSize;
           }
         }
 
-        stackTrace->written +=
-          swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                      L"\"" );
+        stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"\"" );
       }
 
       break;
@@ -258,47 +234,39 @@ bool printBasicType( StackTrace *stackTrace, PSYMBOL_INFOW pSymInfo, ULONG typeI
 
       switch ( length )
       {
-        case sizeof( int8_t ) :
+        case sizeof( int8_t ):
         {
           int8_t value;
           ReadProcessMemory( stackTrace->process, valueLocation, &value, sizeof( value ), NULL );
 
-          stackTrace->written +=
-            swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                        L"%" WIDEN( PRId8 ), value );
+          stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"%" WIDEN( PRId8 ), value );
           break;
         }
 
-        case sizeof( int16_t ) :
+        case sizeof( int16_t ):
         {
           int16_t value;
           ReadProcessMemory( stackTrace->process, valueLocation, &value, sizeof( value ), NULL );
 
-          stackTrace->written +=
-            swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                        L"%" WIDEN( PRId16 ), value );
+          stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"%" WIDEN( PRId16 ), value );
           break;
         }
 
-        case sizeof( int32_t ) :
+        case sizeof( int32_t ):
         {
           int32_t value;
           ReadProcessMemory( stackTrace->process, valueLocation, &value, sizeof( value ), NULL );
 
-          stackTrace->written +=
-            swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                        L"%" WIDEN( PRId32 ), value );
+          stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"%" WIDEN( PRId32 ), value );
           break;
         }
 
-        case sizeof( int64_t ) :
+        case sizeof( int64_t ):
         {
           int64_t value;
           ReadProcessMemory( stackTrace->process, valueLocation, &value, sizeof( value ), NULL );
 
-          stackTrace->written +=
-            swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                        L"%" WIDEN( PRId64 ), value );
+          stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"%" WIDEN( PRId64 ), value );
           break;
         }
 
@@ -322,47 +290,39 @@ bool printBasicType( StackTrace *stackTrace, PSYMBOL_INFOW pSymInfo, ULONG typeI
 
       switch ( length )
       {
-        case sizeof( uint8_t ) :
+        case sizeof( uint8_t ):
         {
           uint8_t value;
           ReadProcessMemory( stackTrace->process, valueLocation, &value, sizeof( value ), NULL );
 
-          stackTrace->written +=
-            swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                        L"%" WIDEN( PRIu8 ), value );
+          stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"%" WIDEN( PRIu8 ), value );
           break;
         }
 
-        case sizeof( uint16_t ) :
+        case sizeof( uint16_t ):
         {
           uint16_t value;
           ReadProcessMemory( stackTrace->process, valueLocation, &value, sizeof( value ), NULL );
 
-          stackTrace->written +=
-            swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                        L"%" WIDEN( PRIu16 ), value );
+          stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"%" WIDEN( PRIu16 ), value );
           break;
         }
 
-        case sizeof( uint32_t ) :
+        case sizeof( uint32_t ):
         {
           uint32_t value;
           ReadProcessMemory( stackTrace->process, valueLocation, &value, sizeof( value ), NULL );
 
-          stackTrace->written +=
-            swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                        L"%" WIDEN( PRIu32 ), value );
+          stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"%" WIDEN( PRIu32 ), value );
           break;
         }
 
-        case sizeof( uint64_t ) :
+        case sizeof( uint64_t ):
         {
           uint64_t value;
           ReadProcessMemory( stackTrace->process, valueLocation, &value, sizeof( value ), NULL );
 
-          stackTrace->written +=
-            swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                        L"%" WIDEN( PRIu64 ), value );
+          stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"%" WIDEN( PRIu64 ), value );
           break;
         }
 
@@ -381,9 +341,7 @@ bool printBasicType( StackTrace *stackTrace, PSYMBOL_INFOW pSymInfo, ULONG typeI
       float value;
       ReadProcessMemory( stackTrace->process, valueLocation, &value, sizeof( value ), NULL );
 
-      stackTrace->written +=
-        swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                    L"%f", value );
+      stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"%f", value );
       break;
     }
 
@@ -392,9 +350,7 @@ bool printBasicType( StackTrace *stackTrace, PSYMBOL_INFOW pSymInfo, ULONG typeI
       long value;
       ReadProcessMemory( stackTrace->process, valueLocation, &value, sizeof( value ), NULL );
 
-      stackTrace->written +=
-        swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                    L"%ld", value );
+      stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"%ld", value );
       break;
     }
 
@@ -403,9 +359,7 @@ bool printBasicType( StackTrace *stackTrace, PSYMBOL_INFOW pSymInfo, ULONG typeI
       unsigned long value;
       ReadProcessMemory( stackTrace->process, valueLocation, &value, sizeof( value ), NULL );
 
-      stackTrace->written +=
-        swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                    L"%lu", value );
+      stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"%lu", value );
       break;
     }
 
@@ -439,15 +393,11 @@ bool printGivenType( StackTrace *stackTrace, PSYMBOL_INFOW pSymInfo, enum SymTag
       ReadProcessMemory( stackTrace->process, valueLocation, &pointedValueLocation, sizeof( pointedValueLocation ), NULL );
 
 
-      stackTrace->written +=
-        swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                    L"0x%p -> ", pointedValueLocation );
+      stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"0x%p -> ", pointedValueLocation );
 
-      if ( pointedValueLocation < ( void * )0x1000 )
+      if ( pointedValueLocation < ( void * ) 0x1000 )
       {
-        stackTrace->written +=
-          swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                      L"?" );
+        stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"?" );
         break;
       }
 
@@ -471,9 +421,9 @@ bool printGivenType( StackTrace *stackTrace, PSYMBOL_INFOW pSymInfo, enum SymTag
 
       for ( ;; )
       {
-        PVOID pageEndAddress = ( char * )pageInfo.BaseAddress + pageInfo.RegionSize;
+        PVOID pageEndAddress = ( char * ) pageInfo.BaseAddress + pageInfo.RegionSize;
 
-        if ( ( void * )( ( char * )pointedValueLocation + pointedTypeLength ) >= pageEndAddress )
+        if ( ( void * ) ( ( char * ) pointedValueLocation + pointedTypeLength ) >= pageEndAddress )
         {
           if ( VirtualQueryEx( stackTrace->process, pageEndAddress, &pageInfo, sizeof( pageInfo ) ) == 0 )
           {
@@ -519,44 +469,35 @@ bool printType( StackTrace *stackTrace, PSYMBOL_INFOW pSymInfo, void *valueLocat
 BOOL CALLBACK enumParams(
   _In_ PSYMBOL_INFOW pSymInfo,
   _In_ ULONG SymbolSize,
-  _In_opt_ PVOID UserContext )
+  _In_opt_ PVOID UserContext
+)
 {
   if ( ( pSymInfo->Flags & SYMFLAG_LOCAL ) == 0 )
   {
     return TRUE;
   }
 
-  StackTrace *stackTrace = ( StackTrace * )UserContext;
+  StackTrace *stackTrace = ( StackTrace * ) UserContext;
 
-  stackTrace->written +=
-    swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                L"\n" );
+  stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"\n" );
 
   if ( pSymInfo->Flags & SYMFLAG_PARAMETER )
   {
-    stackTrace->written +=
-      swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                  L"Parm: " );
+    stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"Parm: " );
   }
   else if ( pSymInfo->Flags & SYMFLAG_LOCAL )
   {
-    stackTrace->written +=
-      swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                  L"Local: " );
+    stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"Local: " );
   }
 
-  stackTrace->written +=
-    swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                L"%ls = ", pSymInfo->Name );
+  stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"%ls = ", pSymInfo->Name );
 
   void *valueLocation = NULL;
   if ( pSymInfo->Flags & SYMFLAG_REGISTER )
   {
     if ( stackTrace->scratchSpace == NULL )
     {
-      stackTrace->written +=
-        swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                    L"<Could not allocate memory to write register value>" );
+      stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"<Could not allocate memory to write register value>" );
       return TRUE;
     }
 
@@ -620,18 +561,16 @@ BOOL CALLBACK enumParams(
 #endif
 
       default:
-        stackTrace->written +=
-          swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                      L"<Unknown register %lu>", pSymInfo->Register );
+        stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"<Unknown register %lu>", pSymInfo->Register );
         return TRUE;
     }
   }
   else if ( pSymInfo->Flags & SYMFLAG_LOCAL )
   {
 #ifndef _WIN64
-    valueLocation = ( ( char * )stackTrace->contextRecord->Ebp ) + pSymInfo->Address;
+    valueLocation = ( ( char * ) stackTrace->contextRecord->Ebp ) + pSymInfo->Address;
 #else
-    valueLocation = ( ( char * )stackTrace->contextRecord->Rbp ) + pSymInfo->Address;
+    valueLocation = ( ( char * ) stackTrace->contextRecord->Rbp ) + pSymInfo->Address;
 #endif
   }
   else if ( pSymInfo->Flags & SYMFLAG_REGREL )
@@ -640,34 +579,30 @@ BOOL CALLBACK enumParams(
     {
 #ifndef _WIN64
       case 22:
-        valueLocation = ( ( char * )stackTrace->contextRecord->Ebp ) + pSymInfo->Address;
+        valueLocation = ( ( char * ) stackTrace->contextRecord->Ebp ) + pSymInfo->Address;
         break;
 #else
       case 334:
-        valueLocation = ( ( char * )stackTrace->contextRecord->Rbp ) + pSymInfo->Address;
+        valueLocation = ( ( char * ) stackTrace->contextRecord->Rbp ) + pSymInfo->Address;
         break;
       case 335:
-        valueLocation = ( ( char * )stackTrace->contextRecord->Rsp ) + 0x20 + pSymInfo->Address;
+        valueLocation = ( ( char * ) stackTrace->contextRecord->Rsp ) + 0x20 + pSymInfo->Address;
         break;
 #endif
 
       default:
-        stackTrace->written +=
-          swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                      L"<Relative to unknown register %lu>", pSymInfo->Register );
+        stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"<Relative to unknown register %lu>", pSymInfo->Register );
         return TRUE;
     }
   }
   else
   {
-    valueLocation = ( void * )( stackTrace->currentStackFrame.AddrFrame.Offset + pSymInfo->Address );
+    valueLocation = ( void * ) ( stackTrace->currentStackFrame.AddrFrame.Offset + pSymInfo->Address );
   }
 
   if ( !printType( stackTrace, pSymInfo, valueLocation ) )
   {
-    stackTrace->written +=
-      swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                  L"?" );
+    stackTrace->written += swprintf_s( stackTrace->message + stackTrace->written, sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"?" );
   }
 
   return TRUE;
@@ -680,8 +615,7 @@ void GetLastErrorAsString()
   DWORD errorMessageID = ::GetLastError();
 
   LPSTR messageBuffer = nullptr;
-  size_t size = FormatMessageA( FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS,
-                                NULL, errorMessageID, MAKELANGID( LANG_NEUTRAL, SUBLANG_DEFAULT ), ( LPSTR )&messageBuffer, 0, NULL );
+  size_t size = FormatMessageA( FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS, NULL, errorMessageID, MAKELANGID( LANG_NEUTRAL, SUBLANG_DEFAULT ), ( LPSTR ) &messageBuffer, 0, NULL );
 
   std::string message( messageBuffer, size );
 
@@ -701,7 +635,7 @@ void getStackTrace( StackTrace *stackTrace, QString symbolPath, QgsStackTrace *t
   }
   trace->symbolsLoaded = true;
 
-  SYMBOL_INFOW *symbol = ( SYMBOL_INFOW * )calloc( sizeof( *symbol ) + 256 * sizeof( wchar_t ), 1 );
+  SYMBOL_INFOW *symbol = ( SYMBOL_INFOW * ) calloc( sizeof( *symbol ) + 256 * sizeof( wchar_t ), 1 );
   symbol->MaxNameLen = 255;
   symbol->SizeOfStruct = sizeof( SYMBOL_INFOW );
 
@@ -711,17 +645,9 @@ void getStackTrace( StackTrace *stackTrace, QString symbolPath, QgsStackTrace *t
   DWORD machineType = IMAGE_FILE_MACHINE_AMD64;
 #endif
 
-  for ( int i = 0; ; i++ )
+  for ( int i = 0;; i++ )
   {
-    if ( !StackWalk64( machineType,
-                       stackTrace->process,
-                       stackTrace->thread,
-                       &stackTrace->currentStackFrame,
-                       stackTrace->contextRecord,
-                       NULL,
-                       SymFunctionTableAccess64,
-                       SymGetModuleBase64,
-                       NULL ) )
+    if ( !StackWalk64( machineType, stackTrace->process, stackTrace->thread, &stackTrace->currentStackFrame, stackTrace->contextRecord, NULL, SymFunctionTableAccess64, SymGetModuleBase64, NULL ) )
     {
       break;
     }
@@ -731,9 +657,7 @@ void getStackTrace( StackTrace *stackTrace, QString symbolPath, QgsStackTrace *t
       QgsStackTrace::StackLine stackline;
       stackline.symbolName = QString::fromWCharArray( symbol->Name );
 
-      stackTrace->written +=
-        swprintf_s( &stackTrace->message[stackTrace->written], sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written - 1,
-                    L">%02i: 0x%08llX %ls", i, symbol->Address, symbol->Name );
+      stackTrace->written += swprintf_s( &stackTrace->message[stackTrace->written], sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written - 1, L">%02i: 0x%08llX %ls", i, symbol->Address, symbol->Name );
 
       IMAGEHLP_STACK_FRAME stackFrame = { 0 };
       stackFrame.InstructionOffset = symbol->Address;
@@ -751,22 +675,16 @@ void getStackTrace( StackTrace *stackTrace, QString symbolPath, QgsStackTrace *t
         stackline.fileName = QString::fromWCharArray( lineInfo.FileName );
         stackline.lineNumber = QString::number( lineInfo.LineNumber );
 
-        stackTrace->written +=
-          swprintf_s( &stackTrace->message[stackTrace->written], sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                      L"\nSource: %ls:%lu", lineInfo.FileName, lineInfo.LineNumber );
+        stackTrace->written += swprintf_s( &stackTrace->message[stackTrace->written], sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"\nSource: %ls:%lu", lineInfo.FileName, lineInfo.LineNumber );
       }
 
-      stackTrace->written +=
-        swprintf_s( &stackTrace->message[stackTrace->written], sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                    L"\n" );
+      stackTrace->written += swprintf_s( &stackTrace->message[stackTrace->written], sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L"\n" );
 
       trace->lines.append( stackline );
     }
     else
     {
-      stackTrace->written +=
-        swprintf_s( &stackTrace->message[stackTrace->written], sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written,
-                    L">%02i: 0x%08llX ?\n", i, stackTrace->currentStackFrame.AddrPC.Offset );
+      stackTrace->written += swprintf_s( &stackTrace->message[stackTrace->written], sizeof( stackTrace->message ) / sizeof( stackTrace->message[0] ) - stackTrace->written, L">%02i: 0x%08llX ?\n", i, stackTrace->currentStackFrame.AddrPC.Offset );
     }
   }
 
@@ -781,7 +699,7 @@ QgsStackTrace *QgsStackTrace::trace( DWORD processId, DWORD threadId, LPEXCEPTIO
   EXCEPTION_POINTERS remoteException = { 0 };
   CONTEXT remoteContextRecord = { 0 };
 
-  StackTrace *stackTrace = ( StackTrace * )calloc( sizeof( *stackTrace ), 1 );
+  StackTrace *stackTrace = ( StackTrace * ) calloc( sizeof( *stackTrace ), 1 );
   stackTrace->process = OpenProcess( PROCESS_ALL_ACCESS, FALSE, processId );
   stackTrace->thread = OpenThread( THREAD_ALL_ACCESS, FALSE, threadId );
   trace->process = stackTrace->process;
@@ -796,8 +714,7 @@ QgsStackTrace *QgsStackTrace::trace( DWORD processId, DWORD threadId, LPEXCEPTIO
     {
       do
       {
-        if ( te.dwSize >= FIELD_OFFSET( THREADENTRY32, th32OwnerProcessID ) +
-             sizeof( te.th32OwnerProcessID ) )
+        if ( te.dwSize >= FIELD_OFFSET( THREADENTRY32, th32OwnerProcessID ) + sizeof( te.th32OwnerProcessID ) )
         {
           if ( te.th32OwnerProcessID == processId )
           {
@@ -807,8 +724,7 @@ QgsStackTrace *QgsStackTrace::trace( DWORD processId, DWORD threadId, LPEXCEPTIO
           }
         }
         te.dwSize = sizeof( te );
-      }
-      while ( Thread32Next( h, &te ) );
+      } while ( Thread32Next( h, &te ) );
     }
     CloseHandle( h );
   }
@@ -866,10 +782,7 @@ bool QgsStackTrace::StackLine::isQgisModule() const
 
 bool QgsStackTrace::StackLine::isValid() const
 {
-  return !( fileName.contains( QLatin1String( "exe_common" ), Qt::CaseInsensitive ) ||
-            fileName.contains( QLatin1String( "unknown" ), Qt::CaseInsensitive ) ||
-            lineNumber.contains( QLatin1String( "unknown" ), Qt::CaseInsensitive ) );
-
+  return !( fileName.contains( QLatin1String( "exe_common" ), Qt::CaseInsensitive ) || fileName.contains( QLatin1String( "unknown" ), Qt::CaseInsensitive ) || lineNumber.contains( QLatin1String( "unknown" ), Qt::CaseInsensitive ) );
 }
 
 ///@endcond
