@@ -35,7 +35,6 @@ class GUI_EXPORT QgsAuthSslErrorsDialog : public QDialog, private Ui::QgsAuthSsl
 {
     Q_OBJECT
   public:
-
     /**
      * Construct a dialog to handle SSL errors and saving SSL server certificate exceptions
      * \param reply Network reply that hand error(s)
@@ -44,11 +43,7 @@ class GUI_EXPORT QgsAuthSslErrorsDialog : public QDialog, private Ui::QgsAuthSsl
      * \param digest SHA digest of server certificate
      * \param hostport Unique host:port to associate with the server certificate
      */
-    QgsAuthSslErrorsDialog( QNetworkReply *reply,
-                            const QList<QSslError> &sslErrors,
-                            QWidget *parent SIP_TRANSFERTHIS = nullptr,
-                            const QString &digest = QString(),
-                            const QString &hostport = QString() );
+    QgsAuthSslErrorsDialog( QNetworkReply *reply, const QList<QSslError> &sslErrors, QWidget *parent SIP_TRANSFERTHIS = nullptr, const QString &digest = QString(), const QString &hostport = QString() );
 
   private slots:
     void loadUnloadCertificate( bool load );
