@@ -29,29 +29,21 @@ class QgsMessageBar;
  * \brief Wraps a relation reference widget.
  *
  * Options:
- * <ul>
- * <li><b>ShowForm</b> <i>If TRUE, an embedded form with the referenced feature will be shown.</i></li>
- * <li><b>MapIdentification</b> <i>Will offer a map tool to pick a referenced feature on the map canvas. Only use for layers with geometry.</i></li>
- * <li><b>ReadOnly</b> <i>If TRUE, will represent the referenced widget in a read-only line edit. Can speed up loading.</i></li>
- * <li><b>AllowNULL</b> <i>Will offer NULL as a value.</i></li>
- * <li><b>Relation</b> <i>The ID of the relation that will be used to define this widget.</i></li>
- * ReadOnly
- * </ul>
+ *
+ * - **ShowForm** If TRUE, an embedded form with the referenced feature will be shown.
+ * - **MapIdentification** Will offer a map tool to pick a referenced feature on the map canvas. Only use for layers with geometry.
+ * - **ReadOnly** If TRUE, will represent the referenced widget in a read-only line edit. Can speed up loading.
+ * - **AllowNULL** Will offer NULL as a value.
+ * - **Relation** The ID of the relation that will be used to define this widget.
+ * - **ReadOnly**
  *
  */
-
 class GUI_EXPORT QgsRelationReferenceWidgetWrapper : public QgsEditorWidgetWrapper
 {
     Q_OBJECT
   public:
-
     //! Constructor for QgsRelationReferenceWidgetWrapper
-    explicit QgsRelationReferenceWidgetWrapper( QgsVectorLayer *vl,
-        int fieldIdx,
-        QWidget *editor,
-        QgsMapCanvas *canvas,
-        QgsMessageBar *messageBar,
-        QWidget *parent SIP_TRANSFERTHIS = nullptr );
+    explicit QgsRelationReferenceWidgetWrapper( QgsVectorLayer *vl, int fieldIdx, QWidget *editor, QgsMapCanvas *canvas, QgsMessageBar *messageBar, QWidget *parent SIP_TRANSFERTHIS = nullptr );
 
     QWidget *createWidget( QWidget *parent ) override;
     void initWidget( QWidget *editor ) override;
@@ -64,13 +56,26 @@ class GUI_EXPORT QgsRelationReferenceWidgetWrapper : public QgsEditorWidgetWrapp
   public slots:
     void setEnabled( bool enabled ) override;
 
+    void parentFormValueChanged( const QString &attribute, const QVariant &value ) override;
+
   private slots:
     void foreignKeysChanged( const QVariantList &values );
 
   protected:
     void updateConstraintWidgetStatus() override;
 
+    /**
+     * Will be called when a value in the current edited form or table row changes
+     *
+     * \param attribute The name of the attribute that changed.
+     * \param newValue     The new value of the attribute.
+     * \param attributeChanged If TRUE, it corresponds to an actual change of the feature attribute
+     * \since QGIS 3.42.2
+     */
+    void widgetValueChanged( const QString &attribute, const QVariant &newValue, bool attributeChanged );
+
   private:
+    void aboutToSave() override;
     void updateValues( const QVariant &val, const QVariantList &additionalValues = QVariantList() ) override;
 
     QString mExpression;
@@ -80,7 +85,6 @@ class GUI_EXPORT QgsRelationReferenceWidgetWrapper : public QgsEditorWidgetWrapp
     QgsMessageBar *mMessageBar = nullptr;
     bool mIndeterminateState;
     int mBlockChanges = 0;
-
 };
 
 #endif // QGSRELATIONREFERENCEWIDGETWRAPPER_H
