@@ -13,6 +13,7 @@
  *                                                                         *
  ***************************************************************************/
 #include "qgslabelengineconfigdialog.h"
+#include "moc_qgslabelengineconfigdialog.cpp"
 
 #include "qgslabelingenginesettings.h"
 #include "qgsproject.h"
@@ -38,21 +39,21 @@ QgsLabelEngineConfigWidget::QgsLabelEngineConfigWidget( QgsMapCanvas *canvas, QW
 
   mMessageBar = new QgsMessageBar();
   mMessageBar->setSizePolicy( QSizePolicy::Minimum, QSizePolicy::Fixed );
-  verticalLayout->insertWidget( 0,  mMessageBar );
+  verticalLayout->insertWidget( 0, mMessageBar );
 
   const QgsLabelingEngineSettings engineSettings = QgsProject::instance()->labelingEngineSettings();
 
-  mTextRenderFormatComboBox->addItem( tr( "Always Render Labels as Paths (Recommended)" ), static_cast< int >( Qgis::TextRenderFormat::AlwaysOutlines ) );
-  mTextRenderFormatComboBox->addItem( tr( "Always Render Labels as Text" ), static_cast< int >( Qgis::TextRenderFormat::AlwaysText ) );
+  mTextRenderFormatComboBox->addItem( tr( "Always Render Labels as Paths (Recommended)" ), QVariant::fromValue( Qgis::TextRenderFormat::AlwaysOutlines ) );
+  mTextRenderFormatComboBox->addItem( tr( "Always Render Labels as Text" ), QVariant::fromValue( Qgis::TextRenderFormat::AlwaysText ) );
+  mTextRenderFormatComboBox->addItem( tr( "Prefer Rendering Labels as Text" ), QVariant::fromValue( Qgis::TextRenderFormat::PreferText ) );
 
-  mPlacementVersionComboBox->addItem( tr( "Version 1" ), static_cast< int >( Qgis::LabelPlacementEngineVersion::Version1 ) );
-  mPlacementVersionComboBox->addItem( tr( "Version 2 (Recommended)" ), static_cast< int >( Qgis::LabelPlacementEngineVersion::Version2 ) );
+  mPlacementVersionComboBox->addItem( tr( "Version 1" ), static_cast<int>( Qgis::LabelPlacementEngineVersion::Version1 ) );
+  mPlacementVersionComboBox->addItem( tr( "Version 2 (Recommended)" ), static_cast<int>( Qgis::LabelPlacementEngineVersion::Version2 ) );
 
   mPreviousEngineVersion = engineSettings.placementVersion();
-  mPlacementVersionComboBox->setCurrentIndex( mPlacementVersionComboBox->findData( static_cast< int >( mPreviousEngineVersion ) ) );
-  connect( mPlacementVersionComboBox, &QComboBox::currentTextChanged, this, [ = ]()
-  {
-    if ( static_cast< Qgis::LabelPlacementEngineVersion >( mPlacementVersionComboBox->currentData().toInt() ) != mPreviousEngineVersion )
+  mPlacementVersionComboBox->setCurrentIndex( mPlacementVersionComboBox->findData( static_cast<int>( mPreviousEngineVersion ) ) );
+  connect( mPlacementVersionComboBox, &QComboBox::currentTextChanged, this, [=]() {
+    if ( static_cast<Qgis::LabelPlacementEngineVersion>( mPlacementVersionComboBox->currentData().toInt() ) != mPreviousEngineVersion )
     {
       mMessageBar->pushMessage( QString(), tr( "Version changes will alter label placement in the project." ), Qgis::MessageLevel::Warning );
     }
@@ -76,7 +77,7 @@ QgsLabelEngineConfigWidget::QgsLabelEngineConfigWidget( QgsMapCanvas *canvas, QW
   mUnplacedColorButton->setDefaultColor( QColor( 255, 0, 0 ) );
   mUnplacedColorButton->setWindowTitle( tr( "Unplaced Label Color" ) );
 
-  mTextRenderFormatComboBox->setCurrentIndex( mTextRenderFormatComboBox->findData( static_cast< int >( engineSettings.defaultTextRenderFormat() ) ) );
+  mTextRenderFormatComboBox->setCurrentIndex( mTextRenderFormatComboBox->findData( QVariant::fromValue( engineSettings.defaultTextRenderFormat() ) ) );
 
   connect( spinCandLine, qOverload<double>( &QgsDoubleSpinBox::valueChanged ), this, &QgsLabelEngineConfigWidget::widgetChanged );
   connect( spinCandPolygon, qOverload<double>( &QgsDoubleSpinBox::valueChanged ), this, &QgsLabelEngineConfigWidget::widgetChanged );
@@ -110,7 +111,7 @@ QString QgsLabelEngineConfigWidget::menuButtonTooltip() const
 
 void QgsLabelEngineConfigWidget::apply()
 {
-  QgsLabelingEngineSettings engineSettings;
+  QgsLabelingEngineSettings engineSettings = QgsProject::instance()->labelingEngineSettings();
 
   // save
   engineSettings.setMaximumLineCandidatesPerCm( spinCandLine->value() );
@@ -122,11 +123,11 @@ void QgsLabelEngineConfigWidget::apply()
   engineSettings.setFlag( Qgis::LabelingFlag::UsePartialCandidates, chkShowPartialsLabels->isChecked() );
   engineSettings.setFlag( Qgis::LabelingFlag::DrawLabelMetrics, chkShowMetrics->isChecked() );
 
-  engineSettings.setDefaultTextRenderFormat( static_cast< Qgis::TextRenderFormat >( mTextRenderFormatComboBox->currentData().toInt() ) );
+  engineSettings.setDefaultTextRenderFormat( mTextRenderFormatComboBox->currentData().value<Qgis::TextRenderFormat>() );
 
   engineSettings.setUnplacedLabelColor( mUnplacedColorButton->color() );
 
-  engineSettings.setPlacementVersion( static_cast< Qgis::LabelPlacementEngineVersion>( mPlacementVersionComboBox->currentData().toInt() ) );
+  engineSettings.setPlacementVersion( static_cast<Qgis::LabelPlacementEngineVersion>( mPlacementVersionComboBox->currentData().toInt() ) );
 
   QgsProject::instance()->setLabelingEngineSettings( engineSettings );
   mCanvas->refreshAllLayers();
@@ -141,8 +142,8 @@ void QgsLabelEngineConfigWidget::setDefaults()
   chkShowMetrics->setChecked( false );
   chkShowAllLabels->setChecked( false );
   chkShowPartialsLabels->setChecked( p.showPartialLabels() );
-  mTextRenderFormatComboBox->setCurrentIndex( mTextRenderFormatComboBox->findData( static_cast< int >( Qgis::TextRenderFormat::AlwaysOutlines ) ) );
-  mPlacementVersionComboBox->setCurrentIndex( mPlacementVersionComboBox->findData( static_cast< int >( Qgis::LabelPlacementEngineVersion::Version2 ) ) );
+  mTextRenderFormatComboBox->setCurrentIndex( mTextRenderFormatComboBox->findData( QVariant::fromValue( Qgis::TextRenderFormat::AlwaysOutlines ) ) );
+  mPlacementVersionComboBox->setCurrentIndex( mPlacementVersionComboBox->findData( static_cast<int>( Qgis::LabelPlacementEngineVersion::Version2 ) ) );
 }
 
 void QgsLabelEngineConfigWidget::showHelp()
@@ -165,8 +166,7 @@ QgsLabelEngineConfigDialog::QgsLabelEngineConfigDialog( QgsMapCanvas *canvas, QW
   connect( bbox, &QDialogButtonBox::accepted, this, &QDialog::accept );
   connect( bbox, &QDialogButtonBox::rejected, this, &QDialog::reject );
   connect( bbox, &QDialogButtonBox::helpRequested, mWidget, &QgsLabelEngineConfigWidget::showHelp );
-  connect( bbox->button( QDialogButtonBox::RestoreDefaults ), &QAbstractButton::clicked,
-           mWidget, &QgsLabelEngineConfigWidget::setDefaults );
+  connect( bbox->button( QDialogButtonBox::RestoreDefaults ), &QAbstractButton::clicked, mWidget, &QgsLabelEngineConfigWidget::setDefaults );
   vLayout->addWidget( bbox );
   setLayout( vLayout );
 
