@@ -14,6 +14,7 @@
  ***************************************************************************/
 
 #include "qgsnumericformatwidget.h"
+#include "moc_qgsnumericformatwidget.cpp"
 #include "qgsbasicnumericformat.h"
 #include "qgscurrencynumericformat.h"
 #include "qgspercentagenumericformat.h"
@@ -21,10 +22,23 @@
 #include "qgsscientificnumericformat.h"
 #include "qgsfractionnumericformat.h"
 #include "qgscoordinatenumericformat.h"
+#include "qgsexpressionbasednumericformat.h"
 #include "qgsgui.h"
 #include "qgis.h"
 #include <QDialogButtonBox>
 
+void QgsNumericFormatWidget::registerExpressionContextGenerator( QgsExpressionContextGenerator *generator )
+{
+  mExpressionContextGenerator = generator;
+}
+
+QgsExpressionContext QgsNumericFormatWidget::createExpressionContext() const
+{
+  if ( mExpressionContextGenerator )
+    return mExpressionContextGenerator->createExpressionContext();
+  return QgsExpressionContext();
+}
+
 //
 // QgsBasicNumericFormatWidget
 //
@@ -38,36 +52,31 @@ QgsBasicNumericFormatWidget::QgsBasicNumericFormatWidget( const QgsNumericFormat
   mThousandsLineEdit->setShowClearButton( true );
   mDecimalLineEdit->setShowClearButton( true );
 
-  connect( mShowPlusCheckBox, &QCheckBox::toggled, this, [ = ]( bool checked )
-  {
+  connect( mShowPlusCheckBox, &QCheckBox::toggled, this, [=]( bool checked ) {
     mFormat->setShowPlusSign( checked );
     if ( !mBlockSignals )
       emit changed();
   } );
 
-  connect( mShowTrailingZerosCheckBox, &QCheckBox::toggled, this, [ = ]( bool checked )
-  {
+  connect( mShowTrailingZerosCheckBox, &QCheckBox::toggled, this, [=]( bool checked ) {
     mFormat->setShowTrailingZeros( checked );
     if ( !mBlockSignals )
       emit changed();
   } );
 
-  connect( mShowThousandsCheckBox, &QCheckBox::toggled, this, [ = ]( bool checked )
-  {
+  connect( mShowThousandsCheckBox, &QCheckBox::toggled, this, [=]( bool checked ) {
     mFormat->setShowThousandsSeparator( checked );
     if ( !mBlockSignals )
       emit changed();
   } );
 
-  connect( mDecimalsSpinBox, qOverload<int>( &QSpinBox::valueChanged ), this, [ = ]( int value )
-  {
+  connect( mDecimalsSpinBox, qOverload<int>( &QSpinBox::valueChanged ), this, [=]( int value ) {
     mFormat->setNumberDecimalPlaces( value );
     if ( !mBlockSignals )
       emit changed();
   } );
 
-  connect( mRadDecimalPlaces, &QRadioButton::toggled, this, [ = ]( bool checked )
-  {
+  connect( mRadDecimalPlaces, &QRadioButton::toggled, this, [=]( bool checked ) {
     if ( !checked )
       return;
 
@@ -76,8 +85,7 @@ QgsBasicNumericFormatWidget::QgsBasicNumericFormatWidget( const QgsNumericFormat
       emit changed();
   } );
 
-  connect( mRadSignificantFigures, &QRadioButton::toggled, this, [ = ]( bool checked )
-  {
+  connect( mRadSignificantFigures, &QRadioButton::toggled, this, [=]( bool checked ) {
     if ( !checked )
       return;
 
@@ -86,15 +94,13 @@ QgsBasicNumericFormatWidget::QgsBasicNumericFormatWidget( const QgsNumericFormat
       emit changed();
   } );
 
-  connect( mThousandsLineEdit, &QLineEdit::textChanged, this, [ = ]( const QString & text )
-  {
+  connect( mThousandsLineEdit, &QLineEdit::textChanged, this, [=]( const QString &text ) {
     mFormat->setThousandsSeparator( text.isEmpty() ? QChar() : text.at( 0 ) );
     if ( !mBlockSignals )
       emit changed();
   } );
 
-  connect( mDecimalLineEdit, &QLineEdit::textChanged, this, [ = ]( const QString & text )
-  {
+  connect( mDecimalLineEdit, &QLineEdit::textChanged, this, [=]( const QString &text ) {
     mFormat->setDecimalSeparator( text.isEmpty() ? QChar() : text.at( 0 ) );
     if ( !mBlockSignals )
       emit changed();
@@ -105,7 +111,7 @@ QgsBasicNumericFormatWidget::~QgsBasicNumericFormatWidget() = default;
 
 void QgsBasicNumericFormatWidget::setFormat( QgsNumericFormat *format )
 {
-  mFormat.reset( static_cast< QgsBasicNumericFormat * >( format ) );
+  mFormat.reset( static_cast<QgsBasicNumericFormat *>( format ) );
 
   mBlockSignals = true;
   mDecimalsSpinBox->setValue( mFormat->numberDecimalPlaces() );
@@ -149,23 +155,20 @@ QgsBearingNumericFormatWidget::QgsBearingNumericFormatWidget( const QgsNumericFo
 
   setFormat( format->clone() );
 
-  connect( mShowTrailingZerosCheckBox, &QCheckBox::toggled, this, [ = ]( bool checked )
-  {
+  connect( mShowTrailingZerosCheckBox, &QCheckBox::toggled, this, [=]( bool checked ) {
     mFormat->setShowTrailingZeros( checked );
     if ( !mBlockSignals )
       emit changed();
   } );
 
-  connect( mDecimalsSpinBox, qOverload<int>( &QSpinBox::valueChanged ), this, [ = ]( int value )
-  {
+  connect( mDecimalsSpinBox, qOverload<int>( &QSpinBox::valueChanged ), this, [=]( int value ) {
     mFormat->setNumberDecimalPlaces( value );
     if ( !mBlockSignals )
       emit changed();
   } );
 
-  connect( mFormatComboBox, qOverload<int>( &QComboBox::currentIndexChanged ), this, [ = ]( int )
-  {
-    mFormat->setDirectionFormat( static_cast < QgsBearingNumericFormat::FormatDirectionOption >( mFormatComboBox->currentData().toInt() ) );
+  connect( mFormatComboBox, qOverload<int>( &QComboBox::currentIndexChanged ), this, [=]( int ) {
+    mFormat->setDirectionFormat( static_cast<QgsBearingNumericFormat::FormatDirectionOption>( mFormatComboBox->currentData().toInt() ) );
     if ( !mBlockSignals )
       emit changed();
   } );
@@ -175,12 +178,12 @@ QgsBearingNumericFormatWidget::~QgsBearingNumericFormatWidget() = default;
 
 void QgsBearingNumericFormatWidget::setFormat( QgsNumericFormat *format )
 {
-  mFormat.reset( static_cast< QgsBearingNumericFormat * >( format ) );
+  mFormat.reset( static_cast<QgsBearingNumericFormat *>( format ) );
 
   mBlockSignals = true;
   mDecimalsSpinBox->setValue( mFormat->numberDecimalPlaces() );
   mShowTrailingZerosCheckBox->setChecked( mFormat->showTrailingZeros() );
-  mFormatComboBox->setCurrentIndex( mFormatComboBox->findData( static_cast< int >( mFormat->directionFormat() ) ) );
+  mFormatComboBox->setCurrentIndex( mFormatComboBox->findData( static_cast<int>( mFormat->directionFormat() ) ) );
   mBlockSignals = false;
 }
 
@@ -214,13 +217,10 @@ QgsBearingNumericFormatDialog::QgsBearingNumericFormatDialog( const QgsNumericFo
 
 QgsBearingNumericFormat *QgsBearingNumericFormatDialog::format()
 {
-  return static_cast< QgsBearingNumericFormat * >( mWidget->format() );
+  return static_cast<QgsBearingNumericFormat *>( mWidget->format() );
 }
 
 
-
-
-
 //
 // QgsGeographicCoordinateNumericFormatWidget
 //
@@ -231,9 +231,9 @@ QgsGeographicCoordinateNumericFormatWidget::QgsGeographicCoordinateNumericFormat
   setupUi( this );
 
   mDecimalsSpinBox->setClearValue( 6 );
-  mFormatComboBox->addItem( QObject::tr( "Decimal Degrees" ), static_cast< int >( QgsGeographicCoordinateNumericFormat::AngleFormat::DecimalDegrees ) );
-  mFormatComboBox->addItem( QObject::tr( "Degrees, Minutes" ), static_cast< int >( QgsGeographicCoordinateNumericFormat::AngleFormat::DegreesMinutes ) );
-  mFormatComboBox->addItem( QObject::tr( "Degrees, Minutes, Seconds" ), static_cast< int >( QgsGeographicCoordinateNumericFormat::AngleFormat::DegreesMinutesSeconds ) );
+  mFormatComboBox->addItem( QObject::tr( "Decimal Degrees" ), static_cast<int>( QgsGeographicCoordinateNumericFormat::AngleFormat::DecimalDegrees ) );
+  mFormatComboBox->addItem( QObject::tr( "Degrees, Minutes" ), static_cast<int>( QgsGeographicCoordinateNumericFormat::AngleFormat::DegreesMinutes ) );
+  mFormatComboBox->addItem( QObject::tr( "Degrees, Minutes, Seconds" ), static_cast<int>( QgsGeographicCoordinateNumericFormat::AngleFormat::DegreesMinutesSeconds ) );
 
   if ( hidePrecisionControl )
   {
@@ -242,44 +242,38 @@ QgsGeographicCoordinateNumericFormatWidget::QgsGeographicCoordinateNumericFormat
   }
   setFormat( format->clone() );
 
-  connect( mShowTrailingZerosCheckBox, &QCheckBox::toggled, this, [ = ]( bool checked )
-  {
+  connect( mShowTrailingZerosCheckBox, &QCheckBox::toggled, this, [=]( bool checked ) {
     mFormat->setShowTrailingZeros( checked );
     if ( !mBlockSignals )
       emit changed();
   } );
 
-  connect( mShowDirectionalSuffixCheckBox, &QCheckBox::toggled, this, [ = ]( bool checked )
-  {
+  connect( mShowDirectionalSuffixCheckBox, &QCheckBox::toggled, this, [=]( bool checked ) {
     mFormat->setShowDirectionalSuffix( checked );
     if ( !mBlockSignals )
       emit changed();
   } );
 
-  connect( mShowLeadingZerosCheckBox, &QCheckBox::toggled, this, [ = ]( bool checked )
-  {
+  connect( mShowLeadingZerosCheckBox, &QCheckBox::toggled, this, [=]( bool checked ) {
     mFormat->setShowLeadingZeros( checked );
     if ( !mBlockSignals )
       emit changed();
   } );
 
-  connect( mShowLeadingZerosForDegreesCheckBox, &QCheckBox::toggled, this, [ = ]( bool checked )
-  {
+  connect( mShowLeadingZerosForDegreesCheckBox, &QCheckBox::toggled, this, [=]( bool checked ) {
     mFormat->setShowDegreeLeadingZeros( checked );
     if ( !mBlockSignals )
       emit changed();
   } );
 
-  connect( mDecimalsSpinBox, qOverload<int>( &QSpinBox::valueChanged ), this, [ = ]( int value )
-  {
+  connect( mDecimalsSpinBox, qOverload<int>( &QSpinBox::valueChanged ), this, [=]( int value ) {
     mFormat->setNumberDecimalPlaces( value );
     if ( !mBlockSignals )
       emit changed();
   } );
 
-  connect( mFormatComboBox, qOverload<int>( &QComboBox::currentIndexChanged ), this, [ = ]( int )
-  {
-    mFormat->setAngleFormat( static_cast < QgsGeographicCoordinateNumericFormat::AngleFormat >( mFormatComboBox->currentData().toInt() ) );
+  connect( mFormatComboBox, qOverload<int>( &QComboBox::currentIndexChanged ), this, [=]( int ) {
+    mFormat->setAngleFormat( static_cast<QgsGeographicCoordinateNumericFormat::AngleFormat>( mFormatComboBox->currentData().toInt() ) );
     if ( !mBlockSignals )
       emit changed();
   } );
@@ -289,7 +283,7 @@ QgsGeographicCoordinateNumericFormatWidget::~QgsGeographicCoordinateNumericForma
 
 void QgsGeographicCoordinateNumericFormatWidget::setFormat( QgsNumericFormat *format )
 {
-  mFormat.reset( static_cast< QgsGeographicCoordinateNumericFormat * >( format ) );
+  mFormat.reset( static_cast<QgsGeographicCoordinateNumericFormat *>( format ) );
 
   mBlockSignals = true;
   mDecimalsSpinBox->setValue( mFormat->numberDecimalPlaces() );
@@ -297,7 +291,7 @@ void QgsGeographicCoordinateNumericFormatWidget::setFormat( QgsNumericFormat *fo
   mShowDirectionalSuffixCheckBox->setChecked( mFormat->showDirectionalSuffix() );
   mShowLeadingZerosCheckBox->setChecked( mFormat->showLeadingZeros() );
   mShowLeadingZerosForDegreesCheckBox->setChecked( mFormat->showDegreeLeadingZeros() );
-  mFormatComboBox->setCurrentIndex( mFormatComboBox->findData( static_cast< int >( mFormat->angleFormat() ) ) );
+  mFormatComboBox->setCurrentIndex( mFormatComboBox->findData( static_cast<int>( mFormat->angleFormat() ) ) );
   mBlockSignals = false;
 }
 
@@ -331,12 +325,10 @@ QgsGeographicCoordinateNumericFormatDialog::QgsGeographicCoordinateNumericFormat
 
 QgsGeographicCoordinateNumericFormat *QgsGeographicCoordinateNumericFormatDialog::format()
 {
-  return static_cast< QgsGeographicCoordinateNumericFormat * >( mWidget->format() );
+  return static_cast<QgsGeographicCoordinateNumericFormat *>( mWidget->format() );
 }
 
 
-
-
 //
 // QgsCurrencyNumericFormatWidget
 //
@@ -347,43 +339,37 @@ QgsCurrencyNumericFormatWidget::QgsCurrencyNumericFormatWidget( const QgsNumeric
   mDecimalsSpinBox->setClearValue( 2 );
   setFormat( format->clone() );
 
-  connect( mShowPlusCheckBox, &QCheckBox::toggled, this, [ = ]( bool checked )
-  {
+  connect( mShowPlusCheckBox, &QCheckBox::toggled, this, [=]( bool checked ) {
     mFormat->setShowPlusSign( checked );
     if ( !mBlockSignals )
       emit changed();
   } );
 
-  connect( mShowTrailingZerosCheckBox, &QCheckBox::toggled, this, [ = ]( bool checked )
-  {
+  connect( mShowTrailingZerosCheckBox, &QCheckBox::toggled, this, [=]( bool checked ) {
     mFormat->setShowTrailingZeros( checked );
     if ( !mBlockSignals )
       emit changed();
   } );
 
-  connect( mShowThousandsCheckBox, &QCheckBox::toggled, this, [ = ]( bool checked )
-  {
+  connect( mShowThousandsCheckBox, &QCheckBox::toggled, this, [=]( bool checked ) {
     mFormat->setShowThousandsSeparator( checked );
     if ( !mBlockSignals )
       emit changed();
   } );
 
-  connect( mDecimalsSpinBox, qOverload<int>( &QSpinBox::valueChanged ), this, [ = ]( int value )
-  {
+  connect( mDecimalsSpinBox, qOverload<int>( &QSpinBox::valueChanged ), this, [=]( int value ) {
     mFormat->setNumberDecimalPlaces( value );
     if ( !mBlockSignals )
       emit changed();
   } );
 
-  connect( mPrefixLineEdit, &QLineEdit::textChanged, this, [ = ]( const QString & text )
-  {
+  connect( mPrefixLineEdit, &QLineEdit::textChanged, this, [=]( const QString &text ) {
     mFormat->setPrefix( text );
     if ( !mBlockSignals )
       emit changed();
   } );
 
-  connect( mSuffixLineEdit, &QLineEdit::textChanged, this, [ = ]( const QString & text )
-  {
+  connect( mSuffixLineEdit, &QLineEdit::textChanged, this, [=]( const QString &text ) {
     mFormat->setSuffix( text );
     if ( !mBlockSignals )
       emit changed();
@@ -394,7 +380,7 @@ QgsCurrencyNumericFormatWidget::~QgsCurrencyNumericFormatWidget() = default;
 
 void QgsCurrencyNumericFormatWidget::setFormat( QgsNumericFormat *format )
 {
-  mFormat.reset( static_cast< QgsCurrencyNumericFormat * >( format ) );
+  mFormat.reset( static_cast<QgsCurrencyNumericFormat *>( format ) );
 
   mBlockSignals = true;
   mDecimalsSpinBox->setValue( mFormat->numberDecimalPlaces() );
@@ -428,37 +414,32 @@ QgsPercentageNumericFormatWidget::QgsPercentageNumericFormatWidget( const QgsNum
 
   setFormat( format->clone() );
 
-  connect( mShowTrailingZerosCheckBox, &QCheckBox::toggled, this, [ = ]( bool checked )
-  {
+  connect( mShowTrailingZerosCheckBox, &QCheckBox::toggled, this, [=]( bool checked ) {
     mFormat->setShowTrailingZeros( checked );
     if ( !mBlockSignals )
       emit changed();
   } );
 
-  connect( mShowPlusCheckBox, &QCheckBox::toggled, this, [ = ]( bool checked )
-  {
+  connect( mShowPlusCheckBox, &QCheckBox::toggled, this, [=]( bool checked ) {
     mFormat->setShowPlusSign( checked );
     if ( !mBlockSignals )
       emit changed();
   } );
 
-  connect( mShowThousandsCheckBox, &QCheckBox::toggled, this, [ = ]( bool checked )
-  {
+  connect( mShowThousandsCheckBox, &QCheckBox::toggled, this, [=]( bool checked ) {
     mFormat->setShowThousandsSeparator( checked );
     if ( !mBlockSignals )
       emit changed();
   } );
 
-  connect( mDecimalsSpinBox, qOverload<int>( &QSpinBox::valueChanged ), this, [ = ]( int value )
-  {
+  connect( mDecimalsSpinBox, qOverload<int>( &QSpinBox::valueChanged ), this, [=]( int value ) {
     mFormat->setNumberDecimalPlaces( value );
     if ( !mBlockSignals )
       emit changed();
   } );
 
-  connect( mScalingComboBox, qOverload<int>( &QComboBox::currentIndexChanged ), this, [ = ]( int )
-  {
-    mFormat->setInputValues( static_cast < QgsPercentageNumericFormat::InputValues >( mScalingComboBox->currentData().toInt() ) );
+  connect( mScalingComboBox, qOverload<int>( &QComboBox::currentIndexChanged ), this, [=]( int ) {
+    mFormat->setInputValues( static_cast<QgsPercentageNumericFormat::InputValues>( mScalingComboBox->currentData().toInt() ) );
     if ( !mBlockSignals )
       emit changed();
   } );
@@ -468,14 +449,14 @@ QgsPercentageNumericFormatWidget::~QgsPercentageNumericFormatWidget() = default;
 
 void QgsPercentageNumericFormatWidget::setFormat( QgsNumericFormat *format )
 {
-  mFormat.reset( static_cast< QgsPercentageNumericFormat * >( format ) );
+  mFormat.reset( static_cast<QgsPercentageNumericFormat *>( format ) );
 
   mBlockSignals = true;
   mDecimalsSpinBox->setValue( mFormat->numberDecimalPlaces() );
   mShowPlusCheckBox->setChecked( mFormat->showPlusSign() );
   mShowTrailingZerosCheckBox->setChecked( mFormat->showTrailingZeros() );
   mShowThousandsCheckBox->setChecked( mFormat->showThousandsSeparator() );
-  mScalingComboBox->setCurrentIndex( mScalingComboBox->findData( static_cast< int >( mFormat->inputValues() ) ) );
+  mScalingComboBox->setCurrentIndex( mScalingComboBox->findData( static_cast<int>( mFormat->inputValues() ) ) );
   mBlockSignals = false;
 }
 
@@ -494,22 +475,19 @@ QgsScientificNumericFormatWidget::QgsScientificNumericFormatWidget( const QgsNum
   mDecimalsSpinBox->setClearValue( 6 );
   setFormat( format->clone() );
 
-  connect( mShowPlusCheckBox, &QCheckBox::toggled, this, [ = ]( bool checked )
-  {
+  connect( mShowPlusCheckBox, &QCheckBox::toggled, this, [=]( bool checked ) {
     mFormat->setShowPlusSign( checked );
     if ( !mBlockSignals )
       emit changed();
   } );
 
-  connect( mShowTrailingZerosCheckBox, &QCheckBox::toggled, this, [ = ]( bool checked )
-  {
+  connect( mShowTrailingZerosCheckBox, &QCheckBox::toggled, this, [=]( bool checked ) {
     mFormat->setShowTrailingZeros( checked );
     if ( !mBlockSignals )
       emit changed();
   } );
 
-  connect( mDecimalsSpinBox, qOverload<int>( &QSpinBox::valueChanged ), this, [ = ]( int value )
-  {
+  connect( mDecimalsSpinBox, qOverload<int>( &QSpinBox::valueChanged ), this, [=]( int value ) {
     mFormat->setNumberDecimalPlaces( value );
     if ( !mBlockSignals )
       emit changed();
@@ -520,7 +498,7 @@ QgsScientificNumericFormatWidget::~QgsScientificNumericFormatWidget() = default;
 
 void QgsScientificNumericFormatWidget::setFormat( QgsNumericFormat *format )
 {
-  mFormat.reset( static_cast< QgsScientificNumericFormat * >( format ) );
+  mFormat.reset( static_cast<QgsScientificNumericFormat *>( format ) );
 
   mBlockSignals = true;
   mDecimalsSpinBox->setValue( mFormat->numberDecimalPlaces() );
@@ -535,7 +513,6 @@ QgsNumericFormat *QgsScientificNumericFormatWidget::format()
 }
 
 
-
 //
 // QgsFractionNumericFormatWidget
 //
@@ -547,48 +524,42 @@ QgsFractionNumericFormatWidget::QgsFractionNumericFormatWidget( const QgsNumeric
 
   mThousandsLineEdit->setShowClearButton( true );
 
-  connect( mUseDedicatedUnicodeCheckBox, &QCheckBox::toggled, this, [ = ]( bool checked )
-  {
+  connect( mUseDedicatedUnicodeCheckBox, &QCheckBox::toggled, this, [=]( bool checked ) {
     mFormat->setUseDedicatedUnicodeCharacters( checked );
     if ( !mBlockSignals )
       emit changed();
   } );
 
-  connect( mUseUnicodeSupersubscriptCheckBox, &QCheckBox::toggled, this, [ = ]( bool checked )
-  {
+  connect( mUseUnicodeSupersubscriptCheckBox, &QCheckBox::toggled, this, [=]( bool checked ) {
     mFormat->setUseUnicodeSuperSubscript( checked );
     if ( !mBlockSignals )
       emit changed();
   } );
 
-  connect( mShowPlusCheckBox, &QCheckBox::toggled, this, [ = ]( bool checked )
-  {
+  connect( mShowPlusCheckBox, &QCheckBox::toggled, this, [=]( bool checked ) {
     mFormat->setShowPlusSign( checked );
     if ( !mBlockSignals )
       emit changed();
   } );
 
-  connect( mShowThousandsCheckBox, &QCheckBox::toggled, this, [ = ]( bool checked )
-  {
+  connect( mShowThousandsCheckBox, &QCheckBox::toggled, this, [=]( bool checked ) {
     mFormat->setShowThousandsSeparator( checked );
     if ( !mBlockSignals )
       emit changed();
   } );
 
-  connect( mThousandsLineEdit, &QLineEdit::textChanged, this, [ = ]( const QString & text )
-  {
+  connect( mThousandsLineEdit, &QLineEdit::textChanged, this, [=]( const QString &text ) {
     mFormat->setThousandsSeparator( text.isEmpty() ? QChar() : text.at( 0 ) );
     if ( !mBlockSignals )
       emit changed();
   } );
-
 }
 
 QgsFractionNumericFormatWidget::~QgsFractionNumericFormatWidget() = default;
 
 void QgsFractionNumericFormatWidget::setFormat( QgsNumericFormat *format )
 {
-  mFormat.reset( static_cast< QgsFractionNumericFormat * >( format ) );
+  mFormat.reset( static_cast<QgsFractionNumericFormat *>( format ) );
 
   mBlockSignals = true;
   mUseDedicatedUnicodeCheckBox->setChecked( mFormat->useDedicatedUnicodeCharacters() );
@@ -603,3 +574,50 @@ QgsNumericFormat *QgsFractionNumericFormatWidget::format()
 {
   return mFormat->clone();
 }
+
+
+//
+// QgsExpressionBasedNumericFormatWidget
+//
+QgsExpressionBasedNumericFormatWidget::QgsExpressionBasedNumericFormatWidget( const QgsNumericFormat *format, QWidget *parent )
+  : QgsNumericFormatWidget( parent )
+{
+  setupUi( this );
+  setFormat( format->clone() );
+
+  mExpressionSelector->setMultiLine( true );
+  mExpressionSelector->registerExpressionContextGenerator( this );
+
+  connect( mExpressionSelector, &QgsExpressionLineEdit::expressionChanged, this, [=]( const QString &text ) {
+    mFormat->setExpression( text );
+    if ( !mBlockSignals )
+      emit changed();
+  } );
+}
+
+QgsExpressionContext QgsExpressionBasedNumericFormatWidget::createExpressionContext() const
+{
+  QgsExpressionContext context = QgsNumericFormatWidget::createExpressionContext();
+
+  QgsExpressionContextScope *scope = new QgsExpressionContextScope();
+  scope->addVariable( QgsExpressionContextScope::StaticVariable( QStringLiteral( "value" ), 1234.5678 ) );
+  context.appendScope( scope );
+  context.setHighlightedVariables( { QStringLiteral( "value" ) } );
+  return context;
+}
+
+QgsExpressionBasedNumericFormatWidget::~QgsExpressionBasedNumericFormatWidget() = default;
+
+void QgsExpressionBasedNumericFormatWidget::setFormat( QgsNumericFormat *format )
+{
+  mFormat.reset( static_cast<QgsExpressionBasedNumericFormat *>( format ) );
+
+  mBlockSignals = true;
+  mExpressionSelector->setExpression( mFormat->expression() );
+  mBlockSignals = false;
+}
+
+QgsNumericFormat *QgsExpressionBasedNumericFormatWidget::format()
+{
+  return mFormat->clone();
+}
