@@ -14,6 +14,7 @@
  ***************************************************************************/
 
 #include "qgsratiolockbutton.h"
+#include "moc_qgsratiolockbutton.cpp"
 #include "qgsapplication.h"
 #include "qgssvgcache.h"
 #include "qgis.h"
@@ -44,7 +45,7 @@ void QgsRatioLockButton::setLocked( const bool locked )
 void QgsRatioLockButton::buttonClicked()
 {
   mLocked = !mLocked;
-  setDown( mLocked );
+  setChecked( mLocked );
 
   emit lockChanged( mLocked );
 
@@ -140,15 +141,10 @@ void QgsRatioLockButton::drawButton()
   const QString imageSource = mLocked ? QStringLiteral( ":/images/themes/default/lockedGray.svg" ) : QStringLiteral( ":/images/themes/default/unlockedGray.svg" );
   bool fitsInCache = false;
   QImage image = QgsApplication::svgCache()->svgAsImage(
-                   imageSource, 16 * pixelRatio, QColor(), QColor(), 0, 1, fitsInCache
-                 );
+    imageSource, 16 * pixelRatio, QColor(), QColor(), 0, 1, fitsInCache
+  );
   image.setDevicePixelRatio( pixelRatio );
-  painter.drawImage( QRectF(
-                       currentIconSize.width() / 2 - 8,
-                       currentIconSize.height() / 2 - 8,
-                       16,
-                       16 ),
-                     image );
+  painter.drawImage( QRectF( currentIconSize.width() / 2 - 8, currentIconSize.height() / 2 - 8, 16, 16 ), image );
 
   painter.end();
 
