@@ -15,6 +15,7 @@
  *                                                                         *
  ***************************************************************************/
 #include "qgssvgselectorwidget.h"
+#include "moc_qgssvgselectorwidget.cpp"
 
 #include "qgsapplication.h"
 #include "qgslogger.h"
@@ -75,7 +76,9 @@ void QgsSvgSelectorLoader::run()
 void QgsSvgSelectorLoader::stop()
 {
   mCanceled = true;
-  while ( isRunning() ) {}
+  while ( isRunning() )
+  {
+  }
 }
 
 void QgsSvgSelectorLoader::loadPath( const QString &path )
@@ -167,7 +170,6 @@ void QgsSvgSelectorLoader::loadImages( const QString &path )
 QgsSvgGroupLoader::QgsSvgGroupLoader( QObject *parent )
   : QThread( parent )
 {
-
 }
 
 QgsSvgGroupLoader::~QgsSvgGroupLoader()
@@ -190,7 +192,9 @@ void QgsSvgGroupLoader::run()
 void QgsSvgGroupLoader::stop()
 {
   mCanceled = true;
-  while ( isRunning() ) {}
+  while ( isRunning() )
+  {
+  }
 }
 
 void QgsSvgGroupLoader::loadGroup( const QString &parentPath )
@@ -218,8 +222,6 @@ void QgsSvgGroupLoader::loadGroup( const QString &parentPath )
 ///@endcond
 
 
-
-
 QgsSvgSelectorFilterModel::QgsSvgSelectorFilterModel( QObject *parent, const QString &path, int iconSize )
   : QSortFilterProxyModel( parent )
 {
@@ -261,11 +263,7 @@ QPixmap QgsSvgSelectorListModel::createPreview( const QString &entry ) const
   bool fillParam, fillOpacityParam, strokeParam, strokeWidthParam, strokeOpacityParam;
   bool hasDefaultFillColor = false, hasDefaultFillOpacity = false, hasDefaultStrokeColor = false,
        hasDefaultStrokeWidth = false, hasDefaultStrokeOpacity = false;
-  QgsApplication::svgCache()->containsParams( entry, fillParam, hasDefaultFillColor, fill,
-      fillOpacityParam, hasDefaultFillOpacity, fillOpacity,
-      strokeParam, hasDefaultStrokeColor, stroke,
-      strokeWidthParam, hasDefaultStrokeWidth, strokeWidth,
-      strokeOpacityParam, hasDefaultStrokeOpacity, strokeOpacity );
+  QgsApplication::svgCache()->containsParams( entry, fillParam, hasDefaultFillColor, fill, fillOpacityParam, hasDefaultFillOpacity, fillOpacity, strokeParam, hasDefaultStrokeColor, stroke, strokeWidthParam, hasDefaultStrokeWidth, strokeWidth, strokeOpacityParam, hasDefaultStrokeOpacity, strokeOpacity );
 
   //if defaults not set in symbol, use these values
   if ( !hasDefaultFillColor )
@@ -288,8 +286,8 @@ QVariant QgsSvgSelectorListModel::data( const QModelIndex &index, int role ) con
 
   if ( role == Qt::DecorationRole ) // icon
   {
-    QPixmap *pixmap = nullptr;
-    if ( !QPixmapCache::find( entry, pixmap ) || !pixmap )
+    QPixmap pixmap;
+    if ( !QPixmapCache::find( entry, &pixmap ) )
     {
       QPixmap newPixmap = createPreview( entry );
       QPixmapCache::insert( entry, newPixmap );
@@ -297,7 +295,7 @@ QVariant QgsSvgSelectorListModel::data( const QModelIndex &index, int role ) con
     }
     else
     {
-      return *pixmap;
+      return pixmap;
     }
   }
   else if ( role == Qt::UserRole || role == Qt::ToolTipRole )
@@ -316,9 +314,6 @@ void QgsSvgSelectorListModel::addSvgs( const QStringList &svgs )
 }
 
 
-
-
-
 //--- QgsSvgSelectorGroupsModel
 
 QgsSvgSelectorGroupsModel::QgsSvgSelectorGroupsModel( QObject *parent )
@@ -393,15 +388,14 @@ QgsSvgSelectorWidget::QgsSvgSelectorWidget( QWidget *parent )
   // TODO: in-code gui setup with option to vertically or horizontally stack SVG groups/images widgets
   setupUi( this );
 
-  mIconSize = std::max( 30, static_cast< int >( std::round( Qgis::UI_SCALE_FACTOR * fontMetrics().horizontalAdvance( 'X' ) * 3 ) ) );
+  mIconSize = std::max( 30, static_cast<int>( std::round( Qgis::UI_SCALE_FACTOR * fontMetrics().horizontalAdvance( 'X' ) * 3 ) ) );
   mImagesListView->setGridSize( QSize( mIconSize * 1.2, mIconSize * 1.2 ) );
   mImagesListView->setUniformItemSizes( false );
 
   mGroupsTreeView->setHeaderHidden( true );
   populateList();
 
-  connect( mSvgFilterLineEdit, &QgsFilterLineEdit::textChanged, this, [ = ]( const QString & filterText )
-  {
+  connect( mSvgFilterLineEdit, &QgsFilterLineEdit::textChanged, this, [=]( const QString &filterText ) {
     if ( !mImagesListView->selectionModel()->selectedIndexes().isEmpty() )
     {
       disconnect( mImagesListView->selectionModel(), &QItemSelectionModel::currentChanged, this, &QgsSvgSelectorWidget::svgSelectionChanged );
@@ -427,8 +421,7 @@ QgsSvgSelectorWidget::QgsSvgSelectorWidget( QWidget *parent )
   connect( mImagesListView->selectionModel(), &QItemSelectionModel::currentChanged, this, &QgsSvgSelectorWidget::svgSelectionChanged );
   connect( mGroupsTreeView->selectionModel(), &QItemSelectionModel::currentChanged, this, &QgsSvgSelectorWidget::populateIcons );
   connect( mAddParameterButton, &QToolButton::clicked, mParametersModel, &QgsSvgParametersModel::addParameter );
-  connect( mRemoveParameterButton, &QToolButton::clicked, this, [ = ]()
-  {
+  connect( mRemoveParameterButton, &QToolButton::clicked, this, [=]() {
     const QModelIndexList selectedRows = mParametersTreeView->selectionModel()->selectedRows();
     if ( selectedRows.count() > 0 )
       mParametersModel->removeParameters( selectedRows );
@@ -522,8 +515,7 @@ void QgsSvgSelectorWidget::populateIcons( const QModelIndex &idx )
   connect( mSvgFilterLineEdit, &QgsFilterLineEdit::textChanged, m, &QSortFilterProxyModel::setFilterFixedString );
   delete oldModel; //explicitly delete old model to force any background threads to stop
 
-  connect( mImagesListView->selectionModel(), &QItemSelectionModel::currentChanged,
-           this, &QgsSvgSelectorWidget::svgSelectionChanged );
+  connect( mImagesListView->selectionModel(), &QItemSelectionModel::currentChanged, this, &QgsSvgSelectorWidget::svgSelectionChanged );
 }
 
 void QgsSvgSelectorWidget::svgSourceChanged( const QString &text )
@@ -554,9 +546,7 @@ void QgsSvgSelectorWidget::populateList()
 
 //-- QgsSvgSelectorDialog
 
-QgsSvgSelectorDialog::QgsSvgSelectorDialog( QWidget *parent, Qt::WindowFlags fl,
-    QDialogButtonBox::StandardButtons buttons,
-    Qt::Orientation orientation )
+QgsSvgSelectorDialog::QgsSvgSelectorDialog( QWidget *parent, Qt::WindowFlags fl, QDialogButtonBox::StandardButtons buttons, Qt::Orientation orientation )
   : QDialog( parent, fl )
 {
   // TODO: pass 'orientation' to QgsSvgSelectorWidget for customizing its layout, once implemented
@@ -585,9 +575,9 @@ QgsSvgSelectorDialog::QgsSvgSelectorDialog( QWidget *parent, Qt::WindowFlags fl,
 QgsSvgParametersModel::QgsSvgParametersModel( QObject *parent )
   : QAbstractTableModel( parent )
 {
-  connect( this, &QAbstractTableModel::rowsInserted, this, [ = ]() {emit parametersChanged( parameters() );} );
-  connect( this, &QAbstractTableModel::rowsRemoved, this, [ = ]() {emit parametersChanged( parameters() );} );
-  connect( this, &QAbstractTableModel::dataChanged, this, [ = ]() {emit parametersChanged( parameters() );} );
+  connect( this, &QAbstractTableModel::rowsInserted, this, [=]() { emit parametersChanged( parameters() ); } );
+  connect( this, &QAbstractTableModel::rowsRemoved, this, [=]() { emit parametersChanged( parameters() ); } );
+  connect( this, &QAbstractTableModel::dataChanged, this, [=]() { emit parametersChanged( parameters() ); } );
 }
 
 void QgsSvgParametersModel::setParameters( const QMap<QString, QgsProperty> &parameters )
@@ -618,7 +608,7 @@ void QgsSvgParametersModel::removeParameters( const QModelIndexList &indexList )
   if ( indexList.isEmpty() )
     return;
 
-  auto mm = std::minmax_element( indexList.constBegin(), indexList.constEnd(), []( const QModelIndex & i1, const QModelIndex & i2 ) {return i1.row() < i2.row();} );
+  auto mm = std::minmax_element( indexList.constBegin(), indexList.constEnd(), []( const QModelIndex &i1, const QModelIndex &i2 ) { return i1.row() < i2.row(); } );
 
   beginRemoveRows( QModelIndex(), ( *mm.first ).row(), ( *mm.second ).row() );
   for ( const QModelIndex &index : indexList )
@@ -722,7 +712,7 @@ void QgsSvgParametersModel::addParameter()
   beginInsertRows( QModelIndex(), c, c );
   int i = 1;
   QStringList currentNames;
-  std::transform( mParameters.begin(), mParameters.end(), std::back_inserter( currentNames ), []( const Parameter & parameter ) {return parameter.name;} );
+  std::transform( mParameters.begin(), mParameters.end(), std::back_inserter( currentNames ), []( const Parameter &parameter ) { return parameter.name; } );
   while ( currentNames.contains( QStringLiteral( "param%1" ).arg( i ) ) )
     i++;
   mParameters.append( Parameter( QStringLiteral( "param%1" ).arg( i ), QgsProperty() ) );
@@ -771,5 +761,3 @@ void QgsSvgParameterValueDelegate::updateEditorGeometry( QWidget *editor, const
 }
 
 ///@endcond
-
-
