@@ -14,6 +14,7 @@
  ***************************************************************************/
 
 #include "qgssymbolslistwidget.h"
+#include "moc_qgssymbolslistwidget.cpp"
 #include "qgsstylesavedialog.h"
 #include "qgsstyleitemslistwidget.h"
 #include "qgsvectorlayer.h"
@@ -22,6 +23,7 @@
 #include "qgsmarkersymbol.h"
 #include "qgslinesymbol.h"
 #include "qgssymbolanimationsettingswidget.h"
+#include "qgssymbolbuffersettingswidget.h"
 #include "qgsprojectstylesettings.h"
 
 #include <QMessageBox>
@@ -50,6 +52,10 @@ QgsSymbolsListWidget::QgsSymbolsListWidget( QgsSymbol *symbol, QgsStyle *style,
   mStandardizeRingsAction = new QAction( tr( "Force Right-Hand-Rule Orientation" ), this );
   mStandardizeRingsAction->setCheckable( true );
   connect( mStandardizeRingsAction, &QAction::toggled, this, &QgsSymbolsListWidget::forceRHRToggled );
+
+  mBufferSettingsAction = new QAction( tr( "Buffer Settings…" ), this );
+  connect( mBufferSettingsAction, &QAction::triggered, this, &QgsSymbolsListWidget::showBufferSettings );
+
   mAnimationSettingsAction = new QAction( tr( "Animation Settings…" ), this );
   connect( mAnimationSettingsAction, &QAction::triggered, this, &QgsSymbolsListWidget::showAnimationSettings );
 
@@ -65,11 +71,11 @@ QgsSymbolsListWidget::QgsSymbolsListWidget( QgsSymbol *symbol, QgsStyle *style,
       opacityDDBtn = mMarkerOpacityDDBtn;
       mSymbolOpacityWidget = mMarkerOpacityWidget;
       mSymbolUnitWidget = mMarkerUnitWidget;
-      connect( spinAngle, static_cast < void ( QDoubleSpinBox::* )( double ) > ( &QDoubleSpinBox::valueChanged ), this, &QgsSymbolsListWidget::setMarkerAngle );
-      connect( spinSize, static_cast < void ( QDoubleSpinBox::* )( double ) > ( &QDoubleSpinBox::valueChanged ), this, &QgsSymbolsListWidget::setMarkerSize );
-      registerDataDefinedButton( mSizeDDBtn, QgsSymbolLayer::PropertySize );
+      connect( spinAngle, static_cast<void ( QDoubleSpinBox::* )( double )>( &QDoubleSpinBox::valueChanged ), this, &QgsSymbolsListWidget::setMarkerAngle );
+      connect( spinSize, static_cast<void ( QDoubleSpinBox::* )( double )>( &QDoubleSpinBox::valueChanged ), this, &QgsSymbolsListWidget::setMarkerSize );
+      registerDataDefinedButton( mSizeDDBtn, QgsSymbolLayer::Property::Size );
       connect( mSizeDDBtn, &QgsPropertyOverrideButton::changed, this, &QgsSymbolsListWidget::updateDataDefinedMarkerSize );
-      registerDataDefinedButton( mRotationDDBtn, QgsSymbolLayer::PropertyAngle );
+      registerDataDefinedButton( mRotationDDBtn, QgsSymbolLayer::Property::Angle );
       connect( mRotationDDBtn, &QgsPropertyOverrideButton::changed, this, &QgsSymbolsListWidget::updateDataDefinedMarkerAngle );
       break;
     }
@@ -82,8 +88,8 @@ QgsSymbolsListWidget::QgsSymbolsListWidget( QgsSymbol *symbol, QgsStyle *style,
       opacityDDBtn = mLineOpacityDDBtn;
       mSymbolOpacityWidget = mLineOpacityWidget;
       mSymbolUnitWidget = mLineUnitWidget;
-      connect( spinWidth, static_cast < void ( QDoubleSpinBox::* )( double ) > ( &QDoubleSpinBox::valueChanged ), this, &QgsSymbolsListWidget::setLineWidth );
-      registerDataDefinedButton( mWidthDDBtn, QgsSymbolLayer::PropertyStrokeWidth );
+      connect( spinWidth, static_cast<void ( QDoubleSpinBox::* )( double )>( &QDoubleSpinBox::valueChanged ), this, &QgsSymbolsListWidget::setLineWidth );
+      registerDataDefinedButton( mWidthDDBtn, QgsSymbolLayer::Property::StrokeWidth );
       connect( mWidthDDBtn, &QgsPropertyOverrideButton::changed, this, &QgsSymbolsListWidget::updateDataDefinedLineWidth );
       break;
     }
@@ -105,12 +111,7 @@ QgsSymbolsListWidget::QgsSymbolsListWidget( QgsSymbol *symbol, QgsStyle *style,
 
   stackedWidget->setCurrentIndex( 0 );
 
-  mSymbolUnitWidget->setUnits( { Qgis::RenderUnit::Millimeters,
-                                 Qgis::RenderUnit::MetersInMapUnits,
-                                 Qgis::RenderUnit::MapUnits,
-                                 Qgis::RenderUnit::Pixels,
-                                 Qgis::RenderUnit::Points,
-                                 Qgis::RenderUnit::Inches } );
+  mSymbolUnitWidget->setUnits( { Qgis::RenderUnit::Millimeters, Qgis::RenderUnit::MetersInMapUnits, Qgis::RenderUnit::MapUnits, Qgis::RenderUnit::Pixels, Qgis::RenderUnit::Points, Qgis::RenderUnit::Inches } );
 
   if ( mSymbol )
   {
@@ -120,7 +121,7 @@ QgsSymbolsListWidget::QgsSymbolsListWidget( QgsSymbol *symbol, QgsStyle *style,
   connect( mSymbolUnitWidget, &QgsUnitSelectionWidget::changed, this, &QgsSymbolsListWidget::mSymbolUnitWidget_changed );
   connect( mSymbolColorButton, &QgsColorButton::colorChanged, this, &QgsSymbolsListWidget::setSymbolColor );
 
-  registerSymbolDataDefinedButton( opacityDDBtn, QgsSymbol::PropertyOpacity );
+  registerSymbolDataDefinedButton( opacityDDBtn, QgsSymbol::Property::Opacity );
 
   connect( this, &QgsSymbolsListWidget::changed, this, &QgsSymbolsListWidget::updateAssistantSymbol );
   updateAssistantSymbol();
@@ -142,11 +143,12 @@ QgsSymbolsListWidget::~QgsSymbolsListWidget()
   mStyleItemsListWidget->advancedMenu()->removeAction( mClipFeaturesAction );
   mStyleItemsListWidget->advancedMenu()->removeAction( mStandardizeRingsAction );
   mStyleItemsListWidget->advancedMenu()->removeAction( mAnimationSettingsAction );
+  mStyleItemsListWidget->advancedMenu()->removeAction( mBufferSettingsAction );
 }
 
 void QgsSymbolsListWidget::registerDataDefinedButton( QgsPropertyOverrideButton *button, QgsSymbolLayer::Property key )
 {
-  button->setProperty( "propertyKey", key );
+  button->setProperty( "propertyKey", static_cast<int>( key ) );
   button->registerExpressionContextGenerator( this );
 
   connect( button, &QgsPropertyOverrideButton::createAuxiliaryField, this, &QgsSymbolsListWidget::createAuxiliaryField );
@@ -166,8 +168,8 @@ void QgsSymbolsListWidget::createAuxiliaryField()
     return;
 
   QgsPropertyOverrideButton *button = qobject_cast<QgsPropertyOverrideButton *>( sender() );
-  const QgsSymbolLayer::Property key = static_cast<  QgsSymbolLayer::Property >( button->propertyKey() );
-  const QgsPropertyDefinition def = QgsSymbolLayer::propertyDefinitions()[key];
+  const QgsSymbolLayer::Property key = static_cast<QgsSymbolLayer::Property>( button->propertyKey() );
+  const QgsPropertyDefinition def = QgsSymbolLayer::propertyDefinitions()[static_cast<int>( key )];
 
   // create property in auxiliary storage if necessary
   if ( !mLayer->auxiliaryLayer()->exists( def ) )
@@ -184,12 +186,12 @@ void QgsSymbolsListWidget::createAuxiliaryField()
   QgsLineSymbol *lineSymbol = static_cast<QgsLineSymbol *>( mSymbol );
   switch ( key )
   {
-    case QgsSymbolLayer::PropertyAngle:
+    case QgsSymbolLayer::Property::Angle:
       if ( markerSymbol )
         markerSymbol->setDataDefinedAngle( button->toProperty() );
       break;
 
-    case QgsSymbolLayer::PropertySize:
+    case QgsSymbolLayer::Property::Size:
       if ( markerSymbol )
       {
         markerSymbol->setDataDefinedSize( button->toProperty() );
@@ -197,7 +199,7 @@ void QgsSymbolsListWidget::createAuxiliaryField()
       }
       break;
 
-    case QgsSymbolLayer::PropertyStrokeWidth:
+    case QgsSymbolLayer::Property::StrokeWidth:
       if ( lineSymbol )
         lineSymbol->setDataDefinedWidth( button->toProperty() );
       break;
@@ -223,8 +225,8 @@ void QgsSymbolsListWidget::createSymbolAuxiliaryField()
     return;
 
   QgsPropertyOverrideButton *button = qobject_cast<QgsPropertyOverrideButton *>( sender() );
-  const QgsSymbol::Property key = static_cast<  QgsSymbol::Property >( button->propertyKey() );
-  const QgsPropertyDefinition def = QgsSymbol::propertyDefinitions()[key];
+  const QgsSymbol::Property key = static_cast<QgsSymbol::Property>( button->propertyKey() );
+  const QgsPropertyDefinition def = QgsSymbol::propertyDefinitions()[static_cast<int>( key )];
 
   // create property in auxiliary storage if necessary
   if ( !mLayer->auxiliaryLayer()->exists( def ) )
@@ -274,8 +276,7 @@ void QgsSymbolsListWidget::showAnimationSettings()
     QgsSymbolAnimationSettingsWidget *widget = new QgsSymbolAnimationSettingsWidget( panel );
     widget->setPanelTitle( tr( "Animation Settings" ) );
     widget->setAnimationSettings( mSymbol->animationSettings() );
-    connect( widget, &QgsPanelWidget::widgetChanged, this, [ this, widget ]()
-    {
+    connect( widget, &QgsPanelWidget::widgetChanged, this, [this, widget]() {
       mSymbol->setAnimationSettings( widget->animationSettings() );
       emit changed();
     } );
@@ -292,6 +293,34 @@ void QgsSymbolsListWidget::showAnimationSettings()
   }
 }
 
+void QgsSymbolsListWidget::showBufferSettings()
+{
+  QgsPanelWidget *panel = QgsPanelWidget::findParentPanel( this );
+  if ( panel && panel->dockMode() )
+  {
+    QgsSymbolBufferSettingsWidget *widget = new QgsSymbolBufferSettingsWidget( panel );
+    widget->setPanelTitle( tr( "Buffer Settings" ) );
+    if ( const QgsSymbolBufferSettings *settings = mSymbol->bufferSettings() )
+      widget->setBufferSettings( *settings );
+
+    connect( widget, &QgsPanelWidget::widgetChanged, this, [this, widget]() {
+      mSymbol->setBufferSettings( new QgsSymbolBufferSettings( widget->bufferSettings() ) );
+      emit changed();
+    } );
+    panel->openPanel( widget );
+    return;
+  }
+
+  QgsSymbolBufferSettingsDialog d( this );
+  if ( const QgsSymbolBufferSettings *settings = mSymbol->bufferSettings() )
+    d.setBufferSettings( *settings );
+  if ( d.exec() == QDialog::Accepted )
+  {
+    mSymbol->setBufferSettings( new QgsSymbolBufferSettings( d.bufferSettings() ) );
+    emit changed();
+  }
+}
+
 void QgsSymbolsListWidget::saveSymbol()
 {
   QgsStyleSaveDialog saveDlg( this );
@@ -309,10 +338,7 @@ void QgsSymbolsListWidget::saveSymbol()
   // check if there is no symbol with same name
   if ( style->symbolNames().contains( saveDlg.name() ) )
   {
-    const int res = QMessageBox::warning( this, tr( "Save Symbol" ),
-                                          tr( "Symbol with name '%1' already exists. Overwrite?" )
-                                          .arg( saveDlg.name() ),
-                                          QMessageBox::Yes | QMessageBox::No );
+    const int res = QMessageBox::warning( this, tr( "Save Symbol" ), tr( "Symbol with name '%1' already exists. Overwrite?" ).arg( saveDlg.name() ), QMessageBox::Yes | QMessageBox::No );
     if ( res != QMessageBox::Yes )
     {
       return;
@@ -336,14 +362,14 @@ void QgsSymbolsListWidget::updateSymbolDataDefinedProperty()
     return;
 
   QgsPropertyOverrideButton *button = qobject_cast<QgsPropertyOverrideButton *>( sender() );
-  const QgsSymbol::Property key = static_cast<  QgsSymbol::Property >( button->propertyKey() );
+  const QgsSymbol::Property key = static_cast<QgsSymbol::Property>( button->propertyKey() );
   mSymbol->setDataDefinedProperty( key, button->toProperty() );
   emit changed();
 }
 
 void QgsSymbolsListWidget::registerSymbolDataDefinedButton( QgsPropertyOverrideButton *button, QgsSymbol::Property key )
 {
-  button->init( key, mSymbol ? mSymbol->dataDefinedProperties() : QgsPropertyCollection(), QgsSymbol::propertyDefinitions(), mLayer, true );
+  button->init( static_cast<int>( key ), mSymbol ? mSymbol->dataDefinedProperties() : QgsPropertyCollection(), QgsSymbol::propertyDefinitions(), mLayer, true );
   connect( button, &QgsPropertyOverrideButton::changed, this, &QgsSymbolsListWidget::updateSymbolDataDefinedProperty );
   connect( button, &QgsPropertyOverrideButton::createAuxiliaryField, this, &QgsSymbolsListWidget::createSymbolAuxiliaryField );
 
@@ -386,7 +412,8 @@ void QgsSymbolsListWidget::updateDataDefinedMarkerAngle()
   if ( // shall we remove datadefined expressions for layers ?
     ( !symbolDD && !dd )
     // shall we set the "en masse" expression for properties ?
-    || dd )
+    || dd
+  )
   {
     markerSymbol->setDataDefinedAngle( dd );
     emit changed();
@@ -414,7 +441,8 @@ void QgsSymbolsListWidget::updateDataDefinedMarkerSize()
   if ( // shall we remove datadefined expressions for layers ?
     ( !symbolDD && !dd )
     // shall we set the "en masse" expression for properties ?
-    || dd )
+    || dd
+  )
   {
     markerSymbol->setDataDefinedSize( dd );
     markerSymbol->setScaleMethod( Qgis::ScaleMethod::ScaleDiameter );
@@ -443,7 +471,8 @@ void QgsSymbolsListWidget::updateDataDefinedLineWidth()
   if ( // shall we remove datadefined expressions for layers ?
     ( !symbolDD && !dd )
     // shall we set the "en masse" expression for properties ?
-    || dd )
+    || dd
+  )
   {
     lineSymbol->setDataDefinedWidth( dd );
     emit changed();
@@ -463,7 +492,6 @@ void QgsSymbolsListWidget::mSymbolUnitWidget_changed()
 {
   if ( mSymbol )
   {
-
     mSymbol->setOutputUnit( mSymbolUnitWidget->unit() );
     mSymbol->setMapUnitScale( mSymbolUnitWidget->getMapUnitScale() );
 
@@ -502,13 +530,7 @@ QgsExpressionContext QgsSymbolsListWidget::createExpressionContext() const
     expContext.appendScope( new QgsExpressionContextScope( scope ) );
   }
 
-  expContext.setHighlightedVariables( QStringList() << QgsExpressionContext::EXPR_ORIGINAL_VALUE << QgsExpressionContext::EXPR_SYMBOL_COLOR
-                                      << QgsExpressionContext::EXPR_GEOMETRY_PART_COUNT << QgsExpressionContext::EXPR_GEOMETRY_PART_NUM
-                                      << QgsExpressionContext::EXPR_GEOMETRY_RING_NUM
-                                      << QgsExpressionContext::EXPR_GEOMETRY_POINT_COUNT << QgsExpressionContext::EXPR_GEOMETRY_POINT_NUM
-                                      << QgsExpressionContext::EXPR_CLUSTER_COLOR << QgsExpressionContext::EXPR_CLUSTER_SIZE
-                                      << QStringLiteral( "symbol_layer_count" ) << QStringLiteral( "symbol_layer_index" )
-                                      << QStringLiteral( "symbol_frame" ) );
+  expContext.setHighlightedVariables( QStringList() << QgsExpressionContext::EXPR_ORIGINAL_VALUE << QgsExpressionContext::EXPR_SYMBOL_COLOR << QgsExpressionContext::EXPR_GEOMETRY_PART_COUNT << QgsExpressionContext::EXPR_GEOMETRY_PART_NUM << QgsExpressionContext::EXPR_GEOMETRY_RING_NUM << QgsExpressionContext::EXPR_GEOMETRY_POINT_COUNT << QgsExpressionContext::EXPR_GEOMETRY_POINT_NUM << QgsExpressionContext::EXPR_CLUSTER_COLOR << QgsExpressionContext::EXPR_CLUSTER_SIZE << QStringLiteral( "symbol_layer_count" ) << QStringLiteral( "symbol_layer_index" ) << QStringLiteral( "symbol_frame" ) );
 
   return expContext;
 }
@@ -517,7 +539,7 @@ void QgsSymbolsListWidget::updateSymbolInfo()
 {
   updateSymbolColor();
 
-  const auto overrideButtons {findChildren< QgsPropertyOverrideButton * >()};
+  const auto overrideButtons { findChildren<QgsPropertyOverrideButton *>() };
   for ( QgsPropertyOverrideButton *button : overrideButtons )
   {
     button->registerExpressionContextGenerator( this );
@@ -532,10 +554,10 @@ void QgsSymbolsListWidget::updateSymbolInfo()
     if ( mLayer )
     {
       const QgsProperty ddSize( markerSymbol->dataDefinedSize() );
-      mSizeDDBtn->init( QgsSymbolLayer::PropertySize, ddSize, QgsSymbolLayer::propertyDefinitions(), mLayer, true );
+      mSizeDDBtn->init( static_cast<int>( QgsSymbolLayer::Property::Size ), ddSize, QgsSymbolLayer::propertyDefinitions(), mLayer, true );
       spinSize->setEnabled( !mSizeDDBtn->isActive() );
       const QgsProperty ddAngle( markerSymbol->dataDefinedAngle() );
-      mRotationDDBtn->init( QgsSymbolLayer::PropertyAngle, ddAngle, QgsSymbolLayer::propertyDefinitions(), mLayer, true );
+      mRotationDDBtn->init( static_cast<int>( QgsSymbolLayer::Property::Angle ), ddAngle, QgsSymbolLayer::propertyDefinitions(), mLayer, true );
       spinAngle->setEnabled( !mRotationDDBtn->isActive() );
     }
     else
@@ -552,7 +574,7 @@ void QgsSymbolsListWidget::updateSymbolInfo()
     if ( mLayer )
     {
       const QgsProperty dd( lineSymbol->dataDefinedWidth() );
-      mWidthDDBtn->init( QgsSymbolLayer::PropertyStrokeWidth, dd, QgsSymbolLayer::propertyDefinitions(), mLayer, true );
+      mWidthDDBtn->init( static_cast<int>( QgsSymbolLayer::Property::StrokeWidth ), dd, QgsSymbolLayer::propertyDefinitions(), mLayer, true );
       spinWidth->setEnabled( !mWidthDDBtn->isActive() );
     }
     else
@@ -570,19 +592,21 @@ void QgsSymbolsListWidget::updateSymbolInfo()
 
   // Clean up previous advanced symbol actions
   const QList<QAction *> actionList( mStyleItemsListWidget->advancedMenu()->actions() );
-  for ( const auto &action : actionList )
+  for ( QAction *action : actionList )
   {
-    if ( mClipFeaturesAction->text() == action->text() )
+    for ( QAction *actionsToRemove :
+          {
+            mClipFeaturesAction,
+            mStandardizeRingsAction,
+            mAnimationSettingsAction,
+            mBufferSettingsAction
+          } )
     {
-      mStyleItemsListWidget->advancedMenu()->removeAction( action );
-    }
-    else if ( mStandardizeRingsAction->text() == action->text() )
-    {
-      mStyleItemsListWidget->advancedMenu()->removeAction( action );
-    }
-    else if ( mAnimationSettingsAction->text() == action->text() )
-    {
-      mStyleItemsListWidget->advancedMenu()->removeAction( action );
+      if ( actionsToRemove->text() == action->text() )
+      {
+        mStyleItemsListWidget->advancedMenu()->removeAction( action );
+        break;
+      }
     }
   }
 
@@ -595,6 +619,10 @@ void QgsSymbolsListWidget::updateSymbolInfo()
   {
     mStyleItemsListWidget->advancedMenu()->addAction( mStandardizeRingsAction );
   }
+  if ( mSymbol->type() == Qgis::SymbolType::Marker )
+  {
+    mStyleItemsListWidget->advancedMenu()->addAction( mBufferSettingsAction );
+  }
   mStyleItemsListWidget->advancedMenu()->addAction( mAnimationSettingsAction );
 
   mStyleItemsListWidget->showAdvancedButton( mAdvancedMenu || !mStyleItemsListWidget->advancedMenu()->isEmpty() );
@@ -623,7 +651,7 @@ void QgsSymbolsListWidget::setSymbolFromStyle( const QString &name, QgsStyle::St
     return;
 
   // get new instance of symbol from style
-  std::unique_ptr< QgsSymbol > s( style->symbol( name ) );
+  std::unique_ptr<QgsSymbol> s( style->symbol( name ) );
   if ( !s )
     return;
 
