@@ -33,7 +33,7 @@ class QgsMapLayer;
 class QgsAttributeActionDialog;
 class QgsVectorLayer;
 class QgsLabelingWidget;
-class QgsDiagramProperties;
+class QgsDiagramWidget;
 class QgsSourceFieldsProperties;
 class QgsAttributesFormProperties;
 class QgsRendererPropertiesDialog;
@@ -59,7 +59,6 @@ class GUI_EXPORT QgsVectorLayerProperties : public QgsLayerPropertiesDialog, pri
     Q_OBJECT
 
   public:
-
     QgsVectorLayerProperties( QgsMapCanvas *canvas, QgsMessageBar *messageBar, QgsVectorLayer *lyr = nullptr, QWidget *parent = nullptr, Qt::WindowFlags fl = QgsGuiUtils::ModalDialogFlags );
 
     bool eventFilter( QObject *obj, QEvent *ev ) override;
@@ -72,7 +71,8 @@ class GUI_EXPORT QgsVectorLayerProperties : public QgsLayerPropertiesDialog, pri
 
   private slots:
 
-    void insertFieldOrExpression();
+    void insertField();
+    void insertOrEditExpression();
 
     //! Gets metadata about the layer in nice formatted html
     QString htmlMetadata();
@@ -137,7 +137,6 @@ class GUI_EXPORT QgsVectorLayerProperties : public QgsLayerPropertiesDialog, pri
     void resizeMapTip();
 
   private:
-
     enum PropertyType
     {
       Style = 0,
@@ -171,16 +170,14 @@ class GUI_EXPORT QgsVectorLayerProperties : public QgsLayerPropertiesDialog, pri
     //! Actions dialog. If apply is pressed, the actions are stored for later use
     QgsAttributeActionDialog *mActionDialog = nullptr;
     //! Diagram dialog. If apply is pressed, options are applied to vector's diagrams
-    QgsDiagramProperties *diagramPropertiesDialog = nullptr;
+    QgsDiagramWidget *diagramPropertiesDialog = nullptr;
     //! SourceFields dialog. If apply is pressed, options are applied to vector's diagrams
     QgsSourceFieldsProperties *mSourceFieldsPropertiesDialog = nullptr;
     //! AttributesForm dialog. If apply is pressed, options are applied to vector's diagrams
     QgsAttributesFormProperties *mAttributesFormPropertiesDialog = nullptr;
 
     //! List of joins of a layer at the time of creation of the dialog. Used to return joins to previous state if dialog is canceled
-    QList< QgsVectorLayerJoinInfo > mOldJoins;
-
-    void initDiagramTab();
+    QList<QgsVectorLayerJoinInfo> mOldJoins;
 
     //! Adds a new join to mJoinTreeWidget
     void addJoinToTreeWidget( const QgsVectorLayerJoinInfo &join, int insertIndex = -1 );
@@ -227,6 +224,7 @@ class GUI_EXPORT QgsVectorLayerProperties : public QgsLayerPropertiesDialog, pri
     void openPanel( QgsPanelWidget *panel );
 
     friend class QgsAppScreenShots;
+    friend class TestQgsLayerPropertiesDialogs;
 };
 
 #endif
