@@ -14,9 +14,10 @@
  ***************************************************************************/
 
 #include "qgsoapifoptionsrequest.h"
+#include "moc_qgsoapifoptionsrequest.cpp"
 
-QgsOapifOptionsRequest::QgsOapifOptionsRequest( const QgsDataSourceUri &uri ):
-  QgsBaseNetworkRequest( QgsAuthorizationSettings( uri.username(), uri.password(), uri.authConfigId() ), "OAPIF" )
+QgsOapifOptionsRequest::QgsOapifOptionsRequest( const QgsDataSourceUri &uri )
+  : QgsBaseNetworkRequest( QgsAuthorizationSettings( uri.username(), uri.password(), QgsHttpHeaders(), uri.authConfigId() ), "OAPIF" )
 {
 }
 
