@@ -15,6 +15,7 @@
 
 #include "QtGlobal"
 
+#include "qgsmessagelog.h"
 #include "qgswfsconstants.h"
 #include "qgswfsdatasourceuri.h"
 #include "qgsmessagelog.h"
@@ -193,6 +194,7 @@ QSet<QString> QgsWFSDataSourceURI::unknownParamKeys() const
     QgsWFSConstants::URI_PARAM_SKIP_INITIAL_GET_FEATURE,
     QgsWFSConstants::URI_PARAM_GEOMETRY_TYPE_FILTER,
     QgsWFSConstants::URI_PARAM_SQL,
+    QgsWFSConstants::URI_PARAM_FEATURE_MODE,
   };
 
   QSet<QString> l_unknownParamKeys;
@@ -457,6 +459,24 @@ bool QgsWFSDataSourceURI::skipInitialGetFeature() const
   return mURI.param( QgsWFSConstants::URI_PARAM_SKIP_INITIAL_GET_FEATURE ).toUpper() == QLatin1String( "TRUE" );
 }
 
+QgsWFSDataSourceURI::FeatureMode QgsWFSDataSourceURI::featureMode() const
+{
+  if ( !mURI.hasParam( QgsWFSConstants::URI_PARAM_FEATURE_MODE ) )
+    return FeatureMode::Default;
+  const QString val = mURI.param( QgsWFSConstants::URI_PARAM_FEATURE_MODE );
+  if ( val == QLatin1String( "default" ) )
+    return FeatureMode::Default;
+  else if ( val == QLatin1String( "simpleFeatures" ) )
+    return FeatureMode::SimpleFeatures;
+  else if ( val == QLatin1String( "complexFeatures" ) )
+    return FeatureMode::ComplexFeatures;
+  else
+  {
+    QgsMessageLog::logMessage( QObject::tr( "Unknown value for featureMode URI parameter '%1'" ).arg( val ), QObject::tr( "WFS" ) );
+    return FeatureMode::Default;
+  }
+}
+
 QString QgsWFSDataSourceURI::build( const QString &baseUri, const QString &typeName, const QString &crsString, const QString &sql, const QString &filter, bool restrictToCurrentViewExtent )
 {
   QgsWFSDataSourceURI uri( baseUri );
