@@ -39,19 +39,18 @@ class QgsWFSItemDelegate : public QItemDelegate
     Q_OBJECT
 
   public:
-    explicit QgsWFSItemDelegate( QObject *parent = nullptr ) : QItemDelegate( parent ) { }
+    explicit QgsWFSItemDelegate( QObject *parent = nullptr )
+      : QItemDelegate( parent ) {}
 
     QSize sizeHint( const QStyleOptionViewItem &option, const QModelIndex &index ) const override;
-
 };
 
-class QgsWFSSourceSelect: public QgsAbstractDataSourceWidget, private Ui::QgsWFSSourceSelectBase
+class QgsWFSSourceSelect : public QgsAbstractDataSourceWidget, private Ui::QgsWFSSourceSelectBase
 {
     Q_OBJECT
 
   public:
-
-    QgsWFSSourceSelect( QWidget *parent = nullptr, Qt::WindowFlags fl = QgsGuiUtils::ModalDialogFlags, QgsProviderRegistry::WidgetMode widgetMode = QgsProviderRegistry::WidgetMode::None );
+    QgsWFSSourceSelect( QWidget *parent = nullptr, Qt::WindowFlags fl = QgsGuiUtils::ModalDialogFlags, QgsProviderRegistry::WidgetMode widgetMode = QgsProviderRegistry::WidgetMode::Standalone );
     ~QgsWFSSourceSelect() override;
 
     void reset() override;
@@ -65,11 +64,11 @@ class QgsWFSSourceSelect: public QgsAbstractDataSourceWidget, private Ui::QgsWFS
      * The first string is the typename, the corresponding list
      * stores the CRS for the typename in the form 'EPSG:XXXX'
     */
-    QMap<QString, QStringList > mAvailableCRS;
+    QMap<QString, QStringList> mAvailableCRS;
     std::unique_ptr<QgsWfsCapabilities> mCapabilities;
     std::unique_ptr<QgsOapifLandingPageRequest> mOAPIFLandingPage;
     std::unique_ptr<QgsOapifCollectionsRequest> mOAPIFCollections;
-    QString mUri;            // data source URI
+    QString mUri; // data source URI
     QgsWFSItemDelegate *mItemDelegate = nullptr;
     QStandardItemModel *mModel = nullptr;
     QSortFilterProxyModel *mModelProxy = nullptr;
