@@ -19,7 +19,7 @@
 #include "qgsserverinterface.h"
 
 //! Constructor
-QgsServerInterface::QgsServerInterface():
-  mConfigFilePath( QString() )
+QgsServerInterface::QgsServerInterface()
+  : mConfigFilePath( QString() )
 {
 }
