@@ -19,13 +19,13 @@
 #include "qgsproject.h"
 #include "qgsmessagelog.h"
 
-double  QgsServerProjectUtils::ceilWithPrecision( double number, int places )
+double QgsServerProjectUtils::ceilWithPrecision( double number, int places )
 {
   const double scaleFactor = std::pow( 10.0, places );
   return ( std::ceil( number * scaleFactor ) / scaleFactor );
 }
 
-double  QgsServerProjectUtils::floorWithPrecision( double number, int places )
+double QgsServerProjectUtils::floorWithPrecision( double number, int places )
 {
   const double scaleFactor = std::pow( 10.0, places );
   return ( std::floor( number * scaleFactor ) / scaleFactor );
@@ -78,7 +78,7 @@ QString QgsServerProjectUtils::owsServiceOnlineResource( const QgsProject &proje
   QString wmsOnlineResource = project.readEntry( QStringLiteral( "WMSOnlineResource" ), QStringLiteral( "/" ) );
 
   const QgsProperty wmsOnlineResourceProperty = project.dataDefinedServerProperties().property( QgsProject::DataDefinedServerProperty::WMSOnlineResource );
-  if ( wmsOnlineResourceProperty.isActive() && ! wmsOnlineResourceProperty.expressionString().isEmpty() )
+  if ( wmsOnlineResourceProperty.isActive() && !wmsOnlineResourceProperty.expressionString().isEmpty() )
   {
     const QgsExpressionContext context = project.createExpressionContext();
     return wmsOnlineResourceProperty.valueAsString( context, wmsOnlineResource );
@@ -195,6 +195,11 @@ bool QgsServerProjectUtils::wmsAddLegendGroupsLegendGraphic( const QgsProject &p
          || legendGroups.compare( QLatin1String( "true" ), Qt::CaseInsensitive ) == 0;
 }
 
+bool QgsServerProjectUtils::wmsSkipNameForGroup( const QgsProject &project )
+{
+  return project.readBoolEntry( QStringLiteral( "WMSSkipNameForGroup" ), QStringLiteral( "/" ), false );
+}
+
 int QgsServerProjectUtils::wmsFeatureInfoPrecision( const QgsProject &project )
 {
   return project.readNumEntry( QStringLiteral( "WMSPrecision" ), QStringLiteral( "/" ), 6 );
@@ -326,7 +331,7 @@ QString QgsServerProjectUtils::serviceUrl( const QString &service, const QgsServ
 {
   const QString serviceUpper = service.toUpper();
   QString url = settings.serviceUrl( serviceUpper );
-  if ( ! url.isEmpty() )
+  if ( !url.isEmpty() )
   {
     return url;
   }
@@ -349,12 +354,12 @@ QString QgsServerProjectUtils::serviceUrl( const QString &service, const QgsServ
     header = QgsServerRequest::RequestHeader::X_QGIS_WMTS_SERVICE_URL;
   }
   url = request.header( header );
-  if ( ! url.isEmpty() )
+  if ( !url.isEmpty() )
   {
     return url;
   }
   url = request.header( QgsServerRequest::RequestHeader::X_QGIS_SERVICE_URL );
-  if ( ! url.isEmpty() )
+  if ( !url.isEmpty() )
   {
     return url;
   }
@@ -363,7 +368,7 @@ QString QgsServerProjectUtils::serviceUrl( const QString &service, const QgsServ
   QString host;
 
   QString forwarded = request.header( QgsServerRequest::FORWARDED );
-  if ( ! forwarded.isEmpty() )
+  if ( !forwarded.isEmpty() )
   {
     forwarded = forwarded.split( QLatin1Char( ',' ) )[0];
     const QStringList elements = forwarded.split( ';' );
@@ -393,12 +398,12 @@ QString QgsServerProjectUtils::serviceUrl( const QString &service, const QgsServ
   }
 
   QUrl urlQUrl = request.baseUrl();
-  if ( ! proto.isEmpty() )
+  if ( !proto.isEmpty() )
   {
     urlQUrl.setScheme( proto );
   }
 
-  if ( ! host.isEmpty() )
+  if ( !host.isEmpty() )
   {
     QStringList hostPort = host.split( QLatin1Char( ':' ) );
     if ( hostPort.length() == 1 )
@@ -415,7 +420,7 @@ QString QgsServerProjectUtils::serviceUrl( const QString &service, const QgsServ
 
   // https://docs.qgis.org/3.16/en/docs/server_manual/services.html#wms-map
   const QUrlQuery query { request.originalUrl().query() };
-  const QList<QPair<QString, QString>> constItems { query.queryItems( ) };
+  const QList<QPair<QString, QString>> constItems { query.queryItems() };
   QString map;
   for ( const QPair<QString, QString> &item : std::as_const( constItems ) )
   {
@@ -426,10 +431,10 @@ QString QgsServerProjectUtils::serviceUrl( const QString &service, const QgsServ
     }
   }
 
-  if ( ! map.isEmpty() )
+  if ( !map.isEmpty() )
   {
     QUrlQuery query;
-    query.setQueryItems( {{"MAP", map}} );
+    query.setQueryItems( { { "MAP", map } } );
     urlQUrl.setQuery( query );
   }
   else
@@ -440,7 +445,7 @@ QString QgsServerProjectUtils::serviceUrl( const QString &service, const QgsServ
   return urlQUrl.url();
 }
 
-QString QgsServerProjectUtils::wmsServiceUrl( const QgsProject &project, const  QgsServerRequest &request, const QgsServerSettings &settings )
+QString QgsServerProjectUtils::wmsServiceUrl( const QgsProject &project, const QgsServerRequest &request, const QgsServerSettings &settings )
 {
   QString url = project.readEntry( QStringLiteral( "WMSUrl" ), QStringLiteral( "/" ), "" );
   if ( url.isEmpty() )
@@ -469,10 +474,10 @@ QgsRectangle QgsServerProjectUtils::wmsExtent( const QgsProject &project )
     return QgsRectangle();
   }
   //order of value elements must be xmin, ymin, xmax, ymax
-  const double xmin = values[ 0 ].toDouble();
-  const double ymin = values[ 1 ].toDouble();
-  const double xmax = values[ 2 ].toDouble();
-  const double ymax = values[ 3 ].toDouble();
+  const double xmin = values[0].toDouble();
+  const double ymin = values[1].toDouble();
+  const double xmax = values[2].toDouble();
+  const double ymax = values[3].toDouble();
   return QgsRectangle( xmin, ymin, xmax, ymax );
 }
 
@@ -540,4 +545,3 @@ bool QgsServerProjectUtils::wmsRenderMapTiles( const QgsProject &project )
 {
   return project.readBoolEntry( QStringLiteral( "RenderMapTile" ), QStringLiteral( "/" ), false );
 }
-
