@@ -33,19 +33,17 @@ class QgsRectangle;
 #ifdef SIP_RUN
 % ModuleHeaderCode
 #include "qgsserverprojectutils.h"
-% End
+  % End
 #endif
 
 
-/**
+  /**
  * \ingroup server
  * \brief The QgsServerProjectUtils namespace provides a way to retrieve specific
  * entries from a QgsProject.
- * \since QGIS 3.0
  */
-namespace QgsServerProjectUtils
+  namespace QgsServerProjectUtils
 {
-
   /**
    * Returns a double greater than \a number to the specified number of \a places.
    *
@@ -244,6 +242,14 @@ namespace QgsServerProjectUtils
    */
   SERVER_EXPORT bool wmsAddLegendGroupsLegendGraphic( const QgsProject &project );
 
+  /**
+   * Returns if name attribute should be skipped for groups in WMS capabilities document.
+   * \param project the QGIS project
+   * \returns if name attribute should be skipped for groups in capabilities
+   * \since QGIS 3.36
+   */
+  SERVER_EXPORT bool wmsSkipNameForGroup( const QgsProject &project );
+
   /**
    * Returns the geometry precision for GetFeatureInfo request.
    * \param project the QGIS project
@@ -365,7 +371,7 @@ namespace QgsServerProjectUtils
    * \param project the QGIS project
    * \returns the WMS Extent restriction.
    */
-  SERVER_EXPORT  QgsRectangle wmsExtent( const QgsProject &project );
+  SERVER_EXPORT QgsRectangle wmsExtent( const QgsProject &project );
 
   /**
    * Returns the WFS service url.
@@ -392,7 +398,7 @@ namespace QgsServerProjectUtils
    * \return the layer precision for WFS GetFeature.
    */
 
-  SERVER_EXPORT  int wfsLayerPrecision( const QgsProject &project, const QString &layerId );
+  SERVER_EXPORT int wfsLayerPrecision( const QgsProject &project, const QString &layerId );
 
   /**
    * Returns the Layer ids list defined in a QGIS project as published as WFS-T with update capabilities.
