@@ -13,27 +13,25 @@
  *                                                                         *
  ***************************************************************************/
 
+#include "qgsoffscreen3dengine.h"
 #include "qgstest.h"
 #include "qgsmultirenderchecker.h"
 
 #include "qgsproject.h"
 #include "qgsapplication.h"
 #include "qgs3d.h"
-
-#include "qgs3dmapscene.h"
-#include "qgs3dmapsettings.h"
-#include "qgs3dutils.h"
-#include "qgscameracontroller.h"
-#include "qgsoffscreen3dengine.h"
 #include "qgspointcloudlayer.h"
-#include "qgspointcloudlayerrenderer.h"
 #include "qgspointcloudextentrenderer.h"
 #include "qgspointcloudattributebyramprenderer.h"
 #include "qgspointcloudrgbrenderer.h"
 #include "qgspointcloudclassifiedrenderer.h"
 #include "qgspointcloudlayer3drenderer.h"
 #include "qgspointcloud3dsymbol.h"
+#include "qgspointlightsettings.h"
 #include "qgsstyle.h"
+#include "qgs3dutils.h"
+#include "qgs3dmapsettings.h"
+#include "qgs3dmapscene.h"
 
 #include <QFileInfo>
 #include <QDir>
@@ -42,44 +40,30 @@ class TestQgsPointCloud3DRendering : public QgsTest
 {
     Q_OBJECT
   public:
-    TestQgsPointCloud3DRendering() : QgsTest( QStringLiteral( "Point Cloud 3D Rendering Tests" ) ) {}
+    TestQgsPointCloud3DRendering()
+      : QgsTest( QStringLiteral( "Point Cloud 3D Rendering Tests" ), QStringLiteral( "3d" ) ) {}
 
   private slots:
-    void initTestCase();// will be called before the first testfunction is executed.
-    void cleanupTestCase();// will be called after the last testfunction was executed.
+    void initTestCase();    // will be called before the first testfunction is executed.
+    void cleanupTestCase(); // will be called after the last testfunction was executed.
     void testSync3DRendererTo2DRenderer();
     void testDisableSync3DRendererTo2DRenderer();
 
-//    void testPointCloudSingleColor();
-//    void testPointCloudAttributeByRamp();
-//    void testPointCloudRgb();
-//    void testPointCloudClassification();
-//    void testPointCloudSyncedTo2D();
+    void testPointCloudSingleColor();
+    void testPointCloudSingleColorClipping();
+    void testPointCloudAttributeByRamp();
+    void testPointCloudClassification();
+    void testPointCloudClassificationOverridePointSizes();
+
+    void testPointCloudFilteredClassification();
+    void testPointCloudFilteredSceneExtent();
 
 
   private:
-    bool renderCheck( const QString &testName, QImage &image, int mismatchCount = 0 );
-
     std::unique_ptr<QgsProject> mProject;
     QgsPointCloudLayer *mLayer;
-
 };
 
-bool TestQgsPointCloud3DRendering::renderCheck( const QString &testName, QImage &image, int mismatchCount )
-{
-  const QString myTmpDir = QDir::tempPath() + '/';
-  const QString myFileName = myTmpDir + testName + ".png";
-  image.save( myFileName, "PNG" );
-  QgsMultiRenderChecker myChecker;
-  myChecker.setControlPathPrefix( QStringLiteral( "3d" ) );
-  myChecker.setControlName( "expected_" + testName );
-  myChecker.setRenderedImage( myFileName );
-  myChecker.setColorTolerance( 2 );  // color tolerance < 2 was failing polygon3d_extrusion test
-  const bool myResultFlag = myChecker.runTest( testName, mismatchCount );
-  mReport += myChecker.report();
-  return myResultFlag;
-}
-
 //runs before all tests
 void TestQgsPointCloud3DRendering::initTestCase()
 {
@@ -92,7 +76,7 @@ void TestQgsPointCloud3DRendering::initTestCase()
 
   const QString dataDir( TEST_DATA_DIR );
 
-  mLayer = new QgsPointCloudLayer( dataDir + "/point_clouds/ept/rgb/ept.json", "test", "ept" );
+  mLayer = new QgsPointCloudLayer( dataDir + "/point_clouds/ept/sunshine-coast-laz/ept.json", "test", "ept" );
   QVERIFY( mLayer->isValid() );
   mProject->addMapLayer( mLayer );
   mProject->setCrs( mLayer->crs() );
@@ -122,15 +106,17 @@ void TestQgsPointCloud3DRendering::testSync3DRendererTo2DRenderer()
   shader.setSourceColorRamp( QgsStyle::defaultStyle()->colorRamp( QStringLiteral( "Viridis" ) ) );
   shader.classifyColorRamp( 5, -1, QgsRectangle(), nullptr );
   colorramp2DRenderer->setColorRampShader( shader );
-  QgsPointCloudRgbRenderer *rgb2DRenderer = dynamic_cast<QgsPointCloudRgbRenderer *>( mLayer->renderer()->clone() );
+  QgsPointCloudRgbRenderer *rgb2DRenderer = new QgsPointCloudRgbRenderer();
   QgsPointCloudClassifiedRenderer *classification2DRenderer = new QgsPointCloudClassifiedRenderer();
   classification2DRenderer->setAttribute( QStringLiteral( "Classification" ) );
   auto categories = QgsPointCloudClassifiedRenderer::defaultCategories();
   // change a couple of categories
-  categories[3].setRenderState( false );
-  categories[3].setColor( QColor( 255, 0, 0 ) );
+  categories[2].setRenderState( false );
+  categories[2].setColor( QColor( 255, 0, 0 ) );
+  categories[2].setPointSize( 7 );
   categories[5].setRenderState( false );
   categories[5].setColor( QColor( 0, 255, 0 ) );
+  categories[5].setPointSize( 10 );
   classification2DRenderer->setCategories( categories );
 
   // enable syncing, the 3D renderer should change when the 2D renderer changes
@@ -197,10 +183,12 @@ void TestQgsPointCloud3DRendering::testDisableSync3DRendererTo2DRenderer()
   classification2DRenderer->setAttribute( QStringLiteral( "Classification" ) );
   auto categories = QgsPointCloudClassifiedRenderer::defaultCategories();
   // change a couple of categories
-  categories[3].setRenderState( false );
-  categories[3].setColor( QColor( 255, 0, 0 ) );
+  categories[2].setRenderState( false );
+  categories[2].setColor( QColor( 255, 0, 0 ) );
+  categories[2].setPointSize( 7 );
   categories[5].setRenderState( false );
   categories[5].setColor( QColor( 0, 255, 0 ) );
+  categories[5].setPointSize( 10 );
   classification2DRenderer->setCategories( categories );
 
 
@@ -232,27 +220,26 @@ void TestQgsPointCloud3DRendering::testDisableSync3DRendererTo2DRenderer()
 
   {
     mLayer->setRenderer( colorramp2DRenderer );
-    QgsPointCloudLayer3DRenderer *r3D  = static_cast<QgsPointCloudLayer3DRenderer *>( mLayer->renderer3D() );
+    QgsPointCloudLayer3DRenderer *r3D = static_cast<QgsPointCloudLayer3DRenderer *>( mLayer->renderer3D() );
     QVERIFY( r3D );
-    const QgsColorRampPointCloud3DSymbol *s = dynamic_cast<const QgsColorRampPointCloud3DSymbol *>( r3D ->symbol() );
+    const QgsColorRampPointCloud3DSymbol *s = dynamic_cast<const QgsColorRampPointCloud3DSymbol *>( r3D->symbol() );
     QVERIFY( s );
   }
   {
     mLayer->setRenderer( rgb2DRenderer );
-    QgsPointCloudLayer3DRenderer *r3D  = static_cast<QgsPointCloudLayer3DRenderer *>( mLayer->renderer3D() );
+    QgsPointCloudLayer3DRenderer *r3D = static_cast<QgsPointCloudLayer3DRenderer *>( mLayer->renderer3D() );
     QVERIFY( r3D );
-    const QgsColorRampPointCloud3DSymbol *s = dynamic_cast<const QgsColorRampPointCloud3DSymbol *>( r3D ->symbol() );
+    const QgsColorRampPointCloud3DSymbol *s = dynamic_cast<const QgsColorRampPointCloud3DSymbol *>( r3D->symbol() );
     QVERIFY( s );
   }
   {
     mLayer->setRenderer( classification2DRenderer );
-    QgsPointCloudLayer3DRenderer *r3D  = static_cast<QgsPointCloudLayer3DRenderer *>( mLayer->renderer3D() );
+    QgsPointCloudLayer3DRenderer *r3D = static_cast<QgsPointCloudLayer3DRenderer *>( mLayer->renderer3D() );
     QVERIFY( r3D );
-    const QgsColorRampPointCloud3DSymbol *s = dynamic_cast<const QgsColorRampPointCloud3DSymbol *>( r3D ->symbol() );
+    const QgsColorRampPointCloud3DSymbol *s = dynamic_cast<const QgsColorRampPointCloud3DSymbol *>( r3D->symbol() );
     QVERIFY( s );
   }
 }
-/*
 
 void TestQgsPointCloud3DRendering::testPointCloudSingleColor()
 {
@@ -265,7 +252,7 @@ void TestQgsPointCloud3DRendering::testPointCloudSingleColor()
   QgsPointLightSettings defaultLight;
   defaultLight.setIntensity( 0.5 );
   defaultLight.setPosition( QgsVector3D( 0, 1000, 0 ) );
-  map->setPointLights( QList<QgsPointLightSettings>() << defaultLight );
+  map->setLightSources( { defaultLight.clone() } );
 
   QgsOffscreen3DEngine engine;
   Qgs3DMapScene *scene = new Qgs3DMapScene( *map, &engine );
@@ -273,19 +260,72 @@ void TestQgsPointCloud3DRendering::testPointCloudSingleColor()
 
   QgsSingleColorPointCloud3DSymbol *symbol = new QgsSingleColorPointCloud3DSymbol();
   symbol->setSingleColor( QColor( 255, 0, 0 ) );
+  symbol->setPointSize( 10 );
 
   QgsPointCloudLayer3DRenderer *renderer = new QgsPointCloudLayer3DRenderer();
   renderer->setSymbol( symbol );
   mLayer->setRenderer3D( renderer );
 
+  scene->cameraController()->resetView( 90 );
   Qgs3DUtils::captureSceneImage( engine, scene );
   // When running the test on Travis, it would initially return empty rendered image.
   // Capturing the initial image and throwing it away fixes that. Hopefully we will
   // find a better fix in the future.
-  scene->cameraController()->resetView( 2.5 );
   QImage img = Qgs3DUtils::captureSceneImage( engine, scene );
 
-  QVERIFY( renderCheck( "pointcloud_3d_singlecolor", img, 40 ) );
+  QGSVERIFYIMAGECHECK( "pointcloud_3d_singlecolor", "pointcloud_3d_singlecolor", img, QString(), 80, QSize( 0, 0 ), 15 );
+}
+
+void TestQgsPointCloud3DRendering::testPointCloudSingleColorClipping()
+{
+  const QgsRectangle fullExtent = mLayer->extent();
+
+  Qgs3DMapSettings *map = new Qgs3DMapSettings;
+  map->setCrs( mProject->crs() );
+  map->setOrigin( QgsVector3D( fullExtent.center().x(), fullExtent.center().y(), 0 ) );
+  map->setLayers( QList<QgsMapLayer *>() << mLayer );
+  QgsPointLightSettings defaultLight;
+  defaultLight.setIntensity( 0.5 );
+  defaultLight.setPosition( QgsVector3D( 0, 1000, 0 ) );
+  map->setLightSources( { defaultLight.clone() } );
+
+  QgsOffscreen3DEngine engine;
+  Qgs3DMapScene *scene = new Qgs3DMapScene( *map, &engine );
+  engine.setRootEntity( scene );
+
+  QgsSingleColorPointCloud3DSymbol *symbol = new QgsSingleColorPointCloud3DSymbol();
+  symbol->setSingleColor( QColor( 255, 0, 0 ) );
+  symbol->setPointSize( 10 );
+
+  QgsPointCloudLayer3DRenderer *renderer = new QgsPointCloudLayer3DRenderer();
+  renderer->setSymbol( symbol );
+  mLayer->setRenderer3D( renderer );
+
+  scene->cameraController()->resetView( 90 );
+
+  QList<QVector4D> clipPlanesEquations = QList<QVector4D>()
+                                         << QVector4D( 0.866025, 0, 0.5, 1.0 )
+                                         << QVector4D( 0.5, 0, -0.866025, 0.5 );
+  scene->enableClipping( clipPlanesEquations );
+
+
+  Qgs3DUtils::captureSceneImage( engine, scene );
+  // When running the test on Travis, it would initially return empty rendered image.
+  // Capturing the initial image and throwing it away fixes that. Hopefully we will
+  // find a better fix in the future.
+  QImage img = Qgs3DUtils::captureSceneImage( engine, scene );
+
+  QGSVERIFYIMAGECHECK( "pointcloud_3d_singlecolor_clipping", "pointcloud_3d_singlecolor_clipping", img, QString(), 80, QSize( 0, 0 ), 15 );
+
+  scene->disableClipping();
+
+  Qgs3DUtils::captureSceneImage( engine, scene );
+  // When running the test on Travis, it would initially return empty rendered image.
+  // Capturing the initial image and throwing it away fixes that. Hopefully we will
+  // find a better fix in the future.
+  QImage img2 = Qgs3DUtils::captureSceneImage( engine, scene );
+
+  QGSVERIFYIMAGECHECK( "pointcloud_3d_singlecolor", "pointcloud_3d_singlecolor", img2, QString(), 80, QSize( 0, 0 ), 15 );
 }
 
 void TestQgsPointCloud3DRendering::testPointCloudAttributeByRamp()
@@ -299,83 +339,32 @@ void TestQgsPointCloud3DRendering::testPointCloudAttributeByRamp()
   QgsPointLightSettings defaultLight;
   defaultLight.setIntensity( 0.5 );
   defaultLight.setPosition( QgsVector3D( 0, 1000, 0 ) );
-  map->setPointLights( QList<QgsPointLightSettings>() << defaultLight );
+  map->setLightSources( { defaultLight.clone() } );
 
   QgsOffscreen3DEngine engine;
   Qgs3DMapScene *scene = new Qgs3DMapScene( *map, &engine );
   engine.setRootEntity( scene );
 
   QgsColorRampPointCloud3DSymbol *symbol = new QgsColorRampPointCloud3DSymbol();
-  symbol->setAttribute( QStringLiteral( "Z" ) );
-  QgsColorRampShader shader = QgsColorRampShader( 0.98, 1.25 );
+  symbol->setAttribute( QStringLiteral( "Intensity" ) );
+  QgsColorRampShader shader = QgsColorRampShader( 199, 2086 );
   shader.setSourceColorRamp( QgsStyle::defaultStyle()->colorRamp( QStringLiteral( "Viridis" ) ) );
   shader.classifyColorRamp( 5, -1, QgsRectangle(), nullptr );
   symbol->setColorRampShader( shader );
+  symbol->setPointSize( 10 );
 
   QgsPointCloudLayer3DRenderer *renderer = new QgsPointCloudLayer3DRenderer();
   renderer->setSymbol( symbol );
   mLayer->setRenderer3D( renderer );
 
+  scene->cameraController()->resetView( 90 );
   Qgs3DUtils::captureSceneImage( engine, scene );
   // When running the test on Travis, it would initially return empty rendered image.
   // Capturing the initial image and throwing it away fixes that. Hopefully we will
   // find a better fix in the future.
-  scene->cameraController()->resetView( 2.5 );
   QImage img = Qgs3DUtils::captureSceneImage( engine, scene );
 
-  QVERIFY( renderCheck( "pointcloud_3d_colorramp", img, 40 ) );
-}
-
-void TestQgsPointCloud3DRendering::testPointCloudRgb()
-{
-  const QgsRectangle fullExtent = mLayer->extent();
-
-  Qgs3DMapSettings *map = new Qgs3DMapSettings;
-  map->setCrs( mProject->crs() );
-  map->setOrigin( QgsVector3D( fullExtent.center().x(), fullExtent.center().y(), 0 ) );
-  map->setLayers( QList<QgsMapLayer *>() << mLayer );
-  QgsPointLightSettings defaultLight;
-  defaultLight.setIntensity( 0.5 );
-  defaultLight.setPosition( QgsVector3D( 0, 1000, 0 ) );
-  map->setPointLights( QList<QgsPointLightSettings>() << defaultLight );
-
-  QgsOffscreen3DEngine engine;
-  Qgs3DMapScene *scene = new Qgs3DMapScene( *map, &engine );
-  engine.setRootEntity( scene );
-
-  QgsRgbPointCloud3DSymbol *symbol = new QgsRgbPointCloud3DSymbol();
-  symbol->setRedAttribute( QStringLiteral( "Red" ) );
-  symbol->setGreenAttribute( QStringLiteral( "Green" ) );
-  symbol->setBlueAttribute( QStringLiteral( "Blue" ) );
-
-  QgsContrastEnhancement *redContrastEnhancement = new QgsContrastEnhancement( Qgis::DataType::UnknownDataType );
-  redContrastEnhancement->setMinimumValue( 0 );
-  redContrastEnhancement->setMaximumValue( 255 );
-  QgsContrastEnhancement *greenContrastEnhancement = new QgsContrastEnhancement( Qgis::DataType::UnknownDataType );
-  greenContrastEnhancement->setMinimumValue( 0 );
-  greenContrastEnhancement->setMaximumValue( 255 );
-  QgsContrastEnhancement *blueContrastEnhancement = new QgsContrastEnhancement( Qgis::DataType::UnknownDataType );
-  blueContrastEnhancement->setMinimumValue( 0 );
-  blueContrastEnhancement->setMaximumValue( 255 );
-  blueContrastEnhancement->setContrastEnhancementAlgorithm( QgsContrastEnhancement::ContrastEnhancementAlgorithm::StretchAndClipToMinimumMaximum );
-  greenContrastEnhancement->setContrastEnhancementAlgorithm( QgsContrastEnhancement::ContrastEnhancementAlgorithm::StretchAndClipToMinimumMaximum );
-  blueContrastEnhancement->setContrastEnhancementAlgorithm( QgsContrastEnhancement::ContrastEnhancementAlgorithm::StretchAndClipToMinimumMaximum );
-  symbol->setRedContrastEnhancement( redContrastEnhancement );
-  symbol->setGreenContrastEnhancement( greenContrastEnhancement );
-  symbol->setBlueContrastEnhancement( blueContrastEnhancement );
-
-  QgsPointCloudLayer3DRenderer *renderer = new QgsPointCloudLayer3DRenderer();
-  renderer->setSymbol( symbol );
-  mLayer->setRenderer3D( renderer );
-
-  Qgs3DUtils::captureSceneImage( engine, scene );
-  // When running the test on Travis, it would initially return empty rendered image.
-  // Capturing the initial image and throwing it away fixes that. Hopefully we will
-  // find a better fix in the future.
-  scene->cameraController()->resetView( 2.5 );
-  QImage img = Qgs3DUtils::captureSceneImage( engine, scene );
-
-  QVERIFY( renderCheck( "pointcloud_3d_rgb", img, 40 ) );
+  QGSVERIFYIMAGECHECK( "pointcloud_3d_colorramp", "pointcloud_3d_colorramp", img, QString(), 100, QSize( 0, 0 ), 15 );
 }
 
 void TestQgsPointCloud3DRendering::testPointCloudClassification()
@@ -389,7 +378,7 @@ void TestQgsPointCloud3DRendering::testPointCloudClassification()
   QgsPointLightSettings defaultLight;
   defaultLight.setIntensity( 0.5 );
   defaultLight.setPosition( QgsVector3D( 0, 1000, 0 ) );
-  map->setPointLights( QList<QgsPointLightSettings>() << defaultLight );
+  map->setLightSources( { defaultLight.clone() } );
 
   QgsOffscreen3DEngine engine;
   Qgs3DMapScene *scene = new Qgs3DMapScene( *map, &engine );
@@ -397,23 +386,25 @@ void TestQgsPointCloud3DRendering::testPointCloudClassification()
 
   QgsClassificationPointCloud3DSymbol *symbol = new QgsClassificationPointCloud3DSymbol();
   symbol->setAttribute( QStringLiteral( "Classification" ) );
-  symbol->setCategoriesList( QgsPointCloudClassifiedRenderer::defaultCategories() );
+  auto categories = QgsPointCloudClassifiedRenderer::defaultCategories();
+  symbol->setCategoriesList( categories );
+  symbol->setPointSize( 10 );
 
   QgsPointCloudLayer3DRenderer *renderer = new QgsPointCloudLayer3DRenderer();
   renderer->setSymbol( symbol );
   mLayer->setRenderer3D( renderer );
 
+  scene->cameraController()->resetView( 90 );
   Qgs3DUtils::captureSceneImage( engine, scene );
   // When running the test on Travis, it would initially return empty rendered image.
   // Capturing the initial image and throwing it away fixes that. Hopefully we will
   // find a better fix in the future.
-  scene->cameraController()->resetView( 2.5 );
   QImage img = Qgs3DUtils::captureSceneImage( engine, scene );
 
-  QVERIFY( renderCheck( "pointcloud_3d_classification", img, 40 ) );
+  QGSVERIFYIMAGECHECK( "pointcloud_3d_classification", "pointcloud_3d_classification", img, QString(), 100, QSize( 0, 0 ), 15 );
 }
 
-void TestQgsPointCloud3DRendering::testPointCloudSyncedTo2D()
+void TestQgsPointCloud3DRendering::testPointCloudClassificationOverridePointSizes()
 {
   const QgsRectangle fullExtent = mLayer->extent();
 
@@ -424,89 +415,112 @@ void TestQgsPointCloud3DRendering::testPointCloudSyncedTo2D()
   QgsPointLightSettings defaultLight;
   defaultLight.setIntensity( 0.5 );
   defaultLight.setPosition( QgsVector3D( 0, 1000, 0 ) );
-  map->setPointLights( QList<QgsPointLightSettings>() << defaultLight );
+  map->setLightSources( { defaultLight.clone() } );
 
   QgsOffscreen3DEngine engine;
   Qgs3DMapScene *scene = new Qgs3DMapScene( *map, &engine );
   engine.setRootEntity( scene );
 
+  QgsClassificationPointCloud3DSymbol *symbol = new QgsClassificationPointCloud3DSymbol();
+  symbol->setAttribute( QStringLiteral( "Classification" ) );
+  auto categories = QgsPointCloudClassifiedRenderer::defaultCategories();
+  categories[2].setPointSize( 4 );
+  categories[5].setPointSize( 7 );
+  symbol->setCategoriesList( categories );
+  symbol->setPointSize( 10 );
+
   QgsPointCloudLayer3DRenderer *renderer = new QgsPointCloudLayer3DRenderer();
+  renderer->setSymbol( symbol );
   mLayer->setRenderer3D( renderer );
 
-  // gather different 2D renderers
-  QgsPointCloudExtentRenderer *extent2DRenderer = new QgsPointCloudExtentRenderer();
-  QgsPointCloudAttributeByRampRenderer *colorramp2DRenderer = new QgsPointCloudAttributeByRampRenderer();
-  colorramp2DRenderer->setAttribute( QStringLiteral( "Z" ) );
-  QgsColorRampShader shader = QgsColorRampShader( 0.98, 1.25 );
-  shader.setSourceColorRamp( QgsStyle::defaultStyle()->colorRamp( QStringLiteral( "Viridis" ) ) );
-  shader.classifyColorRamp( 5, -1, QgsRectangle(), nullptr );
-  colorramp2DRenderer->setColorRampShader( shader );
-  QgsPointCloudRgbRenderer *rgb2DRenderer = dynamic_cast<QgsPointCloudRgbRenderer *>( mLayer->renderer()->clone() );
-  QgsPointCloudClassifiedRenderer *classification2DRenderer = new QgsPointCloudClassifiedRenderer();
-  classification2DRenderer->setAttribute( QStringLiteral( "Classification" ) );
-  classification2DRenderer->setCategories( QgsPointCloudClassifiedRenderer::defaultCategories() );
-
-  QgsPointCloudExtentRenderer *extent2DRenderer_2 = new QgsPointCloudExtentRenderer();
-  QgsPointCloudAttributeByRampRenderer *colorramp2DRenderer_2 = new QgsPointCloudAttributeByRampRenderer();
-  colorramp2DRenderer_2->setAttribute( QStringLiteral( "Z" ) );
-  QgsColorRampShader shader_2 = QgsColorRampShader( 0.98, 1.25 );
-  shader_2.setSourceColorRamp( QgsStyle::defaultStyle()->colorRamp( QStringLiteral( "Viridis" ) ) );
-  shader_2.classifyColorRamp( 5, -1, QgsRectangle(), nullptr );
-  colorramp2DRenderer_2->setColorRampShader( shader_2 );
-  QgsPointCloudRgbRenderer *rgb2DRenderer_2 = dynamic_cast<QgsPointCloudRgbRenderer *>( mLayer->renderer()->clone() );
-  QgsPointCloudClassifiedRenderer *classification2DRenderer_2 = new QgsPointCloudClassifiedRenderer();
-  classification2DRenderer_2->setAttribute( QStringLiteral( "Classification" ) );
-  classification2DRenderer_2->setCategories( QgsPointCloudClassifiedRenderer::defaultCategories() );
-
+  scene->cameraController()->resetView( 90 );
   Qgs3DUtils::captureSceneImage( engine, scene );
   // When running the test on Travis, it would initially return empty rendered image.
   // Capturing the initial image and throwing it away fixes that. Hopefully we will
   // find a better fix in the future.
-  scene->cameraController()->resetView( 2.5 );
-
-  // 3D symbols should now automatically change to match the 2D renderer
-  mLayer->setSync3DRendererTo2DRenderer( true );
-
-  // default 2D renderer is rgb for this pointcloud
   QImage img = Qgs3DUtils::captureSceneImage( engine, scene );
-  QVERIFY( renderCheck( "pointcloud_3d_rgb", img, 40 ) );
 
-  // extent renderer should not render anythin in 3D
-  mLayer->setRenderer( extent2DRenderer );
-  QImage img2 = Qgs3DUtils::captureSceneImage( engine, scene );
-  QVERIFY( renderCheck( "pointcloud_3d_norenderer", img2, 40 ) );
-
-  mLayer->setRenderer( colorramp2DRenderer );
-  QImage img3 = Qgs3DUtils::captureSceneImage( engine, scene );
-  QVERIFY( renderCheck( "pointcloud_3d_colorramp", img3, 40 ) );
-
-  mLayer->setRenderer( rgb2DRenderer );
-  QImage img4 = Qgs3DUtils::captureSceneImage( engine, scene );
-  QVERIFY( renderCheck( "pointcloud_3d_rgb", img4, 40 ) );
-
-  mLayer->setRenderer( classification2DRenderer );
-  QImage img5 = Qgs3DUtils::captureSceneImage( engine, scene );
-  QVERIFY( renderCheck( "pointcloud_3d_classification", img5, 40 ) );
-
-  // Now let's stop syncing, 3D symbol should stay at the last one used
-  mLayer->setSync3DRendererTo2DRenderer( false );
-
-  mLayer->setRenderer( extent2DRenderer_2 );
-  QImage img6 = Qgs3DUtils::captureSceneImage( engine, scene );
-  QVERIFY( renderCheck( "pointcloud_3d_classification", img6, 40 ) );
-
-  mLayer->setRenderer( colorramp2DRenderer_2 );
-  QImage img7 = Qgs3DUtils::captureSceneImage( engine, scene );
-  QVERIFY( renderCheck( "pointcloud_3d_classification", img7, 40 ) );
-
-  mLayer->setRenderer( rgb2DRenderer_2 );
-  QImage img8 = Qgs3DUtils::captureSceneImage( engine, scene );
-  QVERIFY( renderCheck( "pointcloud_3d_classification", img8, 40 ) );
-
-  mLayer->setRenderer( classification2DRenderer_2 );
-  QImage img9 = Qgs3DUtils::captureSceneImage( engine, scene );
-  QVERIFY( renderCheck( "pointcloud_3d_classification", img9, 40 ) );
+  QGSVERIFYIMAGECHECK( "pointcloud_3d_classification_pointsizes", "pointcloud_3d_classification_pointsizes", img, QString(), 40, QSize( 0, 0 ), 15 );
 }
-*/
+
+void TestQgsPointCloud3DRendering::testPointCloudFilteredClassification()
+{
+  mLayer->setSubsetString( "Classification = 2" );
+  const QgsRectangle fullExtent = mLayer->extent();
+
+  Qgs3DMapSettings *map = new Qgs3DMapSettings;
+  map->setCrs( mProject->crs() );
+  map->setOrigin( QgsVector3D( fullExtent.center().x(), fullExtent.center().y(), 0 ) );
+  map->setLayers( QList<QgsMapLayer *>() << mLayer );
+  QgsPointLightSettings defaultLight;
+  defaultLight.setIntensity( 0.5 );
+  defaultLight.setPosition( QgsVector3D( 0, 1000, 0 ) );
+  map->setLightSources( { defaultLight.clone() } );
+
+  QgsOffscreen3DEngine engine;
+  Qgs3DMapScene *scene = new Qgs3DMapScene( *map, &engine );
+  engine.setRootEntity( scene );
+
+  QgsClassificationPointCloud3DSymbol *symbol = new QgsClassificationPointCloud3DSymbol();
+  symbol->setAttribute( QStringLiteral( "Classification" ) );
+  auto categories = QgsPointCloudClassifiedRenderer::defaultCategories();
+  symbol->setCategoriesList( categories );
+  symbol->setPointSize( 10 );
+
+  QgsPointCloudLayer3DRenderer *renderer = new QgsPointCloudLayer3DRenderer();
+  renderer->setSymbol( symbol );
+  mLayer->setRenderer3D( renderer );
+
+  scene->cameraController()->resetView( 90 );
+  Qgs3DUtils::captureSceneImage( engine, scene );
+  // When running the test on Travis, it would initially return empty rendered image.
+  // Capturing the initial image and throwing it away fixes that. Hopefully we will
+  // find a better fix in the future.
+  QImage img = Qgs3DUtils::captureSceneImage( engine, scene );
+
+  QGSVERIFYIMAGECHECK( "pointcloud_3d_filtered_classification", "pointcloud_3d_filtered_classification", img, QString(), 80, QSize( 0, 0 ), 15 );
+
+  mLayer->setSubsetString( "" );
+}
+
+void TestQgsPointCloud3DRendering::testPointCloudFilteredSceneExtent()
+{
+  const QgsRectangle fullExtent = mLayer->extent();
+  const QgsRectangle filteredExtent = QgsRectangle( fullExtent.xMinimum(), fullExtent.yMinimum(), fullExtent.xMinimum() + fullExtent.width() / 3.0, fullExtent.yMinimum() + fullExtent.height() / 4.0 );
+
+  Qgs3DMapSettings *map = new Qgs3DMapSettings;
+  map->setCrs( mProject->crs() );
+  map->setOrigin( QgsVector3D( filteredExtent.center().x(), filteredExtent.center().y(), 0 ) );
+  map->setExtent( filteredExtent );
+  map->setLayers( QList<QgsMapLayer *>() << mLayer );
+  QgsPointLightSettings defaultLight;
+  defaultLight.setIntensity( 0.5 );
+  defaultLight.setPosition( QgsVector3D( 0, 1000, 0 ) );
+  map->setLightSources( { defaultLight.clone() } );
+
+  QgsOffscreen3DEngine engine;
+  Qgs3DMapScene *scene = new Qgs3DMapScene( *map, &engine );
+  engine.setRootEntity( scene );
+
+  QgsClassificationPointCloud3DSymbol *symbol = new QgsClassificationPointCloud3DSymbol();
+  symbol->setAttribute( QStringLiteral( "Classification" ) );
+  auto categories = QgsPointCloudClassifiedRenderer::defaultCategories();
+  symbol->setCategoriesList( categories );
+  symbol->setPointSize( 10 );
+
+  QgsPointCloudLayer3DRenderer *renderer = new QgsPointCloudLayer3DRenderer();
+  renderer->setSymbol( symbol );
+  mLayer->setRenderer3D( renderer );
+
+  scene->cameraController()->resetView( 90 );
+  Qgs3DUtils::captureSceneImage( engine, scene );
+  // When running the test on Travis, it would initially return empty rendered image.
+  // Capturing the initial image and throwing it away fixes that. Hopefully we will
+  // find a better fix in the future.
+  QImage img = Qgs3DUtils::captureSceneImage( engine, scene );
+
+  QGSVERIFYIMAGECHECK( "pointcloud_3d_filtered_scene_extent", "pointcloud_3d_filtered_scene_extent", img, QString(), 80, QSize( 0, 0 ), 15 );
+}
+
 QGSTEST_MAIN( TestQgsPointCloud3DRendering )
 #include "testqgspointcloud3drendering.moc"
