@@ -23,7 +23,7 @@
 #include "qgscoordinatetransform.h"
 #include "testgeometryutils.h"
 
-class TestQgsPoint: public QObject
+class TestQgsPoint : public QObject
 {
     Q_OBJECT
   private slots:
@@ -168,7 +168,7 @@ void TestQgsPoint::constructorZ()
   QVERIFY( pt1.is3D() );
   QVERIFY( !pt1.isMeasure() );
   QCOMPARE( pt1.wkbType(), Qgis::WkbType::PointZ );
-  QCOMPARE( pt1.wktTypeStr(), QString( "PointZ" ) );
+  QCOMPARE( pt1.wktTypeStr(), QString( "Point Z" ) );
 
   QgsPoint pt2( Qgis::WkbType::PointZ, 11.0, 13.0, 17.0, 18.0 );
 
@@ -195,7 +195,7 @@ void TestQgsPoint::constructorM()
   QVERIFY( !pt1.is3D() );
   QVERIFY( pt1.isMeasure() );
   QCOMPARE( pt1.wkbType(), Qgis::WkbType::PointM );
-  QCOMPARE( pt1.wktTypeStr(), QString( "PointM" ) );
+  QCOMPARE( pt1.wktTypeStr(), QString( "Point M" ) );
 
   QgsPoint pt2( Qgis::WkbType::PointM, 11.0, 13.0, 15.0, 17.0 );
 
@@ -209,7 +209,6 @@ void TestQgsPoint::constructorM()
 
   QVERIFY( !pt3.is3D() );
   QVERIFY( pt3.isMeasure() );
-
 }
 
 void TestQgsPoint::constructorZM()
@@ -223,7 +222,7 @@ void TestQgsPoint::constructorZM()
   QVERIFY( pt1.is3D() );
   QVERIFY( pt1.isMeasure() );
   QCOMPARE( pt1.wkbType(), Qgis::WkbType::PointZM );
-  QCOMPARE( pt1.wktTypeStr(), QString( "PointZM" ) );
+  QCOMPARE( pt1.wktTypeStr(), QString( "Point ZM" ) );
 
   QgsPoint pt2( Qgis::WkbType::PointZM );
 
@@ -264,7 +263,7 @@ void TestQgsPoint::clone()
 {
   QgsPoint pt( Qgis::WkbType::PointZM, 9.0, 3.0, 13.0, 23.0 );
 
-  std::unique_ptr< QgsPoint >clone( pt.clone() );
+  std::unique_ptr<QgsPoint> clone( pt.clone() );
   QVERIFY( pt == *clone );
 }
 
@@ -337,51 +336,36 @@ void TestQgsPoint::equality()
   QVERIFY( pt2 == pt1 );
 
 
-  QVERIFY( QgsPoint( Qgis::WkbType::Point, 2 / 3.0, 1 / 3.0 ) ==
-           QgsPoint( Qgis::WkbType::Point, 2 / 3.0, 1 / 3.0 ) );
+  QVERIFY( QgsPoint( Qgis::WkbType::Point, 2 / 3.0, 1 / 3.0 ) == QgsPoint( Qgis::WkbType::Point, 2 / 3.0, 1 / 3.0 ) );
 
-  QVERIFY( !( QgsPoint( Qgis::WkbType::PointZ, 2 / 3.0, 1 / 3.0 ) ==
-              QgsPoint( Qgis::WkbType::Point, 2 / 3.0, 1 / 3.0 ) ) );
+  QVERIFY( !( QgsPoint( Qgis::WkbType::PointZ, 2 / 3.0, 1 / 3.0 ) == QgsPoint( Qgis::WkbType::Point, 2 / 3.0, 1 / 3.0 ) ) );
 
-  QVERIFY( !( QgsPoint( Qgis::WkbType::Point, 1 / 3.0, 1 / 3.0 ) ==
-              QgsPoint( Qgis::WkbType::Point, 2 / 3.0, 1 / 3.0 ) ) );
+  QVERIFY( !( QgsPoint( Qgis::WkbType::Point, 1 / 3.0, 1 / 3.0 ) == QgsPoint( Qgis::WkbType::Point, 2 / 3.0, 1 / 3.0 ) ) );
 
-  QVERIFY( !( QgsPoint( Qgis::WkbType::Point, 2 / 3.0, 2 / 3.0 ) ==
-              QgsPoint( Qgis::WkbType::Point, 2 / 3.0, 1 / 3.0 ) ) );
+  QVERIFY( !( QgsPoint( Qgis::WkbType::Point, 2 / 3.0, 2 / 3.0 ) == QgsPoint( Qgis::WkbType::Point, 2 / 3.0, 1 / 3.0 ) ) );
 
-  QVERIFY( QgsPoint( Qgis::WkbType::PointZ, 3.0, 4.0, 1 / 3.0 ) ==
-           QgsPoint( Qgis::WkbType::PointZ, 3.0, 4.0, 1 / 3.0 ) );
+  QVERIFY( QgsPoint( Qgis::WkbType::PointZ, 3.0, 4.0, 1 / 3.0 ) == QgsPoint( Qgis::WkbType::PointZ, 3.0, 4.0, 1 / 3.0 ) );
 
-  QVERIFY( !( QgsPoint( Qgis::WkbType::PointZ, 3.0, 4.0, 1 / 3.0 ) ==
-              QgsPoint( Qgis::WkbType::PointZM, 3.0, 4.0, 1 / 3.0 ) ) );
+  QVERIFY( !( QgsPoint( Qgis::WkbType::PointZ, 3.0, 4.0, 1 / 3.0 ) == QgsPoint( Qgis::WkbType::PointZM, 3.0, 4.0, 1 / 3.0 ) ) );
 
-  QVERIFY( !( QgsPoint( Qgis::WkbType::PointZ, 3.0, 4.0, 2 / 3.0 ) ==
-              QgsPoint( Qgis::WkbType::PointZ, 3.0, 4.0, 1 / 3.0 ) ) );
+  QVERIFY( !( QgsPoint( Qgis::WkbType::PointZ, 3.0, 4.0, 2 / 3.0 ) == QgsPoint( Qgis::WkbType::PointZ, 3.0, 4.0, 1 / 3.0 ) ) );
 
-  QVERIFY( QgsPoint( Qgis::WkbType::PointM, 3.0, 4.0, 0.0, 1 / 3.0 ) ==
-           QgsPoint( Qgis::WkbType::PointM, 3.0, 4.0, 0.0, 1 / 3.0 ) );
+  QVERIFY( QgsPoint( Qgis::WkbType::PointM, 3.0, 4.0, 0.0, 1 / 3.0 ) == QgsPoint( Qgis::WkbType::PointM, 3.0, 4.0, 0.0, 1 / 3.0 ) );
 
-  QVERIFY( !( QgsPoint( Qgis::WkbType::PointM, 3.0, 4.0, 0.0, 1 / 3.0 ) ==
-              QgsPoint( Qgis::WkbType::PointZ, 3.0, 4.0, 0.0, 1 / 3.0 ) ) );
+  QVERIFY( !( QgsPoint( Qgis::WkbType::PointM, 3.0, 4.0, 0.0, 1 / 3.0 ) == QgsPoint( Qgis::WkbType::PointZ, 3.0, 4.0, 0.0, 1 / 3.0 ) ) );
 
-  QVERIFY( !( QgsPoint( Qgis::WkbType::PointM, 3.0, 4.0, 0.0, 1 / 3.0 ) ==
-              QgsPoint( Qgis::WkbType::PointM, 3.0, 4.0, 0.0, 2 / 3.0 ) ) );
+  QVERIFY( !( QgsPoint( Qgis::WkbType::PointM, 3.0, 4.0, 0.0, 1 / 3.0 ) == QgsPoint( Qgis::WkbType::PointM, 3.0, 4.0, 0.0, 2 / 3.0 ) ) );
 
-  QVERIFY( QgsPoint( Qgis::WkbType::PointZM, 3.0, 4.0, 2 / 3.0, 1 / 3.0 ) ==
-           QgsPoint( Qgis::WkbType::PointZM, 3.0, 4.0, 2 / 3.0, 1 / 3.0 ) );
+  QVERIFY( QgsPoint( Qgis::WkbType::PointZM, 3.0, 4.0, 2 / 3.0, 1 / 3.0 ) == QgsPoint( Qgis::WkbType::PointZM, 3.0, 4.0, 2 / 3.0, 1 / 3.0 ) );
 
-  QVERIFY( QgsPoint( Qgis::WkbType::Point25D, 3.0, 4.0, 2 / 3.0 ) ==
-           QgsPoint( Qgis::WkbType::Point25D, 3.0, 4.0, 2 / 3.0 ) );
+  QVERIFY( QgsPoint( Qgis::WkbType::Point25D, 3.0, 4.0, 2 / 3.0 ) == QgsPoint( Qgis::WkbType::Point25D, 3.0, 4.0, 2 / 3.0 ) );
 
-  QVERIFY( !( QgsPoint( Qgis::WkbType::Point25D, 3.0, 4.0, 2 / 3.0 ) ==
-              QgsPoint( Qgis::WkbType::PointZ, 3.0, 4.0, 2 / 3.0 ) ) );
+  QVERIFY( !( QgsPoint( Qgis::WkbType::Point25D, 3.0, 4.0, 2 / 3.0 ) == QgsPoint( Qgis::WkbType::PointZ, 3.0, 4.0, 2 / 3.0 ) ) );
 
   //test inequality operator
-  QVERIFY( !( QgsPoint( Qgis::WkbType::Point, 2 / 3.0, 1 / 3.0 ) !=
-              QgsPoint( Qgis::WkbType::Point, 2 / 3.0, 1 / 3.0 ) ) );
+  QVERIFY( !( QgsPoint( Qgis::WkbType::Point, 2 / 3.0, 1 / 3.0 ) != QgsPoint( Qgis::WkbType::Point, 2 / 3.0, 1 / 3.0 ) ) );
 
-  QVERIFY( QgsPoint( Qgis::WkbType::Point, 2 / 3.0, 1 / 3.0 ) !=
-           QgsPoint( Qgis::WkbType::PointZ, 2 / 3.0, 1 / 3.0 ) );
+  QVERIFY( QgsPoint( Qgis::WkbType::Point, 2 / 3.0, 1 / 3.0 ) != QgsPoint( Qgis::WkbType::PointZ, 2 / 3.0, 1 / 3.0 ) );
 
   QgsLineString ls;
   QVERIFY( pt1 != ls );
@@ -396,7 +380,7 @@ void TestQgsPoint::operators()
   QCOMPARE( pt2 - pt1, QgsVector( 2, 3 ) );
   QCOMPARE( pt1 - pt2, QgsVector( -2, -3 ) );
 
-//  pt1 = QgsPoint( 1, 2 ); ???
+  //  pt1 = QgsPoint( 1, 2 ); ???
   QCOMPARE( pt1 + QgsVector( 3, 5 ), QgsPoint( 4, 7 ) );
 
   pt1 += QgsVector( 3, 5 );
@@ -451,7 +435,6 @@ void TestQgsPoint::dropDimension()
   QVERIFY( pt.dropMValue() );
   QCOMPARE( pt, QgsPoint( Qgis::WkbType::PointZ, 1.0, 2.0, 3.0, 0.0 ) );
   QVERIFY( !pt.dropMValue() );
-
 }
 
 void TestQgsPoint::swapXy()
@@ -624,34 +607,28 @@ void TestQgsPoint::moveVertex()
 {
   QgsPoint pt( Qgis::WkbType::PointZM, 3.0, 4.0, 6.0, 7.0 );
 
-  pt.moveVertex( QgsVertexId( 0, 0, 0 ),
-                 QgsPoint( Qgis::WkbType::PointZM, 1.0, 2.0, 3.0, 4.0 ) );
+  pt.moveVertex( QgsVertexId( 0, 0, 0 ), QgsPoint( Qgis::WkbType::PointZM, 1.0, 2.0, 3.0, 4.0 ) );
   QCOMPARE( pt, QgsPoint( Qgis::WkbType::PointZM, 1.0, 2.0, 3.0, 4.0 ) );
 
   //invalid vertex id, should not crash
-  pt.moveVertex( QgsVertexId( 1, 2, 3 ),
-                 QgsPoint( Qgis::WkbType::PointZM, 2.0, 3.0, 1.0, 2.0 ) );
+  pt.moveVertex( QgsVertexId( 1, 2, 3 ), QgsPoint( Qgis::WkbType::PointZM, 2.0, 3.0, 1.0, 2.0 ) );
   QCOMPARE( pt, QgsPoint( Qgis::WkbType::PointZM, 2.0, 3.0, 1.0, 2.0 ) );
 
   //move PointZM using Point
-  pt.moveVertex( QgsVertexId( 0, 0, 0 ),
-                 QgsPoint( Qgis::WkbType::Point, 11.0, 12.0 ) );
+  pt.moveVertex( QgsVertexId( 0, 0, 0 ), QgsPoint( Qgis::WkbType::Point, 11.0, 12.0 ) );
   QCOMPARE( pt, QgsPoint( Qgis::WkbType::PointZM, 11.0, 12.0, 1.0, 2.0 ) );
 
   //move PointZM using PointZ
-  pt.moveVertex( QgsVertexId( 0, 0, 0 ),
-                 QgsPoint( Qgis::WkbType::PointZ, 21.0, 22.0, 23.0 ) );
+  pt.moveVertex( QgsVertexId( 0, 0, 0 ), QgsPoint( Qgis::WkbType::PointZ, 21.0, 22.0, 23.0 ) );
   QCOMPARE( pt, QgsPoint( Qgis::WkbType::PointZM, 21.0, 22.0, 23.0, 2.0 ) );
 
   //move PointZM using PointM
-  pt.moveVertex( QgsVertexId( 0, 0, 0 ),
-                 QgsPoint( Qgis::WkbType::PointM, 31.0, 32.0, 0.0, 43.0 ) );
+  pt.moveVertex( QgsVertexId( 0, 0, 0 ), QgsPoint( Qgis::WkbType::PointM, 31.0, 32.0, 0.0, 43.0 ) );
   QCOMPARE( pt, QgsPoint( Qgis::WkbType::PointZM, 31.0, 32.0, 23.0, 43.0 ) );
 
   //move Point using PointZM (z/m should be ignored)
   pt = QgsPoint( 3.0, 4.0 );
-  pt.moveVertex( QgsVertexId( 0, 0, 0 ),
-                 QgsPoint( Qgis::WkbType::PointZM, 2.0, 3.0, 1.0, 2.0 ) );
+  pt.moveVertex( QgsVertexId( 0, 0, 0 ), QgsPoint( Qgis::WkbType::PointZM, 2.0, 3.0, 1.0, 2.0 ) );
   QCOMPARE( pt, QgsPoint( 2.0, 3.0 ) );
 }
 
@@ -660,7 +637,7 @@ void TestQgsPoint::vertexAngle()
   QgsPoint pt( 3.0, 4.0 );
 
   //undefined, but check that it doesn't crash
-  ( void )pt.vertexAngle( QgsVertexId() );
+  ( void ) pt.vertexAngle( QgsVertexId() );
 }
 
 void TestQgsPoint::removeDuplicateNodes()
@@ -685,7 +662,7 @@ void TestQgsPoint::project()
   QCOMPARE( pt.project( 5, 270 ), QgsPoint( -4, 2 ) );
   QCOMPARE( pt.project( 6, 360 ), QgsPoint( 1, 8 ) );
   QCOMPARE( pt.project( 5, 450 ), QgsPoint( 6, 2 ) );
-  QCOMPARE( pt.project( 5, 450, 450 ), QgsPoint( 6, 2 ) );  // stay Qgis::WkbType::Point
+  QCOMPARE( pt.project( 5, 450, 450 ), QgsPoint( 6, 2 ) ); // stay Qgis::WkbType::Point
   QCOMPARE( pt.project( -1, 0 ), QgsPoint( 1, 1 ) );
   QCOMPARE( pt.project( 1.5, -90 ), QgsPoint( -0.5, 2 ) );
 
@@ -693,9 +670,9 @@ void TestQgsPoint::project()
   pt.addZValue( 0 );
 
   QCOMPARE( pt.project( 1, 0, 0 ), QgsPoint( Qgis::WkbType::PointZ, 1, 2, 1 ) );
-  QCOMPARE( pt.project( 2, 180, 180 ), QgsPoint( Qgis::WkbType::PointZ,  1, 2, -2 ) );
-  QCOMPARE( pt.project( 5, 270, 270 ), QgsPoint( Qgis::WkbType::PointZ,  6, 2, 0 ) );
-  QCOMPARE( pt.project( 6, 360, 360 ), QgsPoint( Qgis::WkbType::PointZ,  1, 2, 6 ) );
+  QCOMPARE( pt.project( 2, 180, 180 ), QgsPoint( Qgis::WkbType::PointZ, 1, 2, -2 ) );
+  QCOMPARE( pt.project( 5, 270, 270 ), QgsPoint( Qgis::WkbType::PointZ, 6, 2, 0 ) );
+  QCOMPARE( pt.project( 6, 360, 360 ), QgsPoint( Qgis::WkbType::PointZ, 1, 2, 6 ) );
   QCOMPARE( pt.project( -1, 0, 0 ), QgsPoint( Qgis::WkbType::PointZ, 1, 2, -1 ) );
   QCOMPARE( pt.project( 1.5, -90, -90 ), QgsPoint( Qgis::WkbType::PointZ, 2.5, 2, 0 ) );
 
@@ -773,7 +750,7 @@ void TestQgsPoint::measures()
   QCOMPARE( pt.centroid(), pt );
   QVERIFY( !pt.hasCurvedSegments() );
 
-  std::unique_ptr< QgsPoint >segmented( static_cast< QgsPoint *>( pt.segmentize() ) );
+  std::unique_ptr<QgsPoint> segmented( static_cast<QgsPoint *>( pt.segmentize() ) );
   QCOMPARE( *segmented, pt );
 }
 
@@ -847,35 +824,25 @@ void TestQgsPoint::azimuth()
 
 void TestQgsPoint::inclination()
 {
-  QCOMPARE( QgsPoint( 1, 2 ).inclination(
-              QgsPoint( 1, 2 ) ), 90.0 );
+  QCOMPARE( QgsPoint( 1, 2 ).inclination( QgsPoint( 1, 2 ) ), 90.0 );
 
-  QCOMPARE( QgsPoint( Qgis::WkbType::PointZ, 1, 1, 2, 0 ).inclination(
-              QgsPoint( Qgis::WkbType::PointZ, 1, 1, 2, 0 ) ), 90.0 );
+  QCOMPARE( QgsPoint( Qgis::WkbType::PointZ, 1, 1, 2, 0 ).inclination( QgsPoint( Qgis::WkbType::PointZ, 1, 1, 2, 0 ) ), 90.0 );
 
-  QCOMPARE( QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).inclination(
-              QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).project( 5, 90, 90 ) ), 90.0 );
+  QCOMPARE( QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).inclination( QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).project( 5, 90, 90 ) ), 90.0 );
 
-  QCOMPARE( QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).inclination(
-              QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).project( 5, 90, -90 ) ), 90.0 );
+  QCOMPARE( QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).inclination( QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).project( 5, 90, -90 ) ), 90.0 );
 
-  QCOMPARE( QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).inclination(
-              QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).project( 5, 90, 0 ) ), 0.0 );
+  QCOMPARE( QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).inclination( QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).project( 5, 90, 0 ) ), 0.0 );
 
-  QCOMPARE( QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).inclination(
-              QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).project( 5, 90, 180 ) ), 180.0 );
+  QCOMPARE( QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).inclination( QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).project( 5, 90, 180 ) ), 180.0 );
 
-  QCOMPARE( QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).inclination(
-              QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).project( 5, 90, -180 ) ), 180.0 );
+  QCOMPARE( QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).inclination( QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).project( 5, 90, -180 ) ), 180.0 );
 
-  QCOMPARE( QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).inclination(
-              QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).project( 5, 90, 720 ) ), 0.0 );
+  QCOMPARE( QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).inclination( QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).project( 5, 90, 720 ) ), 0.0 );
 
-  QCOMPARE( QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).inclination(
-              QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).project( 5, 90, 45 ) ), 45.0 );
+  QCOMPARE( QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).inclination( QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).project( 5, 90, 45 ) ), 45.0 );
 
-  QCOMPARE( QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).inclination(
-              QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).project( 5, 90, 135 ) ), 135.0 );
+  QCOMPARE( QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).inclination( QgsPoint( Qgis::WkbType::PointZ, 1, 2, 2 ).project( 5, 90, 135 ) ), 135.0 );
 }
 
 void TestQgsPoint::boundary()
@@ -946,25 +913,31 @@ void TestQgsPoint::boundingBoxIntersects()
 {
   // 2d
   QVERIFY( QgsPoint( 1, 2 ).boundingBoxIntersects(
-             QgsRectangle( 0, 0.5, 1.5, 3 ) ) );
+    QgsRectangle( 0, 0.5, 1.5, 3 )
+  ) );
   QVERIFY( !QgsPoint( 1, 2 ).boundingBoxIntersects(
-             QgsRectangle( 3, 0.5, 3.5, 3 ) ) );
+    QgsRectangle( 3, 0.5, 3.5, 3 )
+  ) );
   QVERIFY( !QgsPoint().boundingBoxIntersects(
-             QgsRectangle( 0, 0.5, 3.5, 3 ) ) );
+    QgsRectangle( 0, 0.5, 3.5, 3 )
+  ) );
 
   // 3d
   QVERIFY( QgsPoint( 1, 2, 3 ).boundingBoxIntersects(
-             QgsBox3D( 0, 0.5, 1.5, 3, 2.5, 4.2 ) ) );
+    QgsBox3D( 0, 0.5, 1.5, 3, 2.5, 4.2 )
+  ) );
   QVERIFY( !QgsPoint( 1, 2, 3 ).boundingBoxIntersects(
-             QgsBox3D( 3, 0.5, 1.5, 3.5, 2.5, 4.5 ) ) );
+    QgsBox3D( 3, 0.5, 1.5, 3.5, 2.5, 4.5 )
+  ) );
   QVERIFY( !QgsPoint().boundingBoxIntersects(
-             QgsBox3D( 0, 0.5, 1.5, 3.5, 2.5, 4.5 ) ) );
+    QgsBox3D( 0, 0.5, 1.5, 3.5, 2.5, 4.5 )
+  ) );
 }
 
 void TestQgsPoint::filterVertices()
 {
   QgsPoint pt( 1.1, 2.2, 3.3, 4.4, Qgis::WkbType::PointZM );
-  pt.filterVertices( []( const QgsPoint & )-> bool { return false; } );
+  pt.filterVertices( []( const QgsPoint & ) -> bool { return false; } );
   QCOMPARE( pt.x(), 1.1 );
   QCOMPARE( pt.y(), 2.2 );
   QCOMPARE( pt.z(), 3.3 );
@@ -976,8 +949,7 @@ void TestQgsPoint::transformVertices()
 {
   QgsPoint pt( 1.1, 2.2, 3.3, 4.4, Qgis::WkbType::PointZM );
 
-  pt.transformVertices( []( const QgsPoint & pt )-> QgsPoint
-  {
+  pt.transformVertices( []( const QgsPoint &pt ) -> QgsPoint {
     return QgsPoint( pt.x() + 2, pt.y() + 3, pt.z() + 1, pt.m() + 8 );
   } );
 
@@ -988,8 +960,7 @@ void TestQgsPoint::transformVertices()
   QCOMPARE( pt.wkbType(), Qgis::WkbType::PointZM );
 
   // no dimensionality change allowed
-  pt.transformVertices( []( const QgsPoint & pt )-> QgsPoint
-  {
+  pt.transformVertices( []( const QgsPoint &pt ) -> QgsPoint {
     return QgsPoint( pt.x() + 2, pt.y() + 3 );
   } );
 
@@ -1000,8 +971,7 @@ void TestQgsPoint::transformVertices()
   QCOMPARE( pt.wkbType(), Qgis::WkbType::PointZM );
 
   pt = QgsPoint( 2, 3 );
-  pt.transformVertices( []( const QgsPoint & pt )-> QgsPoint
-  {
+  pt.transformVertices( []( const QgsPoint &pt ) -> QgsPoint {
     return QgsPoint( pt.x() + 2, pt.y() + 3, 7, 8 );
   } );
 
@@ -1113,7 +1083,7 @@ void TestQgsPoint::toCurveType()
 {
   QgsPoint pt( Qgis::WkbType::PointZM, 9.0, 3.0, 13.0, 23.0 );
 
-  std::unique_ptr< QgsPoint >clone( pt.toCurveType() );
+  std::unique_ptr<QgsPoint> clone( pt.toCurveType() );
   QVERIFY( pt == *clone );
 }
 
