@@ -32,25 +32,22 @@ class TestQgsBrowserProxyModel : public QObject
     Q_OBJECT
 
   private slots:
-    void initTestCase();// will be called before the first testfunction is executed.
-    void cleanupTestCase();// will be called after the last testfunction was executed.
-    void init() {} // will be called before each testfunction is executed.
-    void cleanup() {} // will be called after every testfunction.
+    void initTestCase();    // will be called before the first testfunction is executed.
+    void cleanupTestCase(); // will be called after the last testfunction was executed.
+    void init() {}          // will be called before each testfunction is executed.
+    void cleanup() {}       // will be called after every testfunction.
 
     void testModel();
     void testShowLayers();
-
 };
 
-class TestCollectionItem: public QgsDataCollectionItem
+class TestCollectionItem : public QgsDataCollectionItem
 {
     Q_OBJECT
   public:
-
     TestCollectionItem( QgsDataItem *parent, const QString &name, const QString &path = QString(), const QString &providerKey = QString() )
-      : QgsDataCollectionItem( parent, name, path, providerKey )
-    {
-    };
+      : QgsDataCollectionItem( parent, name, path, providerKey ) {
+      };
 
     bool layerCollection() const override { return true; };
 };
@@ -110,11 +107,11 @@ void TestQgsBrowserProxyModel::testModel()
   QCOMPARE( proxy.rowCount( root1Index ), 0 );
   QCOMPARE( proxy.columnCount( root1Index ), 1 );
   QCOMPARE( proxy.data( root1Index ).toString(), QStringLiteral( "Test" ) );
-  QCOMPARE( proxy.data( root1Index, QgsBrowserModel::PathRole ).toString(), QStringLiteral( "root1" ) );
+  QCOMPARE( proxy.data( root1Index, static_cast<int>( QgsBrowserModel::CustomRole::Path ) ).toString(), QStringLiteral( "root1" ) );
   QCOMPARE( proxy.dataItem( root1Index ), rootItem1 );
 
   // second root item
-  QgsDataCollectionItem *rootItem2 = new QgsDataCollectionItem( nullptr, QStringLiteral( "Test2" ), QStringLiteral( "root2" ),  QStringLiteral( "provider2" ) );
+  QgsDataCollectionItem *rootItem2 = new QgsDataCollectionItem( nullptr, QStringLiteral( "Test2" ), QStringLiteral( "root2" ), QStringLiteral( "provider2" ) );
   model.setupItemConnections( rootItem2 );
   model.beginInsertRows( QModelIndex(), 1, 1 );
   model.mRootItems.append( rootItem2 );
@@ -127,7 +124,7 @@ void TestQgsBrowserProxyModel::testModel()
   QCOMPARE( proxy.rowCount( root2Index ), 0 );
   QCOMPARE( proxy.columnCount( root2Index ), 1 );
   QCOMPARE( proxy.data( root2Index ).toString(), QStringLiteral( "Test2" ) );
-  QCOMPARE( proxy.data( root2Index, QgsBrowserModel::PathRole ).toString(), QStringLiteral( "root2" ) );
+  QCOMPARE( proxy.data( root2Index, static_cast<int>( QgsBrowserModel::CustomRole::Path ) ).toString(), QStringLiteral( "root2" ) );
   QCOMPARE( proxy.dataItem( root2Index ), rootItem2 );
 
   // child item
@@ -141,7 +138,7 @@ void TestQgsBrowserProxyModel::testModel()
   QVERIFY( proxy.hasChildren( root1Index ) );
   QModelIndex child1Index = proxy.index( 0, 0, root1Index );
   QCOMPARE( proxy.data( child1Index ).toString(), QStringLiteral( "Child1" ) );
-  QCOMPARE( proxy.data( child1Index, QgsBrowserModel::PathRole ).toString(), QStringLiteral( "child1" ) );
+  QCOMPARE( proxy.data( child1Index, static_cast<int>( QgsBrowserModel::CustomRole::Path ) ).toString(), QStringLiteral( "child1" ) );
   QCOMPARE( proxy.dataItem( child1Index ), childItem1 );
 
   // more children
@@ -269,11 +266,11 @@ void TestQgsBrowserProxyModel::testModel()
   proxy.setFilterByLayerType( false );
 
   // provider filtering
-  proxy.setHiddenDataItemProviderKeyFilter( QStringList( {QStringLiteral( "provider1" )} ) );
+  proxy.setHiddenDataItemProviderKeyFilter( QStringList( { QStringLiteral( "provider1" ) } ) );
   QCOMPARE( proxy.rowCount(), 2 );
   root1Index = proxy.index( 0, 0 );
   QCOMPARE( proxy.rowCount( root1Index ), 1 );
-  proxy.setHiddenDataItemProviderKeyFilter( QStringList( {QStringLiteral( "provider2" )} ) );
+  proxy.setHiddenDataItemProviderKeyFilter( QStringList( { QStringLiteral( "provider2" ) } ) );
   QCOMPARE( proxy.rowCount(), 1 );
   root1Index = proxy.index( 0, 0 );
   QCOMPARE( proxy.rowCount( root1Index ), 2 );
@@ -281,18 +278,17 @@ void TestQgsBrowserProxyModel::testModel()
   QCOMPARE( proxy.rowCount(), 2 );
 
   // provider filtering
-  proxy.setHiddenDataItemProviderKeyFilter( QStringList( ) );
-  proxy.setShownDataItemProviderKeyFilter( QStringList( {QStringLiteral( "provider2" )} ) );
+  proxy.setHiddenDataItemProviderKeyFilter( QStringList() );
+  proxy.setShownDataItemProviderKeyFilter( QStringList( { QStringLiteral( "provider2" ) } ) );
   QCOMPARE( proxy.rowCount(), 2 );
   root1Index = proxy.index( 0, 0 );
   QCOMPARE( proxy.rowCount( root1Index ), 1 );
-  proxy.setShownDataItemProviderKeyFilter( QStringList( {QStringLiteral( "provider1" )} ) );
+  proxy.setShownDataItemProviderKeyFilter( QStringList( { QStringLiteral( "provider1" ) } ) );
   QCOMPARE( proxy.rowCount(), 1 );
   root1Index = proxy.index( 0, 0 );
   QCOMPARE( proxy.rowCount( root1Index ), 2 );
   proxy.setShownDataItemProviderKeyFilter( QStringList() );
   QCOMPARE( proxy.rowCount(), 2 );
-
 }
 
 void TestQgsBrowserProxyModel::testShowLayers()
@@ -323,8 +319,7 @@ void TestQgsBrowserProxyModel::testShowLayers()
   QVERIFY( proxy.hasChildren( container1Index ) );
 
   proxy.setShowLayers( false );
-  QVERIFY( ! proxy.hasChildren( container1Index ) );
-
+  QVERIFY( !proxy.hasChildren( container1Index ) );
 }
 
 QGSTEST_MAIN( TestQgsBrowserProxyModel )
