@@ -32,16 +32,17 @@ class TestQgsLayoutItemGroup : public QgsTest
     Q_OBJECT
 
   public:
-    TestQgsLayoutItemGroup() : QgsTest( QStringLiteral( "Layout Group Item" ) ) {}
+    TestQgsLayoutItemGroup()
+      : QgsTest( QStringLiteral( "Layout Group Item" ) ) {}
 
   private slots:
-    void initTestCase();// will be called before the first testfunction is executed.
-    void cleanupTestCase();// will be called after the last testfunction was executed.
-    void init();// will be called before each testfunction is executed.
-    void cleanup();// will be called after every testfunction.
+    void initTestCase();    // will be called before the first testfunction is executed.
+    void cleanupTestCase(); // will be called after the last testfunction was executed.
+    void init();            // will be called before each testfunction is executed.
+    void cleanup();         // will be called after every testfunction.
     void createGroupDirect();
     void createGroup(); //test grouping items
-    void ungroup(); //test ungrouping items
+    void ungroup();     //test ungrouping items
     void deleteGroup(); //test deleting group works
     void groupVisibility();
     void moveGroup();
@@ -51,20 +52,17 @@ class TestQgsLayoutItemGroup : public QgsTest
     void undoRedo(); //test that group/ungroup undo/redo commands don't crash
 
   private:
-
     void dumpUndoStack( const QUndoStack &, QString prefix = QString() ) const;
-
 };
 
 // private
 void TestQgsLayoutItemGroup::dumpUndoStack( const QUndoStack &us, QString prefix ) const
 {
-  if ( ! prefix.isEmpty() ) prefix += QLatin1String( ": " );
+  if ( !prefix.isEmpty() )
+    prefix += QLatin1String( ": " );
   for ( int i = 0; i < us.count(); ++i )
   {
-    QgsDebugMsgLevel( QStringLiteral( "%4US %1: %2%3" )
-                      .arg( i ). arg( i >= us.index() ? "-" : "",
-                                      us.text( i ), prefix ), 1 );
+    QgsDebugMsgLevel( QStringLiteral( "%4US %1: %2%3" ).arg( i ).arg( i >= us.index() ? "-" : "", us.text( i ), prefix ), 1 );
   }
 }
 
@@ -81,12 +79,10 @@ void TestQgsLayoutItemGroup::cleanupTestCase()
 
 void TestQgsLayoutItemGroup::init()
 {
-
 }
 
 void TestQgsLayoutItemGroup::cleanup()
 {
-
 }
 
 void TestQgsLayoutItemGroup::createGroupDirect()
@@ -137,7 +133,7 @@ void TestQgsLayoutItemGroup::createGroupDirect()
   QVERIFY( l.items().contains( item2 ) );
 
   // manually delete an item
-  const QPointer< QgsLayoutItemShape > pItem( item ); // for testing deletion
+  const QPointer<QgsLayoutItemShape> pItem( item ); // for testing deletion
   l.removeLayoutItem( item );
   QgsApplication::sendPostedEvents( nullptr, QEvent::DeferredDelete );
   QVERIFY( !pItem );
@@ -147,7 +143,7 @@ void TestQgsLayoutItemGroup::createGroupDirect()
   QCOMPARE( group->items().count(), 1 );
   QVERIFY( group->items().contains( item2 ) );
 
-  const QPointer< QgsLayoutItemShape > pItem2( item2 ); // for testing deletion
+  const QPointer<QgsLayoutItemShape> pItem2( item2 ); // for testing deletion
   // remove items
   group->removeItems();
   QgsApplication::sendPostedEvents( nullptr, QEvent::DeferredDelete );
@@ -214,7 +210,7 @@ void TestQgsLayoutItemGroup::ungroup()
   QVERIFY( groups.contains( group ) );
   QCOMPARE( group->layout(), &l );
 
-  const QPointer< QgsLayoutItemGroup > pGroup( group ); // for testing deletion
+  const QPointer<QgsLayoutItemGroup> pGroup( group ); // for testing deletion
   //ungroup group
   QList<QgsLayoutItem *> ungroupedItems;
   ungroupedItems = l.ungroupItems( group );
@@ -249,17 +245,17 @@ void TestQgsLayoutItemGroup::deleteGroup()
   QgsLayout l( &proj );
 
   QgsLayoutItemShape *item = new QgsLayoutItemShape( &l );
-  const QPointer< QgsLayoutItemShape > pItem( item ); // for testing deletion
+  const QPointer<QgsLayoutItemShape> pItem( item ); // for testing deletion
   l.addLayoutItem( item );
   QgsLayoutItemShape *item2 = new QgsLayoutItemShape( &l );
-  const QPointer< QgsLayoutItemShape > pItem2( item2 ); // for testing deletion
+  const QPointer<QgsLayoutItemShape> pItem2( item2 ); // for testing deletion
   l.addLayoutItem( item2 );
 
   //group items
   QList<QgsLayoutItem *> groupItems;
   groupItems << item << item2;
   QgsLayoutItemGroup *group = l.groupItems( groupItems );
-  const QPointer< QgsLayoutItemGroup > pGroup( group ); // for testing deletion
+  const QPointer<QgsLayoutItemGroup> pGroup( group ); // for testing deletion
 
   QList<QgsLayoutItem *> items;
   l.layoutItems( items );
@@ -444,7 +440,7 @@ void TestQgsLayoutItemGroup::resizeGroup()
   QCOMPARE( group->positionWithUnits().y(), 76.2 );
   QCOMPARE( group->positionWithUnits().units(), Qgis::LayoutUnit::Millimeters );
   QCOMPARE( group->sizeWithUnits().width(), 102.4 );
-  QCOMPARE( group->sizeWithUnits().height(),  163.8 );
+  QCOMPARE( group->sizeWithUnits().height(), 163.8 );
   QCOMPARE( group->sizeWithUnits().units(), Qgis::LayoutUnit::Millimeters );
 
   group->attemptResize( QgsLayoutSize( 50.8, 76.2, Qgis::LayoutUnit::Millimeters ) );
@@ -452,7 +448,7 @@ void TestQgsLayoutItemGroup::resizeGroup()
   QCOMPARE( group->positionWithUnits().y(), 76.2 );
   QCOMPARE( group->positionWithUnits().units(), Qgis::LayoutUnit::Millimeters );
   QCOMPARE( group->sizeWithUnits().width(), 50.8 );
-  QCOMPARE( group->sizeWithUnits().height(),  76.2 );
+  QCOMPARE( group->sizeWithUnits().height(), 76.2 );
   QCOMPARE( group->sizeWithUnits().units(), Qgis::LayoutUnit::Millimeters );
   QCOMPARE( item->positionWithUnits().x(), 0.05 );
   QGSCOMPARENEAR( item->positionWithUnits().y(), 0.0826198, 0.00001 );
@@ -464,7 +460,7 @@ void TestQgsLayoutItemGroup::resizeGroup()
   QGSCOMPARENEAR( item2->positionWithUnits().y(), 3.000000, 0.0001 );
   QCOMPARE( item2->positionWithUnits().units(), Qgis::LayoutUnit::Inches );
   QGSCOMPARENEAR( item2->sizeWithUnits().width(), 1.98438, 0.0001 );
-  QGSCOMPARENEAR( item2->sizeWithUnits().height(),  2.791209, 0.0001 );
+  QGSCOMPARENEAR( item2->sizeWithUnits().height(), 2.791209, 0.0001 );
   QCOMPARE( item2->sizeWithUnits().units(), Qgis::LayoutUnit::Inches );
 }
 
@@ -551,21 +547,21 @@ void TestQgsLayoutItemGroup::undoRedo()
   QgsLayoutItemShape *item1 = nullptr;
   QgsLayoutItemShape *item2 = nullptr;
 
-// int shapesAdded = 0;
-// int groupsAdded = 0;
-// int itemsRemoved = 0;
+  // int shapesAdded = 0;
+  // int groupsAdded = 0;
+  // int itemsRemoved = 0;
 
   qRegisterMetaType<QgsLayoutItemShape *>();
-//  QSignalSpy spyPolygonAdded( &l, &QgsLayout::itemAdded );
-// QCOMPARE( spyPolygonAdded.count(), 0 );
+  //  QSignalSpy spyPolygonAdded( &l, &QgsLayout::itemAdded );
+  // QCOMPARE( spyPolygonAdded.count(), 0 );
 
   qRegisterMetaType<QgsLayoutItemGroup *>();
-//  QSignalSpy spyGroupAdded( &l, &QgsLayout::composerItemGroupAdded );
-//  QCOMPARE( spyGroupAdded.count(), 0 );
+  //  QSignalSpy spyGroupAdded( &l, &QgsLayout::composerItemGroupAdded );
+  //  QCOMPARE( spyGroupAdded.count(), 0 );
 
   qRegisterMetaType<QgsLayoutItem *>();
-//  QSignalSpy spyItemRemoved( &l, &QgsLayout::itemRemoved );
-//  QCOMPARE( spyItemRemoved.count(), 0 );
+  //  QSignalSpy spyItemRemoved( &l, &QgsLayout::itemRemoved );
+  //  QCOMPARE( spyItemRemoved.count(), 0 );
 
   //test for crash when undo/redoing with groups
   // Set initial condition
@@ -576,27 +572,27 @@ void TestQgsLayoutItemGroup::undoRedo()
   QList<QgsLayoutItem *> items;
   l.layoutItems( items );
   QCOMPARE( items.size(), 0 );
-  QgsDebugMsgLevel( QStringLiteral( "clear stack count:%1 index:%2" ) .arg( us->count() ) .arg( us->index() ), 1 );
+  QgsDebugMsgLevel( QStringLiteral( "clear stack count:%1 index:%2" ).arg( us->count() ).arg( us->index() ), 1 );
 
   //create some items
   item1 = new QgsLayoutItemShape( &l );
   item1->attemptMove( QgsLayoutPoint( 0.05, 0.09, Qgis::LayoutUnit::Meters ) );
-  QPointer< QgsLayoutItem > pItem1( item1 );
+  QPointer<QgsLayoutItem> pItem1( item1 );
   const QString item1Uuid = item1->uuid();
   item1->attemptResize( QgsLayoutSize( 0.1, 0.15, Qgis::LayoutUnit::Meters ) );
 
   l.addLayoutItem( item1 );
-//  QCOMPARE( spyPolygonAdded.count(), ++shapesAdded );
+  //  QCOMPARE( spyPolygonAdded.count(), ++shapesAdded );
   item2 = new QgsLayoutItemShape( &l );
-  QPointer< QgsLayoutItem > pItem2( item2 );
+  QPointer<QgsLayoutItem> pItem2( item2 );
   const QString item2Uuid = item2->uuid();
   item2->attemptMove( QgsLayoutPoint( 2, 3, Qgis::LayoutUnit::Millimeters ) );
   item2->attemptResize( QgsLayoutSize( 4, 6, Qgis::LayoutUnit::Millimeters ) );
   l.addLayoutItem( item2 );
-//  QCOMPARE( spyPolygonAdded.count(), ++shapesAdded );
+  //  QCOMPARE( spyPolygonAdded.count(), ++shapesAdded );
   l.layoutItems( items );
   QCOMPARE( items.size(), 2 ); // 2 shapes
-  QgsDebugMsgLevel( QStringLiteral( "addedItems stack count:%1 index:%2" ) .arg( us->count() ) .arg( us->index() ), 1 );
+  QgsDebugMsgLevel( QStringLiteral( "addedItems stack count:%1 index:%2" ).arg( us->count() ).arg( us->index() ), 1 );
   QCOMPARE( item1->pos(), QPointF( 50, 90 ) );
   QCOMPARE( item2->pos(), QPointF( 2, 3 ) );
   //dumpUndoStack(*us, "after initial items addition");
@@ -606,9 +602,9 @@ void TestQgsLayoutItemGroup::undoRedo()
   items << item1 << item2;
   QgsLayoutItemGroup *group = l.groupItems( items );
   const QString groupUuid = group->uuid();
-// QCOMPARE( spyPolygonAdded.count(), shapesAdded );
-//  QCOMPARE( spyGroupAdded.count(), ++groupsAdded );
-//  QCOMPARE( spyItemRemoved.count(), itemsRemoved );
+  // QCOMPARE( spyPolygonAdded.count(), shapesAdded );
+  //  QCOMPARE( spyGroupAdded.count(), ++groupsAdded );
+  //  QCOMPARE( spyItemRemoved.count(), itemsRemoved );
   QCOMPARE( group->items().size(), 2 );
   l.layoutItems( items );
   QCOMPARE( items.size(), 3 ); // 2 shapes, 1 group
@@ -620,30 +616,30 @@ void TestQgsLayoutItemGroup::undoRedo()
   //move group
   QgsDebugMsgLevel( QStringLiteral( "moving group" ), 1 );
   group->attemptMove( QgsLayoutPoint( 10.0, 20.0 ) );
-// QCOMPARE( spyPolygonAdded.count(), shapesAdded );
-// QCOMPARE( spyGroupAdded.count(), groupsAdded );
-// QCOMPARE( spyItemRemoved.count(), itemsRemoved );
-  QgsDebugMsgLevel( QStringLiteral( "groupItems stack count:%1 index:%2" ) .arg( us->count() ) .arg( us->index() ), 1 );
+  // QCOMPARE( spyPolygonAdded.count(), shapesAdded );
+  // QCOMPARE( spyGroupAdded.count(), groupsAdded );
+  // QCOMPARE( spyItemRemoved.count(), itemsRemoved );
+  QgsDebugMsgLevel( QStringLiteral( "groupItems stack count:%1 index:%2" ).arg( us->count() ).arg( us->index() ), 1 );
   QCOMPARE( group->items().size(), 2 );
   l.layoutItems( items );
   QCOMPARE( items.size(), 3 ); // 2 shapes, 1 group
   QCOMPARE( item1->pos(), QPointF( 58, 107 ) );
-  QCOMPARE( item2->pos(),  QPointF( 10, 20 ) );
-  QCOMPARE( group->pos(),  QPointF( 10, 20 ) );
+  QCOMPARE( item2->pos(), QPointF( 10, 20 ) );
+  QCOMPARE( group->pos(), QPointF( 10, 20 ) );
 
   //ungroup
-  QPointer< QgsLayoutItemGroup > pGroup( group ); // for testing deletion
+  QPointer<QgsLayoutItemGroup> pGroup( group ); // for testing deletion
   QgsDebugMsgLevel( QStringLiteral( "ungrouping" ), 1 );
   l.ungroupItems( group );
   QgsApplication::sendPostedEvents( nullptr, QEvent::DeferredDelete );
 
-//  QCOMPARE( spyPolygonAdded.count(), shapesAdded );
-//  QCOMPARE( spyGroupAdded.count(), groupsAdded );
-//  QCOMPARE( spyItemRemoved.count(), ++itemsRemoved );
+  //  QCOMPARE( spyPolygonAdded.count(), shapesAdded );
+  //  QCOMPARE( spyGroupAdded.count(), groupsAdded );
+  //  QCOMPARE( spyItemRemoved.count(), ++itemsRemoved );
   l.layoutItems( items );
   QCOMPARE( items.size(), 2 ); // 2 shapes
   QCOMPARE( item1->pos(), QPointF( 58, 107 ) );
-  QCOMPARE( item2->pos(),  QPointF( 10, 20 ) );
+  QCOMPARE( item2->pos(), QPointF( 10, 20 ) );
   QVERIFY( !pGroup );
   //dumpUndoStack(*us, "after ungroup");
   // US 0: Items grouped
@@ -653,9 +649,9 @@ void TestQgsLayoutItemGroup::undoRedo()
   //undo (groups again) -- crashed here before #11371 got fixed
   QgsDebugMsgLevel( QStringLiteral( "undo ungrouping" ), 1 );
   us->undo();
-//  QCOMPARE( spyPolygonAdded.count(), shapesAdded );
-// QCOMPARE( spyGroupAdded.count(), ++groupsAdded );
-// QCOMPARE( spyItemRemoved.count(), itemsRemoved );
+  //  QCOMPARE( spyPolygonAdded.count(), shapesAdded );
+  // QCOMPARE( spyGroupAdded.count(), ++groupsAdded );
+  // QCOMPARE( spyItemRemoved.count(), itemsRemoved );
   QVERIFY( item1->isGroupMember() );
   QVERIFY( item2->isGroupMember() );
   QCOMPARE( item1->parentGroup(), item2->parentGroup() );
@@ -667,9 +663,9 @@ void TestQgsLayoutItemGroup::undoRedo()
   l.layoutItems( items );
   QCOMPARE( items.size(), 3 ); // 2 shapes, 1 group
   QCOMPARE( item1->pos(), QPointF( 58, 107 ) );
-  QCOMPARE( item2->pos(),  QPointF( 10, 20 ) );
+  QCOMPARE( item2->pos(), QPointF( 10, 20 ) );
 
-  QCOMPARE( group->pos(),  QPointF( 10, 20 ) );
+  QCOMPARE( group->pos(), QPointF( 10, 20 ) );
   //dumpUndoStack(*us, "after undo ungroup");
   // US 0: Items grouped
   // US 1: move group
@@ -678,7 +674,7 @@ void TestQgsLayoutItemGroup::undoRedo()
   //remove group
   QgsDebugMsgLevel( QStringLiteral( "remove group" ), 1 );
   l.removeLayoutItem( group );
-// QCOMPARE( spyPolygonAdded.count(), shapesAdded );
+  // QCOMPARE( spyPolygonAdded.count(), shapesAdded );
   //QCOMPARE( spyGroupAdded.count(), groupsAdded );
   //itemsRemoved += 3; // the group and the two items
   //QCOMPARE( spyItemRemoved.count(), itemsRemoved );
@@ -690,7 +686,7 @@ void TestQgsLayoutItemGroup::undoRedo()
 
   l.layoutItems( items );
   QCOMPARE( items.size(), 0 ); // nothing
-  QgsDebugMsgLevel( QStringLiteral( "remove stack count:%1 index:%2" ) .arg( us->count() ) .arg( us->index() ), 1 );
+  QgsDebugMsgLevel( QStringLiteral( "remove stack count:%1 index:%2" ).arg( us->count() ).arg( us->index() ), 1 );
   //dumpUndoStack(*us, "after remove group");
   // US 0: Items grouped
   // US 1: move group
@@ -704,16 +700,16 @@ void TestQgsLayoutItemGroup::undoRedo()
   //QCOMPARE( spyGroupAdded.count(), ++groupsAdded );
   //QCOMPARE( spyItemRemoved.count(), itemsRemoved );
   l.layoutItems( items );
-  group = dynamic_cast< QgsLayoutItemGroup * >( l.itemByUuid( groupUuid ) );
+  group = dynamic_cast<QgsLayoutItemGroup *>( l.itemByUuid( groupUuid ) );
   QVERIFY( group );
 
   QCOMPARE( group->items().size(), 2 );
   QCOMPARE( items.size(), 3 ); // 2 shapes, 1 group
-  item1 = dynamic_cast< QgsLayoutItemShape * >( l.itemByUuid( item1Uuid ) );
+  item1 = dynamic_cast<QgsLayoutItemShape *>( l.itemByUuid( item1Uuid ) );
   QCOMPARE( item1->parentGroup(), group );
-  item2 = dynamic_cast< QgsLayoutItemShape * >( l.itemByUuid( item2Uuid ) );
+  item2 = dynamic_cast<QgsLayoutItemShape *>( l.itemByUuid( item2Uuid ) );
   QCOMPARE( item2->parentGroup(), group );
-  QgsDebugMsgLevel( QStringLiteral( "undo stack count:%1 index:%2" ) .arg( us->count() ) .arg( us->index() ), 1 );
+  QgsDebugMsgLevel( QStringLiteral( "undo stack count:%1 index:%2" ).arg( us->count() ).arg( us->index() ), 1 );
   //dumpUndoStack(*us, "after undo remove group");
   // US 0: Items grouped
   // US 1: move group
@@ -722,15 +718,15 @@ void TestQgsLayoutItemGroup::undoRedo()
   //undo move group
   QgsDebugMsgLevel( QStringLiteral( "undo move group" ), 1 );
   us->undo();
-// QCOMPARE( spyPolygonAdded.count(), shapesAdded );
-// QCOMPARE( spyGroupAdded.count(), groupsAdded );
-// QCOMPARE( spyItemRemoved.count(), itemsRemoved );
+  // QCOMPARE( spyPolygonAdded.count(), shapesAdded );
+  // QCOMPARE( spyGroupAdded.count(), groupsAdded );
+  // QCOMPARE( spyItemRemoved.count(), itemsRemoved );
   QCOMPARE( group->items().size(), 2 );
   l.layoutItems( items );
   QCOMPARE( items.size(), 3 ); // 2 shapes, 1 group
   QCOMPARE( item1->isGroupMember(), true );
   QCOMPARE( item2->isGroupMember(), true );
-  QCOMPARE( item1->pos(),  QPointF( 50, 90 ) );
+  QCOMPARE( item1->pos(), QPointF( 50, 90 ) );
   QCOMPARE( item2->pos(), QPointF( 2, 3 ) );
   QCOMPARE( group->pos(), QPointF( 2, 3 ) );
   //dumpUndoStack(*us, "after undo move group");
@@ -770,7 +766,7 @@ void TestQgsLayoutItemGroup::undoRedo()
   QCOMPARE( items.size(), 3 ); // 2 shapes, 1 group
   QCOMPARE( item1->isGroupMember(), true );
   QCOMPARE( item2->isGroupMember(), true );
-  group = dynamic_cast< QgsLayoutItemGroup * >( l.itemByUuid( groupUuid ) );
+  group = dynamic_cast<QgsLayoutItemGroup *>( l.itemByUuid( groupUuid ) );
   QCOMPARE( group->pos(), QPointF( 2, 3 ) );
   //dumpUndoStack(*us, "after redo group");
   // US 0: Items grouped
@@ -815,7 +811,7 @@ void TestQgsLayoutItemGroup::undoRedo()
   QVERIFY( !pItem1 );
   QVERIFY( !pItem2 );
 
-  QgsDebugMsgLevel( QStringLiteral( "undo stack count:%1 index:%2" ) .arg( us->count() ) .arg( us->index() ), 1 );
+  QgsDebugMsgLevel( QStringLiteral( "undo stack count:%1 index:%2" ).arg( us->count() ).arg( us->index() ), 1 );
   //dumpUndoStack(*us, "after redo remove group");
   // US 0: Items grouped
   // US 1: move group
@@ -824,7 +820,7 @@ void TestQgsLayoutItemGroup::undoRedo()
   //unwind the whole stack
   us->clear();
 
-  QgsDebugMsgLevel( QStringLiteral( "clear stack count:%1 index:%2" ) .arg( us->count() ) .arg( us->index() ), 1 );
+  QgsDebugMsgLevel( QStringLiteral( "clear stack count:%1 index:%2" ).arg( us->count() ).arg( us->index() ), 1 );
 }
 
 QGSTEST_MAIN( TestQgsLayoutItemGroup )
