@@ -48,10 +48,10 @@ class TestQgsExternalResourceWidgetWrapper : public QObject
 {
     Q_OBJECT
   private slots:
-    void initTestCase();// will be called before the first testfunction is executed.
-    void cleanupTestCase();// will be called after the last testfunction was executed.
-    void init();// will be called before each testfunction is executed.
-    void cleanup();// will be called after every testfunction.
+    void initTestCase();    // will be called before the first testfunction is executed.
+    void cleanupTestCase(); // will be called after the last testfunction was executed.
+    void init();            // will be called before each testfunction is executed.
+    void cleanup();         // will be called after every testfunction.
     void testSetNullValues();
 
     void testUrlStorageExpression();
@@ -83,7 +83,6 @@ class QgsTestExternalStorageFetchedContent
     Q_OBJECT
 
   public:
-
     QgsTestExternalStorageFetchedContent( QString url )
       : QgsExternalStorageFetchedContent()
       , mCached( url.endsWith( QLatin1String( "cached.txt" ) ) )
@@ -128,7 +127,6 @@ class QgsTestExternalStorageFetchedContent
     }
 
   private:
-
     bool mCached = false;
     QString mUrl;
 };
@@ -139,10 +137,8 @@ class QgsTestExternalStorageStoredContent
     Q_OBJECT
 
   public:
-
     QgsTestExternalStorageStoredContent( const QString &url )
-      : QgsExternalStorageStoredContent(),
-        mUrl( url )
+      : QgsExternalStorageStoredContent(), mUrl( url )
     {
     }
 
@@ -173,11 +169,10 @@ class QgsTestExternalStorageStoredContent
     QString url() const override
     {
       return mUrl.endsWith( "/" ) ? QString( "http://www.test.com/here/myfile.txt" )
-             : mUrl;
+                                  : mUrl;
     }
 
   private:
-
     QString mUrl;
 };
 
@@ -185,7 +180,6 @@ class QgsTestExternalStorageStoredContent
 class QgsTestExternalStorage : public QgsExternalStorage
 {
   public:
-
     QString type() const override { return QStringLiteral( "test" ); }
 
     QString displayName() const override { return QStringLiteral( "Test" ); }
@@ -235,15 +229,13 @@ void TestQgsExternalResourceWidgetWrapper::cleanupTestCase()
 
 void TestQgsExternalResourceWidgetWrapper::init()
 {
-  vl = std::make_unique<QgsVectorLayer>( QStringLiteral( "NoGeometry?field=type:string&field=url:string" ),
-                                         QStringLiteral( "myvl" ),
-                                         QLatin1String( "memory" ) );
+  vl = std::make_unique<QgsVectorLayer>( QStringLiteral( "NoGeometry?field=type:string&field=url:string" ), QStringLiteral( "myvl" ), QLatin1String( "memory" ) );
 
-  QgsFeature feat1( vl->fields(),  1 );
+  QgsFeature feat1( vl->fields(), 1 );
   feat1.setAttribute( QStringLiteral( "type" ), QStringLiteral( "type1" ) );
   vl->dataProvider()->addFeature( feat1 );
 
-  QgsFeature feat2( vl->fields(),  2 );
+  QgsFeature feat2( vl->fields(), 2 );
   feat2.setAttribute( QStringLiteral( "type" ), QStringLiteral( "type2" ) );
   vl->dataProvider()->addFeature( feat2 );
 }
@@ -271,12 +263,12 @@ void TestQgsExternalResourceWidgetWrapper::testSetNullValues()
 
   ww.updateValues( QVariant() );
   QCOMPARE( ww.mLineEdit->text(), QgsApplication::nullRepresentation() );
-  QCOMPARE( ww.mQgsWidget->documentPath(), QVariant( QVariant::String ) );
+  QCOMPARE( ww.mQgsWidget->documentPath(), QgsVariantUtils::createNullVariant( QMetaType::Type::QString ) );
   QCOMPARE( spy.count(), 2 );
 
   ww.updateValues( QgsApplication::nullRepresentation() );
   QCOMPARE( ww.mLineEdit->text(), QgsApplication::nullRepresentation() );
-  QCOMPARE( ww.mQgsWidget->documentPath(), QVariant( QVariant::String ) );
+  QCOMPARE( ww.mQgsWidget->documentPath(), QgsVariantUtils::createNullVariant( QMetaType::Type::QString ) );
   QCOMPARE( spy.count(), 2 );
 
   delete widget;
@@ -298,10 +290,10 @@ void TestQgsExternalResourceWidgetWrapper::testUrlStorageExpression()
   QVariantMap config;
   config.insert( QStringLiteral( "StorageType" ), QStringLiteral( "test" ) );
   QgsPropertyCollection propertyCollection;
-  propertyCollection.setProperty( QgsWidgetWrapper::StorageUrl, QgsProperty::fromExpression(
-                                    "@myurl || @layer_name || '/' || \"type\" || '/' "
-                                    "|| attribute( @current_feature, 'type' ) "
-                                    "|| '/' || $id || '/test'", true ) );
+  propertyCollection.setProperty( QgsWidgetWrapper::Property::StorageUrl, QgsProperty::fromExpression( "@myurl || @layer_name || '/' || \"type\" || '/' "
+                                                                                                       "|| attribute( @current_feature, 'type' ) "
+                                                                                                       "|| '/' || $id || '/test'",
+                                                                                                       true ) );
   config.insert( QStringLiteral( "PropertyCollection" ), propertyCollection.toVariant( QgsWidgetWrapper::propertyDefinitions() ) );
   ww.setConfig( config );
 
@@ -319,8 +311,7 @@ void TestQgsExternalResourceWidgetWrapper::testUrlStorageExpression()
 
   QgsExpressionContext expressionContext = ww.mQgsWidget->fileWidget()->expressionContext();
   QVERIFY( expression->prepare( &expressionContext ) );
-  QCOMPARE( expression->evaluate( &expressionContext ).toString(),
-            QStringLiteral( "http://url.test.com/myvl/type1/type1/1/test" ) );
+  QCOMPARE( expression->evaluate( &expressionContext ).toString(), QStringLiteral( "http://url.test.com/myvl/type1/type1/1/test" ) );
 
   feat = vl->getFeature( 2 );
   QVERIFY( feat.isValid() );
@@ -328,8 +319,7 @@ void TestQgsExternalResourceWidgetWrapper::testUrlStorageExpression()
 
   expressionContext = ww.mQgsWidget->fileWidget()->expressionContext();
   QVERIFY( expression->prepare( &expressionContext ) );
-  QCOMPARE( expression->evaluate( &expressionContext ).toString(),
-            QStringLiteral( "http://url.test.com/myvl/type2/type2/2/test" ) );
+  QCOMPARE( expression->evaluate( &expressionContext ).toString(), QStringLiteral( "http://url.test.com/myvl/type2/type2/2/test" ) );
 }
 
 void TestQgsExternalResourceWidgetWrapper::testLoadExternalDocument_data()
@@ -375,11 +365,7 @@ void TestQgsExternalResourceWidgetWrapper::testLoadExternalDocument()
   if ( documentType == QgsExternalResourceWidget::Image )
   {
     QVERIFY( ww.mQgsWidget->mPixmapLabel->isVisible() );
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    QVERIFY( !ww.mQgsWidget->mPixmapLabel->pixmap() );
-#else
     QVERIFY( ww.mQgsWidget->mPixmapLabel->pixmap( Qt::ReturnByValue ).isNull() );
-#endif
   }
   else if ( documentType == QgsExternalResourceWidget::Audio )
   {
@@ -425,11 +411,7 @@ void TestQgsExternalResourceWidgetWrapper::testLoadExternalDocument()
   if ( documentType == QgsExternalResourceWidget::Image )
   {
     QVERIFY( ww.mQgsWidget->mPixmapLabel->isVisible() );
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    QVERIFY( ww.mQgsWidget->mPixmapLabel->pixmap() );
-#else
     QVERIFY( !ww.mQgsWidget->mPixmapLabel->pixmap( Qt::ReturnByValue ).isNull() );
-#endif
   }
 #ifdef WITH_QTWEBKIT
   else if ( documentType == QgsExternalResourceWidget::Web )
@@ -466,11 +448,7 @@ void TestQgsExternalResourceWidgetWrapper::testLoadExternalDocument()
   if ( documentType == QgsExternalResourceWidget::Image )
   {
     QVERIFY( ww.mQgsWidget->mPixmapLabel->isVisible() );
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    QVERIFY( ww.mQgsWidget->mPixmapLabel->pixmap() );
-#else
     QVERIFY( !ww.mQgsWidget->mPixmapLabel->pixmap( Qt::ReturnByValue ).isNull() );
-#endif
   }
 #ifdef WITH_QTWEBKIT
   else if ( documentType == QgsExternalResourceWidget::Web )
@@ -571,11 +549,7 @@ void TestQgsExternalResourceWidgetWrapper::testLoadNullExternalDocument()
   if ( documentType == QgsExternalResourceWidget::Image )
   {
     QVERIFY( ww.mQgsWidget->mPixmapLabel->isVisible() );
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    QVERIFY( !ww.mQgsWidget->mPixmapLabel->pixmap() );
-#else
     QVERIFY( ww.mQgsWidget->mPixmapLabel->pixmap( Qt::ReturnByValue ).isNull() );
-#endif
   }
   else if ( documentType == QgsExternalResourceWidget::Audio )
   {
@@ -607,11 +581,7 @@ void TestQgsExternalResourceWidgetWrapper::testLoadNullExternalDocument()
   if ( documentType == QgsExternalResourceWidget::Image )
   {
     QVERIFY( ww.mQgsWidget->mPixmapLabel->isVisible() );
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    QVERIFY( !ww.mQgsWidget->mPixmapLabel->pixmap() );
-#else
     QVERIFY( ww.mQgsWidget->mPixmapLabel->pixmap( Qt::ReturnByValue ).isNull() );
-#endif
   }
 #ifdef WITH_QTWEBKIT
   else if ( documentType == QgsExternalResourceWidget::Web )
@@ -626,7 +596,6 @@ void TestQgsExternalResourceWidgetWrapper::testLoadNullExternalDocument()
   QVERIFY( ww.mQgsWidget->mLoadingMovie->state() != QMovie::Running );
   QVERIFY( !ww.mQgsWidget->mErrorLabel->isVisible() );
   QVERIFY( !messageBar->currentItem() );
-
 }
 
 void TestQgsExternalResourceWidgetWrapper::testStoreExternalDocument_data()
@@ -657,9 +626,9 @@ void TestQgsExternalResourceWidgetWrapper::testStoreExternalDocument()
   config.insert( QStringLiteral( "DocumentViewer" ), documentType );
 
   QgsPropertyCollection propertyCollection;
-  propertyCollection.setProperty( QgsWidgetWrapper::StorageUrl, QgsProperty::fromExpression(
-                                    "'http://mytest.com/' || $id || '/' "
-                                    " || file_name(@selected_file_path)", true ) );
+  propertyCollection.setProperty( QgsWidgetWrapper::Property::StorageUrl, QgsProperty::fromExpression( "'http://mytest.com/' || $id || '/' "
+                                                                                                       " || file_name(@selected_file_path)",
+                                                                                                       true ) );
   config.insert( QStringLiteral( "PropertyCollection" ), propertyCollection.toVariant( QgsWidgetWrapper::propertyDefinitions() ) );
   ww.setConfig( config );
 
@@ -680,11 +649,7 @@ void TestQgsExternalResourceWidgetWrapper::testStoreExternalDocument()
   if ( documentType == QgsExternalResourceWidget::Image )
   {
     QVERIFY( ww.mQgsWidget->mPixmapLabel->isVisible() );
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    QVERIFY( !ww.mQgsWidget->mPixmapLabel->pixmap() );
-#else
     QVERIFY( ww.mQgsWidget->mPixmapLabel->pixmap( Qt::ReturnByValue ).isNull() );
-#endif
   }
   else if ( documentType == QgsExternalResourceWidget::Audio )
   {
@@ -760,9 +725,9 @@ void TestQgsExternalResourceWidgetWrapper::testStoreExternalDocumentError()
   config.insert( QStringLiteral( "StorageType" ), QStringLiteral( "test" ) );
   config.insert( QStringLiteral( "DocumentViewer" ), documentType );
   QgsPropertyCollection propertyCollection;
-  propertyCollection.setProperty( QgsWidgetWrapper::StorageUrl, QgsProperty::fromExpression(
-                                    "'http://mytest.com/' || $id || '/' "
-                                    " || file_name(@selected_file_path)", true ) );
+  propertyCollection.setProperty( QgsWidgetWrapper::Property::StorageUrl, QgsProperty::fromExpression( "'http://mytest.com/' || $id || '/' "
+                                                                                                       " || file_name(@selected_file_path)",
+                                                                                                       true ) );
   config.insert( QStringLiteral( "PropertyCollection" ), propertyCollection.toVariant( QgsWidgetWrapper::propertyDefinitions() ) );
   ww.setConfig( config );
 
@@ -783,11 +748,7 @@ void TestQgsExternalResourceWidgetWrapper::testStoreExternalDocumentError()
   if ( documentType == QgsExternalResourceWidget::Image )
   {
     QVERIFY( ww.mQgsWidget->mPixmapLabel->isVisible() );
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    QVERIFY( !ww.mQgsWidget->mPixmapLabel->pixmap() );
-#else
     QVERIFY( ww.mQgsWidget->mPixmapLabel->pixmap( Qt::ReturnByValue ).isNull() );
-#endif
   }
   else if ( documentType == QgsExternalResourceWidget::Audio )
   {
@@ -823,11 +784,7 @@ void TestQgsExternalResourceWidgetWrapper::testStoreExternalDocumentError()
   if ( documentType == QgsExternalResourceWidget::Image )
   {
     QVERIFY( ww.mQgsWidget->mPixmapLabel->isVisible() );
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    QVERIFY( !ww.mQgsWidget->mPixmapLabel->pixmap() );
-#else
     QVERIFY( ww.mQgsWidget->mPixmapLabel->pixmap( Qt::ReturnByValue ).isNull() );
-#endif
   }
 #ifdef WITH_QTWEBKIT
   else if ( documentType == QgsExternalResourceWidget::Web )
@@ -881,9 +838,9 @@ void TestQgsExternalResourceWidgetWrapper::testStoreExternalDocumentCancel()
   config.insert( QStringLiteral( "StorageType" ), QStringLiteral( "test" ) );
   config.insert( QStringLiteral( "DocumentViewer" ), documentType );
   QgsPropertyCollection propertyCollection;
-  propertyCollection.setProperty( QgsWidgetWrapper::StorageUrl, QgsProperty::fromExpression(
-                                    "'http://mytest.com/' || $id || '/' "
-                                    " || file_name(@selected_file_path)", true ) );
+  propertyCollection.setProperty( QgsWidgetWrapper::Property::StorageUrl, QgsProperty::fromExpression( "'http://mytest.com/' || $id || '/' "
+                                                                                                       " || file_name(@selected_file_path)",
+                                                                                                       true ) );
   config.insert( QStringLiteral( "PropertyCollection" ), propertyCollection.toVariant( QgsWidgetWrapper::propertyDefinitions() ) );
   ww.setConfig( config );
 
@@ -904,11 +861,7 @@ void TestQgsExternalResourceWidgetWrapper::testStoreExternalDocumentCancel()
   if ( documentType == QgsExternalResourceWidget::Image )
   {
     QVERIFY( ww.mQgsWidget->mPixmapLabel->isVisible() );
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    QVERIFY( !ww.mQgsWidget->mPixmapLabel->pixmap() );
-#else
     QVERIFY( ww.mQgsWidget->mPixmapLabel->pixmap( Qt::ReturnByValue ).isNull() );
-#endif
   }
   else if ( documentType == QgsExternalResourceWidget::Audio )
   {
@@ -947,11 +900,7 @@ void TestQgsExternalResourceWidgetWrapper::testStoreExternalDocumentCancel()
   if ( documentType == QgsExternalResourceWidget::Image )
   {
     QVERIFY( ww.mQgsWidget->mPixmapLabel->isVisible() );
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    QVERIFY( !ww.mQgsWidget->mPixmapLabel->pixmap() );
-#else
     QVERIFY( ww.mQgsWidget->mPixmapLabel->pixmap( Qt::ReturnByValue ).isNull() );
-#endif
   }
 #ifdef WITH_QTWEBKIT
   else if ( documentType == QgsExternalResourceWidget::Web )
@@ -1025,11 +974,7 @@ void TestQgsExternalResourceWidgetWrapper::testStoreExternalDocumentNoExpression
   if ( documentType == QgsExternalResourceWidget::Image )
   {
     QVERIFY( ww.mQgsWidget->mPixmapLabel->isVisible() );
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    QVERIFY( !ww.mQgsWidget->mPixmapLabel->pixmap() );
-#else
     QVERIFY( ww.mQgsWidget->mPixmapLabel->pixmap( Qt::ReturnByValue ).isNull() );
-#endif
   }
   else if ( documentType == QgsExternalResourceWidget::Audio )
   {
@@ -1120,11 +1065,7 @@ void TestQgsExternalResourceWidgetWrapper::testChangeValueBeforeLoaded()
   if ( documentType == QgsExternalResourceWidget::Image )
   {
     QVERIFY( ww.mQgsWidget->mPixmapLabel->isVisible() );
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    QVERIFY( !ww.mQgsWidget->mPixmapLabel->pixmap() );
-#else
     QVERIFY( ww.mQgsWidget->mPixmapLabel->pixmap( Qt::ReturnByValue ).isNull() );
-#endif
   }
   else if ( documentType == QgsExternalResourceWidget::Audio )
   {
@@ -1198,11 +1139,7 @@ void TestQgsExternalResourceWidgetWrapper::testChangeValueBeforeLoaded()
   if ( documentType == QgsExternalResourceWidget::Image )
   {
     QVERIFY( ww.mQgsWidget->mPixmapLabel->isVisible() );
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    QVERIFY( ww.mQgsWidget->mPixmapLabel->pixmap() );
-#else
     QVERIFY( !ww.mQgsWidget->mPixmapLabel->pixmap( Qt::ReturnByValue ).isNull() );
-#endif
   }
 #ifdef WITH_QTWEBKIT
   else if ( documentType == QgsExternalResourceWidget::Web )
@@ -1307,11 +1244,7 @@ void TestQgsExternalResourceWidgetWrapper::testChangeValueToNullBeforeLoaded()
   if ( documentType == QgsExternalResourceWidget::Image )
   {
     QVERIFY( ww.mQgsWidget->mPixmapLabel->isVisible() );
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    QVERIFY( !ww.mQgsWidget->mPixmapLabel->pixmap() );
-#else
     QVERIFY( ww.mQgsWidget->mPixmapLabel->pixmap( Qt::ReturnByValue ).isNull() );
-#endif
   }
   else if ( documentType == QgsExternalResourceWidget::Audio )
   {
@@ -1358,11 +1291,7 @@ void TestQgsExternalResourceWidgetWrapper::testChangeValueToNullBeforeLoaded()
   if ( documentType == QgsExternalResourceWidget::Image )
   {
     QVERIFY( ww.mQgsWidget->mPixmapLabel->isVisible() );
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    QVERIFY( !ww.mQgsWidget->mPixmapLabel->pixmap() );
-#else
     QVERIFY( ww.mQgsWidget->mPixmapLabel->pixmap( Qt::ReturnByValue ).isNull() );
-#endif
   }
 #ifdef WITH_QTWEBKIT
   else if ( documentType == QgsExternalResourceWidget::Web )
@@ -1389,6 +1318,5 @@ void TestQgsExternalResourceWidgetWrapper::testChangeValueToNullBeforeLoaded()
 }
 
 
-
 QGSTEST_MAIN( TestQgsExternalResourceWidgetWrapper )
 #include "testqgsexternalresourcewidgetwrapper.moc"
