@@ -5,13 +5,13 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 """
-__author__ = 'Matthias Kuhn'
-__date__ = '15.4.2016'
-__copyright__ = 'Copyright 2015, The QGIS Project'
+
+__author__ = "Matthias Kuhn"
+__date__ = "15.4.2016"
+__copyright__ = "Copyright 2015, The QGIS Project"
 
 import os
 
-import qgis  # NOQA
 from console import console
 from qgis.PyQt.QtCore import QCoreApplication
 from qgis.core import QgsSettings
@@ -24,10 +24,10 @@ start_app()
 class TestConsole(QgisTestCase):
 
     def setUp(self):
-        QgsSettings().setValue('pythonConsole/contextHelpOnFirstLaunch', False)
+        QgsSettings().setValue("pythonConsole/contextHelpOnFirstLaunch", False)
 
     def test_show_console(self):
-        if os.name == 'nt':
+        if os.name == "nt":
             QCoreApplication.setOrganizationName("QGIS")
             QCoreApplication.setOrganizationDomain("qgis.org")
             QCoreApplication.setApplicationName("QGIS-TEST")
