@@ -5,14 +5,15 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 """
-__author__ = 'Nathan Woodrow'
-__date__ = '4/11/2012'
-__copyright__ = 'Copyright 2012, The QGIS Project'
 
-import qgis  # NOQA
+__author__ = "Nathan Woodrow"
+__date__ = "4/11/2012"
+__copyright__ = "Copyright 2012, The QGIS Project"
+
 from qgis.PyQt.QtCore import QVariant
 from qgis.core import (
     NULL,
+    QgsCoordinateReferenceSystem,
     QgsExpression,
     QgsExpressionContext,
     QgsExpressionContextUtils,
@@ -28,110 +29,119 @@ from qgis.utils import qgsfunction
 
 class TestQgsExpressionCustomFunctions(unittest.TestCase):
 
-    @qgsfunction(1, 'testing', register=False)
+    @qgsfunction(1, "testing", register=False)
     def testfun(values, feature, parent):
-        """ Function help """
+        """Function help"""
         return f"Testing_{values[0]}"
 
-    @qgsfunction(args="auto", group='testing', register=False)
+    @qgsfunction(args="auto", group="testing", register=False)
     def expandargs(value1, value2, value3, feature, parent):
         return value1, value2, value3
 
-    @qgsfunction(args=0, group='testing', register=False)
+    @qgsfunction(args=0, group="testing", register=False)
     def special(values, feature, parent):
         return "test"
 
-    @qgsfunction(1, 'testing', register=False)
+    @qgsfunction(1, "testing", register=False)
     def sqrt(values, feature, parent):
         pass
 
-    @qgsfunction(1, 'testing', register=False)
+    @qgsfunction(1, "testing", register=False)
     def help_with_docstring(values, feature, parent):
         """The help comes from the python docstring."""
         pass
 
-    help_text = 'The help comes from a variable.'
+    help_text = "The help comes from a variable."
 
-    @qgsfunction(1, 'testing', register=False, helpText=help_text)
+    @qgsfunction(1, "testing", register=False, helpText=help_text)
     def help_with_variable(values, feature, parent):
         """This docstring is not used for the help."""
         pass
 
-    @qgsfunction(1, 'testing', register=False, usesgeometry=True)
+    @qgsfunction(1, "testing", register=False, usesgeometry=True)
     def geomtest(values, feature, parent):
         pass
 
-    @qgsfunction(args=0, group='testing', register=False)
+    @qgsfunction(args=0, group="testing", register=False)
     def no_referenced_columns_set(values, feature, parent):
         return 1
 
-    @qgsfunction(args=0, group='testing', register=False, referenced_columns=['a', 'b'])
+    @qgsfunction(args=0, group="testing", register=False, referenced_columns=["a", "b"])
     def referenced_columns_set(values, feature, parent):
         return 2
 
-    @qgsfunction(args=-1, group='testing', register=False, handlesnull=True)
+    @qgsfunction(args=-1, group="testing", register=False, handlesnull=True)
     def null_mean(values, feature, parent):
         vals = [val for val in values if val != NULL]
         return sum(vals) / len(vals)
 
-    @qgsfunction(group='testing', register=False)
+    @qgsfunction(group="testing", register=False)
     def raise_exception(feature, parent):
         # an undefined variable
         foo  # noqa: F821
 
-    @qgsfunction(group='testing', register=False)
+    @qgsfunction(group="testing", register=False)
     def simple_sum(val1, val2):
         return val1 + val2
 
-    @qgsfunction(group='testing', register=False)
+    @qgsfunction(group="testing", register=False)
     def sum_vargs(val1, *args):
         return val1 + sum(args)
 
-    @qgsfunction(group='testing', args=-1, register=False)
+    @qgsfunction(group="testing", args=-1, register=False)
     def func_params_as_list_legacy(values, feature, parent):
         return values
 
-    @qgsfunction(group='testing', params_as_list=True, register=False)
+    @qgsfunction(group="testing", params_as_list=True, register=False)
     def func_params_as_list(values):
         return values
 
-    @qgsfunction(group='testing', register=False)
+    @qgsfunction(group="testing", register=False)
     def func_params_no_list(values):
         return values
 
-    @qgsfunction(group='testing', register=False)
+    @qgsfunction(group="testing", register=False)
     def func_feature(*args, feature):
         return (feature["a"] + sum(args)) * feature["b"]
 
-    @qgsfunction(group='testing', register=False)
+    @qgsfunction(group="testing", register=False)
     def func_layer_name_operation(operation="upper", context=None):
         return getattr(context.variable("layer_name"), operation)()
 
     def tearDown(self):
-        QgsExpression.unregisterFunction('testfun')
+        QgsExpression.unregisterFunction("testfun")
 
     def testCanBeRegistered(self):
         QgsExpression.registerFunction(self.testfun)
-        index = QgsExpression.functionIndex('testfun')
+        index = QgsExpression.functionIndex("testfun")
         self.assertNotEqual(index, -1)
 
     def testHelpPythonFunction(self):
         """Test help about python function."""
         QgsExpression.registerFunction(self.help_with_variable)
-        html = ('<h3>help_with_variable function</h3><br>'
-                'The help comes from a variable.')
+        html = (
+            "<h3>help_with_variable function</h3><br>" "The help comes from a variable."
+        )
         self.assertEqual(self.help_with_variable.helpText(), html)
 
         QgsExpression.registerFunction(self.help_with_docstring)
-        html = ('<h3>help_with_docstring function</h3><br>'
-                'The help comes from the python docstring.')
+        html = (
+            "<h3>help_with_docstring function</h3><br>"
+            "The help comes from the python docstring."
+        )
         self.assertEqual(self.help_with_docstring.helpText(), html)
 
     def testHelpString(self):
         """Test add custom help string."""
-        self.assertTrue(QgsExpression.addVariableHelpText("custom_variable_help", "custom help 1"))
-        self.assertFalse(QgsExpression.addVariableHelpText("custom_variable_help", "other help 2"))
-        self.assertEqual(QgsExpression.variableHelpText("custom_variable_help"), "custom help 1")
+        self.assertTrue(
+            QgsExpression.addVariableHelpText("custom_variable_help", "custom help 1")
+        )
+        self.assertFalse(
+            QgsExpression.addVariableHelpText("custom_variable_help", "other help 2")
+        )
+        self.assertEqual(
+            QgsExpression.variableHelpText("custom_variable_help"), "custom help 1"
+        )
 
     def testAutoArgsAreExpanded(self):
         function = self.expandargs
@@ -144,31 +154,31 @@ class TestQgsExpressionCustomFunctions(unittest.TestCase):
 
     def testCanUnregisterFunction(self):
         QgsExpression.registerFunction(self.testfun)
-        index = QgsExpression.functionIndex('testfun')
+        index = QgsExpression.functionIndex("testfun")
         self.assertNotEqual(index, -1)
-        error = QgsExpression.unregisterFunction('testfun')
+        error = QgsExpression.unregisterFunction("testfun")
         self.assertTrue(error)
-        index = QgsExpression.functionIndex('testfun')
+        index = QgsExpression.functionIndex("testfun")
         self.assertEqual(index, -1)
 
     def testCanEvaluateFunction(self):
         QgsExpression.registerFunction(self.testfun)
-        exp = QgsExpression('testfun(1)')
+        exp = QgsExpression("testfun(1)")
         result = exp.evaluate()
-        self.assertEqual('Testing_1', result)
+        self.assertEqual("Testing_1", result)
 
     def testZeroArgFunctionsTakeNoArgs(self):
         QgsExpression.registerFunction(self.special)
         special = self.special
-        self.assertEqual(special.name(), 'special')
-        exp = QgsExpression('special()')
+        self.assertEqual(special.name(), "special")
+        exp = QgsExpression("special()")
         result = exp.evaluate()
-        self.assertEqual('test', result)
+        self.assertEqual("test", result)
 
     def testDecoratorPreservesAttributes(self):
         func = self.testfun
-        self.assertEqual(func.name(), 'testfun')
-        self.assertEqual(func.group(), 'testing')
+        self.assertEqual(func.name(), "testfun")
+        self.assertEqual(func.group(), "testing")
 
     def testCantReregister(self):
         QgsExpression.registerFunction(self.testfun)
@@ -191,19 +201,18 @@ class TestQgsExpressionCustomFunctions(unittest.TestCase):
 
     def testReferencedColumnsNoSet(self):
         QgsExpression.registerFunction(self.no_referenced_columns_set)
-        exp = QgsExpression('no_referenced_columns_set()')
-        self.assertEqual(exp.referencedColumns(),
-                         {QgsFeatureRequest.ALL_ATTRIBUTES})
+        exp = QgsExpression("no_referenced_columns_set()")
+        self.assertEqual(exp.referencedColumns(), {QgsFeatureRequest.ALL_ATTRIBUTES})
 
     def testReferencedColumnsSet(self):
         QgsExpression.registerFunction(self.referenced_columns_set)
-        exp = QgsExpression('referenced_columns_set()')
-        self.assertEqual(set(exp.referencedColumns()), {'a', 'b'})
+        exp = QgsExpression("referenced_columns_set()")
+        self.assertEqual(set(exp.referencedColumns()), {"a", "b"})
 
     def testHandlesNull(self):
         context = QgsExpressionContext()
         QgsExpression.registerFunction(self.null_mean)
-        exp = QgsExpression('null_mean(1, 2, NULL, 3)')
+        exp = QgsExpression("null_mean(1, 2, NULL, 3)")
         result = exp.evaluate(context)
         self.assertFalse(exp.hasEvalError())
         self.assertEqual(result, 2)
@@ -216,8 +225,8 @@ class TestQgsExpressionCustomFunctions(unittest.TestCase):
         for txt in [
             "id",
             "idä",
-            "\"id abc\"",
-            "\"id	abc\"",
+            '"id abc"',
+            '"id	abc"',
             "  abc   ",
             " /* co */ da ",
         ]:
@@ -225,20 +234,20 @@ class TestQgsExpressionCustomFunctions(unittest.TestCase):
 
     def testBlockComment(self):
         expressions = {
-            "'test' /* comment */": 'test',
-            "/* comment */'test'": 'test',
-            "/* comment */'test*/'": 'test*/',
-            "/** comment */'test*/'": 'test*/',
-            "/* comment **/'test*/' /* comment */": 'test*/',
-            "'test/*'/* comment */": 'test/*',
+            "'test' /* comment */": "test",
+            "/* comment */'test'": "test",
+            "/* comment */'test*/'": "test*/",
+            "/** comment */'test*/'": "test*/",
+            "/* comment **/'test*/' /* comment */": "test*/",
+            "'test/*'/* comment */": "test/*",
             """/**
             comment
             **/
-            'test*/'""": 'test*/',
+            'test*/'""": "test*/",
             """'test*/'
             /**
             comment
-            **/""": 'test*/'
+            **/""": "test*/",
         }
         for e, exp_res in list(expressions.items()):
             exp = QgsExpression(e)
@@ -247,12 +256,12 @@ class TestQgsExpressionCustomFunctions(unittest.TestCase):
 
     def testComment(self):
         expressions = {
-            "'test' -- comment\n": 'test',
-            "'test--'\n": 'test--',
-            "'--test'\n": '--test',
-            "'test' -- comment": 'test',
-            "'test--'": 'test--',
-            "'--test'": '--test',
+            "'test' -- comment\n": "test",
+            "'test--'\n": "test--",
+            "'--test'\n": "--test",
+            "'test' -- comment": "test",
+            "'test--'": "test--",
+            "'--test'": "--test",
         }
         for e, exp_res in list(expressions.items()):
             exp = QgsExpression(e)
@@ -262,9 +271,9 @@ class TestQgsExpressionCustomFunctions(unittest.TestCase):
     def testValid(self):
         e = QgsExpression()
         self.assertFalse(e.isValid())
-        e.setExpression('asdf||#@¼')
+        e.setExpression("asdf||#@¼")
         self.assertFalse(e.isValid())
-        e.setExpression('1')
+        e.setExpression("1")
         self.assertTrue(e.isValid())
 
     def testCreateFieldEqualityExpression(self):
@@ -272,13 +281,13 @@ class TestQgsExpressionCustomFunctions(unittest.TestCase):
 
         # test when value is null
         field = "myfield"
-        value = QVariant()
+        value = NULL
         res = '"myfield" IS NULL'
         self.assertEqual(e.createFieldEqualityExpression(field, value), res)
 
         # test when value is null and field name has a quote
         field = "my'field"
-        value = QVariant()
+        value = NULL
         res = '"my\'field" IS NULL'
         self.assertEqual(e.createFieldEqualityExpression(field, value), res)
 
@@ -290,8 +299,8 @@ class TestQgsExpressionCustomFunctions(unittest.TestCase):
 
         # test when field name has a quote and value is a string
         field = "my'field"
-        value = '5'
-        res = '"my\'field" = \'5\''
+        value = "5"
+        res = "\"my'field\" = '5'"
         self.assertEqual(e.createFieldEqualityExpression(field, value), res)
 
         # test when field name has a quote and value is a boolean
@@ -304,7 +313,7 @@ class TestQgsExpressionCustomFunctions(unittest.TestCase):
         field = "myfield"
         value = 1
         type = QVariant.String
-        res = '"myfield" = \'1\''
+        res = "\"myfield\" = '1'"
         self.assertEqual(e.createFieldEqualityExpression(field, value, type), res)
 
         # test with field type
@@ -325,7 +334,9 @@ class TestQgsExpressionCustomFunctions(unittest.TestCase):
         self.assertEqual(exp.evalErrorString(), "")
 
     def testEvalTemplate(self):
-        layer = QgsVectorLayer("Point?field=a:int&field=b:string", "test eval-template", "memory")
+        layer = QgsVectorLayer(
+            "Point?field=a:int&field=b:string", "test eval-template", "memory"
+        )
         context = layer.createExpressionContext()
 
         expression = QgsExpression("eval_template('123 [% \"b\" %] 789')")
@@ -336,25 +347,25 @@ class TestQgsExpressionCustomFunctions(unittest.TestCase):
         self.assertTrue(QgsFeatureRequest.ALL_ATTRIBUTES in columns)
 
         feature = QgsFeature(layer.fields())
-        feature.setAttributes([1, '456'])
+        feature.setAttributes([1, "456"])
         context.setFeature(feature)
 
-        self.assertEqual(expression.evaluate(context), '123 456 789')
+        self.assertEqual(expression.evaluate(context), "123 456 789")
 
     def testExceptionDuringEvalReturnsTraceback(self):
         QgsExpression.registerFunction(self.raise_exception)
-        exp = QgsExpression('raise_exception()')
+        exp = QgsExpression("raise_exception()")
         result = exp.evaluate()
         # The file paths and line offsets are dynamic
         regex = (
             "name 'foo' is not defined:<pre>Traceback \\(most recent call last\\):\n"
-            "  File \".*qgsfunction.py\", line [0-9]+, in func\n"
+            '  File ".*qgsfunction.py", line [0-9]+, in func\n'
             "    return self.function\\(\\*values, \\*\\*kwvalues\\)\n"
             "(.*?\n)?"
-            "  File \".*test_qgsexpression.py\", line [0-9]+, in raise_exception\n"
+            '  File ".*test_qgsexpression.py", line [0-9]+, in raise_exception\n'
             "    foo  # noqa: F821\n"
             "(.*?\n)?"
-            "NameError: name \'foo\' is not defined"
+            "NameError: name 'foo' is not defined"
             "\n</pre>"
         )
         self.assertRegex(exp.evalErrorString(), regex)
@@ -453,7 +464,9 @@ class TestQgsExpressionCustomFunctions(unittest.TestCase):
         QgsExpression.registerFunction(self.func_layer_name_operation)
         context = QgsExpressionContext()
 
-        layer = QgsVectorLayer("Point?field=a:int&field=b:string", "test context", "memory")
+        layer = QgsVectorLayer(
+            "Point?field=a:int&field=b:string", "test context", "memory"
+        )
         context.appendScope(QgsExpressionContextUtils.layerScope(layer))
 
         e = QgsExpression()
@@ -464,6 +477,28 @@ class TestQgsExpressionCustomFunctions(unittest.TestCase):
         e.setExpression("func_layer_name_operation('split')")
         self.assertEqual(e.evaluate(context), ["test", "context"])
 
+    def testLayerScopeVerticalCrs(self):
+        layer = QgsVectorLayer("Point?field=fldtxt:string", "layer", "memory")
+
+        # vertical crs info should be present in layer expression context scope
+        layer.setVerticalCrs(QgsCoordinateReferenceSystem("EPSG:5703"))
+        scope = QgsExpressionContextUtils.layerScope(layer)
+        self.assertEqual(scope.variable("layer_vertical_crs"), "EPSG:5703")
+        self.assertEqual(
+            scope.variable("layer_vertical_crs_definition"), "+vunits=m +no_defs"
+        )
+        self.assertEqual(
+            scope.variable("layer_vertical_crs_description"), "NAVD88 height"
+        )
+        self.assertEqual(scope.variable("layer_vertical_crs_wkt")[:7], "VERTCRS")
+
+        layer.setVerticalCrs(QgsCoordinateReferenceSystem())
+        scope = QgsExpressionContextUtils.layerScope(layer)
+        self.assertFalse(scope.variable("layer_vertical_crs"))
+        self.assertFalse(scope.variable("layer_vertical_crs_definition"))
+        self.assertFalse(scope.variable("layer_vertical_crs_description"))
+        self.assertFalse(scope.variable("layer_vertical_crs_wkt"))
+
 
 if __name__ == "__main__":
     unittest.main()
