@@ -5,11 +5,11 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 """
-__author__ = 'Nyall Dawson'
-__date__ = '12/06/2020'
-__copyright__ = 'Copyright 2020, The QGIS Project'
 
-import qgis  # NOQA
+__author__ = "Nyall Dawson"
+__date__ = "12/06/2020"
+__copyright__ = "Copyright 2020, The QGIS Project"
+
 from qgis.PyQt.QtCore import QVariant
 from qgis.core import (
     Qgis,
@@ -23,6 +23,7 @@ from qgis.core import (
     QgsGeometry,
     QgsRectangle,
     QgsSimplifyMethod,
+    QgsCoordinateTransform,
 )
 import unittest
 from qgis.testing import start_app, QgisTestCase
@@ -41,7 +42,7 @@ class TestQgsFeatureRequest(QgisTestCase):
 
     def testConstructors(self):
         req = QgsFeatureRequest()
-        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterNone)
+        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterType.FilterNone)
         self.assertEqual(req.spatialFilterType(), Qgis.SpatialFilterType.NoFilter)
         self.assertEqual(req.filterFid(), -1)
         self.assertFalse(req.filterFids())
@@ -49,7 +50,7 @@ class TestQgsFeatureRequest(QgisTestCase):
         self.assertTrue(req.referenceGeometry().isNull())
 
         req = QgsFeatureRequest(55)
-        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterFid)
+        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterType.FilterFid)
         self.assertEqual(req.spatialFilterType(), Qgis.SpatialFilterType.NoFilter)
         self.assertEqual(req.filterFid(), 55)
         self.assertFalse(req.filterFids())
@@ -57,7 +58,7 @@ class TestQgsFeatureRequest(QgisTestCase):
         self.assertTrue(req.referenceGeometry().isNull())
 
         req = QgsFeatureRequest([55, 56])
-        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterFids)
+        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterType.FilterFids)
         self.assertEqual(req.spatialFilterType(), Qgis.SpatialFilterType.NoFilter)
         self.assertEqual(req.filterFid(), -1)
         self.assertCountEqual(req.filterFids(), [55, 56])
@@ -65,7 +66,7 @@ class TestQgsFeatureRequest(QgisTestCase):
         self.assertTrue(req.referenceGeometry().isNull())
 
         req = QgsFeatureRequest(QgsRectangle(55, 56, 57, 58))
-        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterNone)
+        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterType.FilterNone)
         self.assertEqual(req.spatialFilterType(), Qgis.SpatialFilterType.BoundingBox)
         self.assertEqual(req.filterFid(), -1)
         self.assertCountEqual(req.filterFids(), [])
@@ -74,7 +75,7 @@ class TestQgsFeatureRequest(QgisTestCase):
 
     def testFilterRect(self):
         req = QgsFeatureRequest().setFilterRect(QgsRectangle(1, 2, 3, 4))
-        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterNone)
+        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterType.FilterNone)
         self.assertEqual(req.spatialFilterType(), Qgis.SpatialFilterType.BoundingBox)
         self.assertEqual(req.filterFid(), -1)
         self.assertFalse(req.filterFids())
@@ -82,24 +83,30 @@ class TestQgsFeatureRequest(QgisTestCase):
         self.assertTrue(req.referenceGeometry().isNull())
 
         # setting filter rect should not change attribute filter
-        req = QgsFeatureRequest().setFilterFid(5).setFilterRect(QgsRectangle(1, 2, 3, 4))
-        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterFid)
+        req = (
+            QgsFeatureRequest().setFilterFid(5).setFilterRect(QgsRectangle(1, 2, 3, 4))
+        )
+        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterType.FilterFid)
         self.assertEqual(req.spatialFilterType(), Qgis.SpatialFilterType.BoundingBox)
         self.assertEqual(req.filterFid(), 5)
         self.assertFalse(req.filterFids())
         self.assertEqual(req.filterRect(), QgsRectangle(1, 2, 3, 4))
 
         # setting attribute filter should not change filter rect
-        req = QgsFeatureRequest().setFilterRect(QgsRectangle(1, 2, 3, 4)).setFilterFid(5)
-        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterFid)
+        req = (
+            QgsFeatureRequest().setFilterRect(QgsRectangle(1, 2, 3, 4)).setFilterFid(5)
+        )
+        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterType.FilterFid)
         self.assertEqual(req.spatialFilterType(), Qgis.SpatialFilterType.BoundingBox)
         self.assertEqual(req.filterFid(), 5)
         self.assertFalse(req.filterFids())
         self.assertEqual(req.filterRect(), QgsRectangle(1, 2, 3, 4))
 
         # setting null rectangle should clear spatial filter
-        req = QgsFeatureRequest().setFilterFid(5).setFilterRect(QgsRectangle(1, 2, 3, 4))
-        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterFid)
+        req = (
+            QgsFeatureRequest().setFilterFid(5).setFilterRect(QgsRectangle(1, 2, 3, 4))
+        )
+        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterType.FilterFid)
         self.assertEqual(req.spatialFilterType(), Qgis.SpatialFilterType.BoundingBox)
         self.assertEqual(req.filterFid(), 5)
         self.assertFalse(req.filterFids())
@@ -110,51 +117,71 @@ class TestQgsFeatureRequest(QgisTestCase):
 
         # setting distance within should override filter rect
         req = QgsFeatureRequest().setFilterRect(QgsRectangle(1, 2, 3, 4))
-        req.setDistanceWithin(QgsGeometry.fromWkt('LineString(0 0, 10 0, 11 2)'), 1.2)
-        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterNone)
+        req.setDistanceWithin(QgsGeometry.fromWkt("LineString(0 0, 10 0, 11 2)"), 1.2)
+        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterType.FilterNone)
         self.assertEqual(req.spatialFilterType(), Qgis.SpatialFilterType.DistanceWithin)
         self.assertEqual(req.filterFid(), -1)
         self.assertFalse(req.filterFids())
-        self.assertEqual(req.referenceGeometry().asWkt(), 'LineString (0 0, 10 0, 11 2)')
+        self.assertEqual(
+            req.referenceGeometry().asWkt(), "LineString (0 0, 10 0, 11 2)"
+        )
         self.assertEqual(req.distanceWithin(), 1.2)
 
     def testDistanceWithin(self):
-        req = QgsFeatureRequest().setDistanceWithin(QgsGeometry.fromWkt('LineString(0 0, 10 0, 11 2)'), 1.2)
-        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterNone)
+        req = QgsFeatureRequest().setDistanceWithin(
+            QgsGeometry.fromWkt("LineString(0 0, 10 0, 11 2)"), 1.2
+        )
+        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterType.FilterNone)
         self.assertEqual(req.spatialFilterType(), Qgis.SpatialFilterType.DistanceWithin)
         self.assertEqual(req.filterFid(), -1)
         self.assertFalse(req.filterFids())
-        self.assertEqual(req.referenceGeometry().asWkt(), 'LineString (0 0, 10 0, 11 2)')
+        self.assertEqual(
+            req.referenceGeometry().asWkt(), "LineString (0 0, 10 0, 11 2)"
+        )
         self.assertEqual(req.distanceWithin(), 1.2)
         # filter rect should reflect bounding box of linestring + 1.2
         self.assertEqual(req.filterRect(), QgsRectangle(-1.2, -1.2, 12.2, 3.2))
 
         # setting distance within should not change attribute filter
-        req = QgsFeatureRequest().setFilterFid(5).setDistanceWithin(QgsGeometry.fromWkt('LineString(0 0, 10 0, 11 2)'), 1.2)
-        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterFid)
+        req = (
+            QgsFeatureRequest()
+            .setFilterFid(5)
+            .setDistanceWithin(QgsGeometry.fromWkt("LineString(0 0, 10 0, 11 2)"), 1.2)
+        )
+        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterType.FilterFid)
         self.assertEqual(req.spatialFilterType(), Qgis.SpatialFilterType.DistanceWithin)
         self.assertEqual(req.filterFid(), 5)
         self.assertFalse(req.filterFids())
-        self.assertEqual(req.referenceGeometry().asWkt(), 'LineString (0 0, 10 0, 11 2)')
+        self.assertEqual(
+            req.referenceGeometry().asWkt(), "LineString (0 0, 10 0, 11 2)"
+        )
         self.assertEqual(req.distanceWithin(), 1.2)
         # filter rect should reflect bounding box of linestring + 1.2
         self.assertEqual(req.filterRect(), QgsRectangle(-1.2, -1.2, 12.2, 3.2))
 
         # setting attribute filter should not change distance within
-        req = QgsFeatureRequest().setDistanceWithin(QgsGeometry.fromWkt('LineString(0 0, 10 0, 11 2)'), 1.2).setFilterFid(5)
-        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterFid)
+        req = (
+            QgsFeatureRequest()
+            .setDistanceWithin(QgsGeometry.fromWkt("LineString(0 0, 10 0, 11 2)"), 1.2)
+            .setFilterFid(5)
+        )
+        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterType.FilterFid)
         self.assertEqual(req.spatialFilterType(), Qgis.SpatialFilterType.DistanceWithin)
         self.assertEqual(req.filterFid(), 5)
         self.assertFalse(req.filterFids())
-        self.assertEqual(req.referenceGeometry().asWkt(), 'LineString (0 0, 10 0, 11 2)')
+        self.assertEqual(
+            req.referenceGeometry().asWkt(), "LineString (0 0, 10 0, 11 2)"
+        )
         self.assertEqual(req.distanceWithin(), 1.2)
         # filter rect should reflect bounding box of linestring + 1.2
         self.assertEqual(req.filterRect(), QgsRectangle(-1.2, -1.2, 12.2, 3.2))
 
         # setting filter rect should override distance within
-        req = QgsFeatureRequest().setDistanceWithin(QgsGeometry.fromWkt('LineString(0 0, 10 0, 11 2)'), 1.2)
+        req = QgsFeatureRequest().setDistanceWithin(
+            QgsGeometry.fromWkt("LineString(0 0, 10 0, 11 2)"), 1.2
+        )
         req.setFilterRect(QgsRectangle(1, 2, 3, 4))
-        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterNone)
+        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterType.FilterNone)
         self.assertEqual(req.spatialFilterType(), Qgis.SpatialFilterType.BoundingBox)
         self.assertEqual(req.filterFid(), -1)
         self.assertFalse(req.filterFids())
@@ -162,9 +189,11 @@ class TestQgsFeatureRequest(QgisTestCase):
         self.assertTrue(req.referenceGeometry().isNull())
         self.assertEqual(req.distanceWithin(), 0)
 
-        req = QgsFeatureRequest().setDistanceWithin(QgsGeometry.fromWkt('LineString(0 0, 10 0, 11 2)'), 1.2)
+        req = QgsFeatureRequest().setDistanceWithin(
+            QgsGeometry.fromWkt("LineString(0 0, 10 0, 11 2)"), 1.2
+        )
         req.setFilterRect(QgsRectangle())
-        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterNone)
+        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterType.FilterNone)
         self.assertEqual(req.spatialFilterType(), Qgis.SpatialFilterType.NoFilter)
         self.assertEqual(req.filterFid(), -1)
         self.assertFalse(req.filterFids())
@@ -174,7 +203,7 @@ class TestQgsFeatureRequest(QgisTestCase):
 
     def testFilterFid(self):
         req = QgsFeatureRequest().setFilterFid(5)
-        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterFid)
+        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterType.FilterFid)
         self.assertEqual(req.spatialFilterType(), Qgis.SpatialFilterType.NoFilter)
         self.assertEqual(req.filterFid(), 5)
         self.assertFalse(req.filterFids())
@@ -183,20 +212,20 @@ class TestQgsFeatureRequest(QgisTestCase):
 
         # filter rect doesn't affect fid filter
         req.setFilterRect(QgsRectangle(1, 2, 3, 4))
-        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterFid)
+        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterType.FilterFid)
         self.assertEqual(req.filterFid(), 5)
         self.assertEqual(req.spatialFilterType(), Qgis.SpatialFilterType.BoundingBox)
         self.assertEqual(req.filterRect(), QgsRectangle(1, 2, 3, 4))
         self.assertTrue(req.referenceGeometry().isNull())
         req.setFilterFid(6)
-        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterFid)
+        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterType.FilterFid)
         self.assertEqual(req.filterFid(), 6)
         self.assertEqual(req.spatialFilterType(), Qgis.SpatialFilterType.BoundingBox)
         self.assertEqual(req.filterRect(), QgsRectangle(1, 2, 3, 4))
 
     def testFilterFids(self):
         req = QgsFeatureRequest().setFilterFids([5, 6])
-        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterFids)
+        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterType.FilterFids)
         self.assertEqual(req.spatialFilterType(), Qgis.SpatialFilterType.NoFilter)
         self.assertEqual(req.filterFid(), -1)
         self.assertCountEqual(req.filterFids(), [5, 6])
@@ -205,14 +234,14 @@ class TestQgsFeatureRequest(QgisTestCase):
 
         # filter rect doesn't affect fids filter
         req.setFilterRect(QgsRectangle(1, 2, 3, 4))
-        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterFids)
+        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterType.FilterFids)
         self.assertEqual(req.filterFid(), -1)
         self.assertCountEqual(req.filterFids(), [5, 6])
         self.assertEqual(req.spatialFilterType(), Qgis.SpatialFilterType.BoundingBox)
         self.assertEqual(req.filterRect(), QgsRectangle(1, 2, 3, 4))
         self.assertTrue(req.referenceGeometry().isNull())
         req.setFilterFids([8, 9])
-        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterFids)
+        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterType.FilterFids)
         self.assertEqual(req.filterFid(), -1)
         self.assertCountEqual(req.filterFids(), [8, 9])
         self.assertEqual(req.spatialFilterType(), Qgis.SpatialFilterType.BoundingBox)
@@ -220,21 +249,37 @@ class TestQgsFeatureRequest(QgisTestCase):
         self.assertTrue(req.referenceGeometry().isNull())
 
     def testInvalidGeomCheck(self):
-        req = QgsFeatureRequest().setFilterFids([5, 6]).setInvalidGeometryCheck(QgsFeatureRequest.GeometrySkipInvalid)
-        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterFids)
+        req = (
+            QgsFeatureRequest()
+            .setFilterFids([5, 6])
+            .setInvalidGeometryCheck(
+                QgsFeatureRequest.InvalidGeometryCheck.GeometrySkipInvalid
+            )
+        )
+        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterType.FilterFids)
         self.assertEqual(req.filterFid(), -1)
         self.assertCountEqual(req.filterFids(), [5, 6])
-        self.assertEqual(req.invalidGeometryCheck(), QgsFeatureRequest.GeometrySkipInvalid)
-        req.setInvalidGeometryCheck(QgsFeatureRequest.GeometryNoCheck)
-        self.assertEqual(req.invalidGeometryCheck(), QgsFeatureRequest.GeometryNoCheck)
+        self.assertEqual(
+            req.invalidGeometryCheck(),
+            QgsFeatureRequest.InvalidGeometryCheck.GeometrySkipInvalid,
+        )
+        req.setInvalidGeometryCheck(
+            QgsFeatureRequest.InvalidGeometryCheck.GeometryNoCheck
+        )
+        self.assertEqual(
+            req.invalidGeometryCheck(),
+            QgsFeatureRequest.InvalidGeometryCheck.GeometryNoCheck,
+        )
 
     def testFilterExpression(self):
-        req = QgsFeatureRequest().setFilterExpression('a=5')
-        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterExpression)
+        req = QgsFeatureRequest().setFilterExpression("a=5")
+        self.assertEqual(
+            req.filterType(), QgsFeatureRequest.FilterType.FilterExpression
+        )
         self.assertEqual(req.spatialFilterType(), Qgis.SpatialFilterType.NoFilter)
         self.assertEqual(req.filterFid(), -1)
         self.assertFalse(req.filterFids())
-        self.assertEqual(req.filterExpression().expression(), 'a=5')
+        self.assertEqual(req.filterExpression().expression(), "a=5")
         self.assertTrue(req.filterRect().isNull())
         self.assertTrue(req.referenceGeometry().isNull())
 
@@ -242,33 +287,37 @@ class TestQgsFeatureRequest(QgisTestCase):
         req.setFilterRect(QgsRectangle(1, 2, 3, 4))
         self.assertEqual(req.filterFid(), -1)
         self.assertFalse(req.filterFids())
-        self.assertEqual(req.filterExpression().expression(), 'a=5')
+        self.assertEqual(req.filterExpression().expression(), "a=5")
         self.assertEqual(req.spatialFilterType(), Qgis.SpatialFilterType.BoundingBox)
         self.assertEqual(req.filterRect(), QgsRectangle(1, 2, 3, 4))
         self.assertTrue(req.referenceGeometry().isNull())
 
-        req.setFilterExpression('a=8')
+        req.setFilterExpression("a=8")
         self.assertEqual(req.filterFid(), -1)
         self.assertFalse(req.filterFids())
-        self.assertEqual(req.filterExpression().expression(), 'a=8')
+        self.assertEqual(req.filterExpression().expression(), "a=8")
         self.assertEqual(req.spatialFilterType(), Qgis.SpatialFilterType.BoundingBox)
         self.assertEqual(req.filterRect(), QgsRectangle(1, 2, 3, 4))
         self.assertTrue(req.referenceGeometry().isNull())
 
     def testCombineFilter(self):
         req = QgsFeatureRequest()
-        req.combineFilterExpression('b=9')
-        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterExpression)
+        req.combineFilterExpression("b=9")
+        self.assertEqual(
+            req.filterType(), QgsFeatureRequest.FilterType.FilterExpression
+        )
         self.assertEqual(req.filterFid(), -1)
         self.assertFalse(req.filterFids())
-        self.assertEqual(req.filterExpression().expression(), 'b=9')
+        self.assertEqual(req.filterExpression().expression(), "b=9")
         self.assertEqual(req.spatialFilterType(), Qgis.SpatialFilterType.NoFilter)
         self.assertTrue(req.filterRect().isNull())
         self.assertTrue(req.referenceGeometry().isNull())
 
-        req.combineFilterExpression('a=11')
-        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterExpression)
-        self.assertEqual(req.filterExpression().expression(), '(b=9) AND (a=11)')
+        req.combineFilterExpression("a=11")
+        self.assertEqual(
+            req.filterType(), QgsFeatureRequest.FilterType.FilterExpression
+        )
+        self.assertEqual(req.filterExpression().expression(), "(b=9) AND (a=11)")
         self.assertEqual(req.spatialFilterType(), Qgis.SpatialFilterType.NoFilter)
         self.assertTrue(req.filterRect().isNull())
         self.assertTrue(req.referenceGeometry().isNull())
@@ -279,31 +328,35 @@ class TestQgsFeatureRequest(QgisTestCase):
 
         context = QgsExpressionContext()
         scope = QgsExpressionContextScope()
-        scope.setVariable('a', 6)
+        scope.setVariable("a", 6)
         context.appendScope(scope)
         req.setExpressionContext(context)
 
         self.assertEqual(req.expressionContext().scopeCount(), 1)
-        self.assertEqual(req.expressionContext().variable('a'), 6)
+        self.assertEqual(req.expressionContext().variable("a"), 6)
 
     def testDisableFilter(self):
         req = QgsFeatureRequest().setFilterFid(5).disableFilter()
-        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterNone)
+        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterType.FilterNone)
         self.assertEqual(req.spatialFilterType(), Qgis.SpatialFilterType.NoFilter)
 
         req = QgsFeatureRequest().setFilterFids([5, 6]).disableFilter()
-        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterNone)
+        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterType.FilterNone)
         self.assertEqual(req.spatialFilterType(), Qgis.SpatialFilterType.NoFilter)
 
-        req = QgsFeatureRequest().setFilterExpression('a=5').disableFilter()
-        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterNone)
+        req = QgsFeatureRequest().setFilterExpression("a=5").disableFilter()
+        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterType.FilterNone)
         self.assertEqual(req.spatialFilterType(), Qgis.SpatialFilterType.NoFilter)
         self.assertFalse(req.filterExpression())
 
         # disable filter does not disable spatial filter
-        req = QgsFeatureRequest().setFilterExpression('a=5').setFilterRect(QgsRectangle(1, 2, 3, 4))
+        req = (
+            QgsFeatureRequest()
+            .setFilterExpression("a=5")
+            .setFilterRect(QgsRectangle(1, 2, 3, 4))
+        )
         req.disableFilter()
-        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterNone)
+        self.assertEqual(req.filterType(), QgsFeatureRequest.FilterType.FilterNone)
         self.assertEqual(req.spatialFilterType(), Qgis.SpatialFilterType.BoundingBox)
         self.assertEqual(req.filterRect(), QgsRectangle(1, 2, 3, 4))
         self.assertFalse(req.filterExpression())
@@ -317,50 +370,56 @@ class TestQgsFeatureRequest(QgisTestCase):
     def testFlags(self):
         req = QgsFeatureRequest()
         self.assertFalse(req.flags())
-        req.setFlags(QgsFeatureRequest.ExactIntersect)
-        self.assertEqual(req.flags(), QgsFeatureRequest.ExactIntersect)
+        req.setFlags(QgsFeatureRequest.Flag.ExactIntersect)
+        self.assertEqual(req.flags(), QgsFeatureRequest.Flag.ExactIntersect)
 
     def testSubsetAttributes(self):
         req = QgsFeatureRequest()
         self.assertFalse(req.subsetOfAttributes())
-        self.assertFalse(req.flags() & QgsFeatureRequest.SubsetOfAttributes)
+        self.assertFalse(req.flags() & QgsFeatureRequest.Flag.SubsetOfAttributes)
 
         req.setSubsetOfAttributes([1, 4])
         self.assertEqual(req.subsetOfAttributes(), [1, 4])
-        self.assertTrue(req.flags() & QgsFeatureRequest.SubsetOfAttributes)
+        self.assertTrue(req.flags() & QgsFeatureRequest.Flag.SubsetOfAttributes)
 
         req.setNoAttributes()
         self.assertEqual(req.subsetOfAttributes(), [])
-        self.assertTrue(req.flags() & QgsFeatureRequest.SubsetOfAttributes)
+        self.assertTrue(req.flags() & QgsFeatureRequest.Flag.SubsetOfAttributes)
 
         req.setSubsetOfAttributes([])
         self.assertFalse(req.subsetOfAttributes())
-        self.assertTrue(req.flags() & QgsFeatureRequest.SubsetOfAttributes)
+        self.assertTrue(req.flags() & QgsFeatureRequest.Flag.SubsetOfAttributes)
 
         req.setFlags(QgsFeatureRequest.Flags())
         f = QgsFields()
-        f.append(QgsField('a', QVariant.String))
-        f.append(QgsField('b', QVariant.String))
-        f.append(QgsField('c', QVariant.String))
-        req.setSubsetOfAttributes(['a', 'c'], f)
+        f.append(QgsField("a", QVariant.String))
+        f.append(QgsField("b", QVariant.String))
+        f.append(QgsField("c", QVariant.String))
+        req.setSubsetOfAttributes(["a", "c"], f)
         self.assertEqual(req.subsetOfAttributes(), [0, 2])
-        self.assertTrue(req.flags() & QgsFeatureRequest.SubsetOfAttributes)
+        self.assertTrue(req.flags() & QgsFeatureRequest.Flag.SubsetOfAttributes)
 
     def testSimplifyMethod(self):
         req = QgsFeatureRequest()
-        self.assertEqual(req.simplifyMethod().methodType(), QgsSimplifyMethod.NoSimplification)
+        self.assertEqual(
+            req.simplifyMethod().methodType(),
+            QgsSimplifyMethod.MethodType.NoSimplification,
+        )
         method = QgsSimplifyMethod()
-        method.setMethodType(QgsSimplifyMethod.PreserveTopology)
+        method.setMethodType(QgsSimplifyMethod.MethodType.PreserveTopology)
         req.setSimplifyMethod(method)
-        self.assertEqual(req.simplifyMethod().methodType(), QgsSimplifyMethod.PreserveTopology)
+        self.assertEqual(
+            req.simplifyMethod().methodType(),
+            QgsSimplifyMethod.MethodType.PreserveTopology,
+        )
 
     def testDestinationCrs(self):
         req = QgsFeatureRequest()
         self.assertFalse(req.destinationCrs().isValid())
         context = QgsCoordinateTransformContext()
-        req.setDestinationCrs(QgsCoordinateReferenceSystem('EPSG:3857'), context)
+        req.setDestinationCrs(QgsCoordinateReferenceSystem("EPSG:3857"), context)
         self.assertTrue(req.destinationCrs().isValid())
-        self.assertEqual(req.destinationCrs().authid(), 'EPSG:3857')
+        self.assertEqual(req.destinationCrs().authid(), "EPSG:3857")
 
     def testTimeout(self):
         req = QgsFeatureRequest()
@@ -374,46 +433,112 @@ class TestQgsFeatureRequest(QgisTestCase):
         req.setRequestMayBeNested(True)
         self.assertTrue(req.requestMayBeNested())
 
+    def testCoordinateTransform(self):
+        req = QgsFeatureRequest()
+        self.assertFalse(req.coordinateTransform().isValid())
+        req.setCoordinateTransform(
+            QgsCoordinateTransform(
+                QgsCoordinateReferenceSystem("EPSG:3111"),
+                QgsCoordinateReferenceSystem("EPSG:3857"),
+                QgsCoordinateTransformContext(),
+            )
+        )
+        self.assertTrue(req.coordinateTransform().isValid())
+        self.assertEqual(req.coordinateTransform().sourceCrs().authid(), "EPSG:3111")
+        self.assertEqual(
+            req.coordinateTransform().destinationCrs().authid(), "EPSG:3857"
+        )
+
     def testAssignment(self):
-        req = QgsFeatureRequest().setFilterFids([8, 9]).setFilterRect(QgsRectangle(1, 2, 3, 4)).setInvalidGeometryCheck(QgsFeatureRequest.GeometrySkipInvalid).setLimit(6).setFlags(QgsFeatureRequest.ExactIntersect).setSubsetOfAttributes([1, 4]).setTimeout(6).setRequestMayBeNested(True)
+        req = (
+            QgsFeatureRequest()
+            .setFilterFids([8, 9])
+            .setFilterRect(QgsRectangle(1, 2, 3, 4))
+            .setInvalidGeometryCheck(
+                QgsFeatureRequest.InvalidGeometryCheck.GeometrySkipInvalid
+            )
+            .setLimit(6)
+            .setFlags(QgsFeatureRequest.Flag.ExactIntersect)
+            .setSubsetOfAttributes([1, 4])
+            .setTimeout(6)
+            .setRequestMayBeNested(True)
+        )
 
         context = QgsExpressionContext()
         scope = QgsExpressionContextScope()
-        scope.setVariable('a', 6)
+        scope.setVariable("a", 6)
         context.appendScope(scope)
         req.setExpressionContext(context)
         method = QgsSimplifyMethod()
-        method.setMethodType(QgsSimplifyMethod.PreserveTopology)
+        method.setMethodType(QgsSimplifyMethod.MethodType.PreserveTopology)
         req.setSimplifyMethod(method)
         context = QgsCoordinateTransformContext()
-        req.setDestinationCrs(QgsCoordinateReferenceSystem('EPSG:3857'), context)
+        req.setDestinationCrs(QgsCoordinateReferenceSystem("EPSG:3857"), context)
+        req.setCoordinateTransform(
+            QgsCoordinateTransform(
+                QgsCoordinateReferenceSystem("EPSG:3111"),
+                QgsCoordinateReferenceSystem("EPSG:3857"),
+                QgsCoordinateTransformContext(),
+            )
+        )
 
         req2 = QgsFeatureRequest(req)
         self.assertEqual(req2.limit(), 6)
         self.assertCountEqual(req2.filterFids(), [8, 9])
         self.assertEqual(req2.filterRect(), QgsRectangle(1, 2, 3, 4))
         self.assertEqual(req2.spatialFilterType(), Qgis.SpatialFilterType.BoundingBox)
-        self.assertEqual(req2.invalidGeometryCheck(), QgsFeatureRequest.GeometrySkipInvalid)
+        self.assertEqual(
+            req2.invalidGeometryCheck(),
+            QgsFeatureRequest.InvalidGeometryCheck.GeometrySkipInvalid,
+        )
         self.assertEqual(req2.expressionContext().scopeCount(), 1)
-        self.assertEqual(req2.expressionContext().variable('a'), 6)
-        self.assertEqual(req2.flags(), QgsFeatureRequest.ExactIntersect | QgsFeatureRequest.SubsetOfAttributes)
+        self.assertEqual(req2.expressionContext().variable("a"), 6)
+        self.assertEqual(
+            req2.flags(),
+            QgsFeatureRequest.Flag.ExactIntersect
+            | QgsFeatureRequest.Flag.SubsetOfAttributes,
+        )
         self.assertEqual(req2.subsetOfAttributes(), [1, 4])
-        self.assertEqual(req2.simplifyMethod().methodType(), QgsSimplifyMethod.PreserveTopology)
-        self.assertEqual(req2.destinationCrs().authid(), 'EPSG:3857')
+        self.assertEqual(
+            req2.simplifyMethod().methodType(),
+            QgsSimplifyMethod.MethodType.PreserveTopology,
+        )
+        self.assertEqual(req2.destinationCrs().authid(), "EPSG:3857")
         self.assertEqual(req2.timeout(), 6)
         self.assertTrue(req2.requestMayBeNested())
+        self.assertEqual(req2.coordinateTransform().sourceCrs().authid(), "EPSG:3111")
+        self.assertEqual(
+            req2.coordinateTransform().destinationCrs().authid(), "EPSG:3857"
+        )
 
         # copy distance within request
-        req = QgsFeatureRequest().setDistanceWithin(QgsGeometry.fromWkt('LineString( 0 0, 10 0, 11 2)'), 1.2)
+        req = QgsFeatureRequest().setDistanceWithin(
+            QgsGeometry.fromWkt("LineString( 0 0, 10 0, 11 2)"), 1.2
+        )
         req2 = QgsFeatureRequest(req)
-        self.assertEqual(req2.spatialFilterType(), Qgis.SpatialFilterType.DistanceWithin)
-        self.assertEqual(req2.referenceGeometry().asWkt(), 'LineString (0 0, 10 0, 11 2)')
+        self.assertEqual(
+            req2.spatialFilterType(), Qgis.SpatialFilterType.DistanceWithin
+        )
+        self.assertEqual(
+            req2.referenceGeometry().asWkt(), "LineString (0 0, 10 0, 11 2)"
+        )
         self.assertEqual(req2.distanceWithin(), 1.2)
         self.assertEqual(req2.filterRect(), QgsRectangle(-1.2, -1.2, 12.2, 3.2))
 
     def test_compare(self):
-
-        req1 = QgsFeatureRequest().setFilterFids([8, 9]).setFilterRect(QgsRectangle(1, 2, 3, 4)).setInvalidGeometryCheck(QgsFeatureRequest.InvalidGeometryCheck.GeometrySkipInvalid).setLimit(6).setFlags(QgsFeatureRequest.Flag.ExactIntersect).setSubsetOfAttributes([1, 4]).setTimeout(6).setRequestMayBeNested(True)
+        req1 = (
+            QgsFeatureRequest()
+            .setFilterFids([8, 9])
+            .setFilterRect(QgsRectangle(1, 2, 3, 4))
+            .setInvalidGeometryCheck(
+                QgsFeatureRequest.InvalidGeometryCheck.GeometrySkipInvalid
+            )
+            .setLimit(6)
+            .setFlags(QgsFeatureRequest.Flag.ExactIntersect)
+            .setSubsetOfAttributes([1, 4])
+            .setTimeout(6)
+            .setRequestMayBeNested(True)
+        )
         req2 = QgsFeatureRequest(req1)
         self.assertTrue(req1.compare(req1))
         self.assertTrue(req1.compare(req2))
@@ -429,7 +554,9 @@ class TestQgsFeatureRequest(QgisTestCase):
         self.assertFalse(req3.compare(req1))
 
         req3 = QgsFeatureRequest(req2)
-        req3.setInvalidGeometryCheck(QgsFeatureRequest.InvalidGeometryCheck.GeometryNoCheck)
+        req3.setInvalidGeometryCheck(
+            QgsFeatureRequest.InvalidGeometryCheck.GeometryNoCheck
+        )
         self.assertFalse(req3.compare(req1))
 
         req3 = QgsFeatureRequest(req2)
@@ -453,12 +580,12 @@ class TestQgsFeatureRequest(QgisTestCase):
         self.assertFalse(req3.compare(req1))
 
         req3 = QgsFeatureRequest(req2)
-        orderClause = QgsFeatureRequest.OrderByClause('a', False)
+        orderClause = QgsFeatureRequest.OrderByClause("a", False)
         order = QgsFeatureRequest.OrderBy([orderClause])
         req3.setOrderBy(order)
         self.assertFalse(req3.compare(req1))
         req4 = QgsFeatureRequest(req2)
-        orderClause = QgsFeatureRequest.OrderByClause('a', False)
+        orderClause = QgsFeatureRequest.OrderByClause("a", False)
         order2 = QgsFeatureRequest.OrderBy([orderClause])
         req4.setOrderBy(order2)
         self.assertTrue(req4.compare(req3))
@@ -468,19 +595,32 @@ class TestQgsFeatureRequest(QgisTestCase):
         req3 = QgsFeatureRequest(req2)
         context = QgsExpressionContext()
         scope = QgsExpressionContextScope()
-        scope.setVariable('a', 6)
+        scope.setVariable("a", 6)
         context.appendScope(scope)
         req3.setExpressionContext(context)
         self.assertTrue(req3.compare(req1))
 
+        # coordinate transform
+        req3 = QgsFeatureRequest(req2)
+        req2.setCoordinateTransform(
+            QgsCoordinateTransform(
+                QgsCoordinateReferenceSystem("EPSG:3111"),
+                QgsCoordinateReferenceSystem("EPSG:3857"),
+                QgsCoordinateTransformContext(),
+            )
+        )
+        self.assertFalse(req3.compare(req2))
+        req3.setCoordinateTransform(req2.coordinateTransform())
+        self.assertTrue(req3.compare(req2))
+
     def test_order_by_equality(self):
 
-        orderClause1 = QgsFeatureRequest.OrderByClause('a', False)
-        orderClause2 = QgsFeatureRequest.OrderByClause('a', False)
+        orderClause1 = QgsFeatureRequest.OrderByClause("a", False)
+        orderClause2 = QgsFeatureRequest.OrderByClause("a", False)
         self.assertTrue(orderClause1 == orderClause2)
-        orderClause2 = QgsFeatureRequest.OrderByClause('b', False)
+        orderClause2 = QgsFeatureRequest.OrderByClause("b", False)
         self.assertFalse(orderClause1 == orderClause2)
-        orderClause2 = QgsFeatureRequest.OrderByClause('a', True)
+        orderClause2 = QgsFeatureRequest.OrderByClause("a", True)
         self.assertFalse(orderClause1 == orderClause2)
 
         order1 = QgsFeatureRequest.OrderBy([orderClause1])
@@ -491,6 +631,38 @@ class TestQgsFeatureRequest(QgisTestCase):
         order2 = QgsFeatureRequest.OrderBy([orderClause1, orderClause2])
         self.assertFalse(order1 == order2)
 
+    def test_calculate_transform(self):
+        """
+        Test transform calculation
+        """
+        req = QgsFeatureRequest()
+        # no transformation
+        transform = req.calculateTransform(QgsCoordinateReferenceSystem("EPSG:4326"))
+        self.assertFalse(transform.isValid())
 
-if __name__ == '__main__':
+        # transform using destination crs
+        req.setDestinationCrs(
+            QgsCoordinateReferenceSystem("EPSG:3857"), QgsCoordinateTransformContext()
+        )
+        transform = req.calculateTransform(QgsCoordinateReferenceSystem("EPSG:4326"))
+        self.assertTrue(transform.isValid())
+        self.assertEqual(transform.sourceCrs().authid(), "EPSG:4326")
+        self.assertEqual(transform.destinationCrs().authid(), "EPSG:3857")
+
+        # transform using a specific coordinate transform, must take precedence
+        req.setCoordinateTransform(
+            QgsCoordinateTransform(
+                QgsCoordinateReferenceSystem("EPSG:3111"),
+                QgsCoordinateReferenceSystem("EPSG:3857"),
+                QgsCoordinateTransformContext(),
+            )
+        )
+        # source crs is ignored
+        transform = req.calculateTransform(QgsCoordinateReferenceSystem("EPSG:4326"))
+        self.assertTrue(transform.isValid())
+        self.assertEqual(transform.sourceCrs().authid(), "EPSG:3111")
+        self.assertEqual(transform.destinationCrs().authid(), "EPSG:3857")
+
+
+if __name__ == "__main__":
     unittest.main()
