@@ -5,11 +5,11 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 """
-__author__ = '(C) 2020 by Nyall Dawson'
-__date__ = '05/04/2020'
-__copyright__ = 'Copyright 2020, The QGIS Project'
 
-import qgis  # NOQA
+__author__ = "(C) 2020 by Nyall Dawson"
+__date__ = "05/04/2020"
+__copyright__ = "Copyright 2020, The QGIS Project"
+
 from qgis.PyQt.QtCore import QRectF, Qt
 from qgis.PyQt.QtXml import QDomDocument
 from qgis.core import (
@@ -25,7 +25,6 @@ from qgis.core import (
     QgsReadWriteContext,
     QgsRectangle,
     QgsUnitTypes,
-    QgsLayoutChecker
 )
 import unittest
 from qgis.testing import start_app, QgisTestCase
@@ -39,9 +38,13 @@ TEST_DATA_DIR = unitTestDataPath()
 
 class TestQgsLayoutMarker(QgisTestCase, LayoutItemTestCase):
 
+    @classmethod
+    def control_path_prefix(cls):
+        return "layout_marker"
+
     @classmethod
     def setUpClass(cls):
-        super(TestQgsLayoutMarker, cls).setUpClass()
+        super().setUpClass()
         cls.item_class = QgsLayoutItemMarker
 
     def __init__(self, methodName):
@@ -65,7 +68,7 @@ class TestQgsLayoutMarker(QgisTestCase, LayoutItemTestCase):
         layout = QgsLayout(QgsProject.instance())
         marker = QgsLayoutItemMarker(layout)
         self.assertEqual(marker.displayName(), "<Marker>")
-        marker.setId('id')
+        marker.setId("id")
         self.assertEqual(marker.displayName(), "id")
 
     def testType(self):
@@ -73,15 +76,16 @@ class TestQgsLayoutMarker(QgisTestCase, LayoutItemTestCase):
         layout = QgsLayout(QgsProject.instance())
         marker = QgsLayoutItemMarker(layout)
 
-        self.assertEqual(
-            marker.type(), QgsLayoutItemRegistry.LayoutMarker)
+        self.assertEqual(marker.type(), QgsLayoutItemRegistry.ItemType.LayoutMarker)
 
     def testRender(self):
         """Test marker rendering."""
         layout = QgsLayout(QgsProject.instance())
         layout.initializeDefaults()
         marker = QgsLayoutItemMarker(layout)
-        marker.attemptMove(QgsLayoutPoint(100, 50, QgsUnitTypes.LayoutMillimeters))
+        marker.attemptMove(
+            QgsLayoutPoint(100, 50, QgsUnitTypes.LayoutUnit.LayoutMillimeters)
+        )
         props = {}
         props["color"] = "0,255,255"
         props["outline_width"] = "4"
@@ -91,11 +95,8 @@ class TestQgsLayoutMarker(QgisTestCase, LayoutItemTestCase):
         style = QgsMarkerSymbol.createSimple(props)
         marker.setSymbol(style)
         layout.addLayoutItem(marker)
-        checker = QgsLayoutChecker(
-            'layout_marker_render', layout)
-        checker.setControlPathPrefix("layout_marker")
-        myTestResult, myMessage = checker.testLayout()
-        assert myTestResult, myMessage
+
+        self.assertTrue(self.render_layout_check("layout_marker_render", layout))
 
     def testReadWriteXml(self):
         pr = QgsProject()
@@ -115,7 +116,7 @@ class TestQgsLayoutMarker(QgisTestCase, LayoutItemTestCase):
         marker.setSymbol(style)
 
         marker.setLinkedMap(map)
-        marker.setNorthMode(QgsLayoutNorthArrowHandler.TrueNorth)
+        marker.setNorthMode(QgsLayoutNorthArrowHandler.NorthMode.TrueNorth)
         marker.setNorthOffset(15)
 
         # save original item to xml
@@ -124,15 +125,21 @@ class TestQgsLayoutMarker(QgisTestCase, LayoutItemTestCase):
         self.assertTrue(marker.writeXml(elem, doc, QgsReadWriteContext()))
 
         marker2 = QgsLayoutItemMarker(l)
-        self.assertTrue(marker2.readXml(elem.firstChildElement(), doc, QgsReadWriteContext()))
+        self.assertTrue(
+            marker2.readXml(elem.firstChildElement(), doc, QgsReadWriteContext())
+        )
         marker2.finalizeRestoreFromXml()
 
-        self.assertEqual(marker2.symbol().symbolLayer(0).color().name(), '#008000')
-        self.assertEqual(marker2.symbol().symbolLayer(0).strokeStyle(), Qt.NoPen)
+        self.assertEqual(marker2.symbol().symbolLayer(0).color().name(), "#008000")
+        self.assertEqual(
+            marker2.symbol().symbolLayer(0).strokeStyle(), Qt.PenStyle.NoPen
+        )
         self.assertEqual(marker2.symbol().symbolLayer(0).size(), 4.4)
 
         self.assertEqual(marker2.linkedMap(), map)
-        self.assertEqual(marker2.northMode(), QgsLayoutNorthArrowHandler.TrueNorth)
+        self.assertEqual(
+            marker2.northMode(), QgsLayoutNorthArrowHandler.NorthMode.TrueNorth
+        )
         self.assertEqual(marker2.northOffset(), 15.0)
 
     def testBounds(self):
@@ -140,7 +147,9 @@ class TestQgsLayoutMarker(QgisTestCase, LayoutItemTestCase):
         l = QgsLayout(pr)
 
         shape = QgsLayoutItemMarker(l)
-        shape.attemptMove(QgsLayoutPoint(10, 20, QgsUnitTypes.LayoutMillimeters))
+        shape.attemptMove(
+            QgsLayoutPoint(10, 20, QgsUnitTypes.LayoutUnit.LayoutMillimeters)
+        )
         props = {}
         props["shape"] = "square"
         props["size"] = "6"
@@ -178,7 +187,7 @@ class TestQgsLayoutMarker(QgisTestCase, LayoutItemTestCase):
         marker.setLinkedMap(map)
         self.assertEqual(marker.linkedMap(), map)
 
-        marker.setNorthMode(QgsLayoutNorthArrowHandler.GridNorth)
+        marker.setNorthMode(QgsLayoutNorthArrowHandler.NorthMode.GridNorth)
         map.setItemRotation(45)
         self.assertEqual(marker.northArrowRotation(), 45)
         map.setMapRotation(-34)
@@ -206,7 +215,7 @@ class TestQgsLayoutMarker(QgisTestCase, LayoutItemTestCase):
         marker.setLinkedMap(map)
         self.assertEqual(marker.linkedMap(), map)
 
-        marker.setNorthMode(QgsLayoutNorthArrowHandler.GridNorth)
+        marker.setNorthMode(QgsLayoutNorthArrowHandler.NorthMode.GridNorth)
         map.setMapRotation(45)
         self.assertEqual(marker.northArrowRotation(), 45)
 
@@ -222,7 +231,9 @@ class TestQgsLayoutMarker(QgisTestCase, LayoutItemTestCase):
         map = QgsLayoutItemMap(layout)
         map.attemptSetSceneRect(QRectF(0, 0, 10, 10))
         map.setCrs(QgsCoordinateReferenceSystem.fromEpsgId(3575))
-        map.setExtent(QgsRectangle(-2126029.962, -2200807.749, -119078.102, -757031.156))
+        map.setExtent(
+            QgsRectangle(-2126029.962, -2200807.749, -119078.102, -757031.156)
+        )
         layout.addLayoutItem(map)
 
         marker = QgsLayoutItemMarker(layout)
@@ -231,11 +242,13 @@ class TestQgsLayoutMarker(QgisTestCase, LayoutItemTestCase):
         marker.setLinkedMap(map)
         self.assertEqual(marker.linkedMap(), map)
 
-        marker.setNorthMode(QgsLayoutNorthArrowHandler.TrueNorth)
+        marker.setNorthMode(QgsLayoutNorthArrowHandler.NorthMode.TrueNorth)
         self.assertAlmostEqual(marker.northArrowRotation(), 37.20, 1)
 
         # shift map
-        map.setExtent(QgsRectangle(2120672.293, -3056394.691, 2481640.226, -2796718.780))
+        map.setExtent(
+            QgsRectangle(2120672.293, -3056394.691, 2481640.226, -2796718.780)
+        )
         self.assertAlmostEqual(marker.northArrowRotation(), -38.18, 1)
 
         # rotate map
@@ -254,7 +267,9 @@ class TestQgsLayoutMarker(QgisTestCase, LayoutItemTestCase):
         map.setExtent(QgsRectangle(0, -256, 256, 0))
 
         marker = QgsLayoutItemMarker(layout)
-        marker.attemptMove(QgsLayoutPoint(100, 50, QgsUnitTypes.LayoutMillimeters))
+        marker.attemptMove(
+            QgsLayoutPoint(100, 50, QgsUnitTypes.LayoutUnit.LayoutMillimeters)
+        )
         props = {}
         props["color"] = "0,255,255"
         props["outline_style"] = "no"
@@ -265,7 +280,7 @@ class TestQgsLayoutMarker(QgisTestCase, LayoutItemTestCase):
         marker.setLinkedMap(map)
         self.assertEqual(marker.linkedMap(), map)
 
-        marker.setNorthMode(QgsLayoutNorthArrowHandler.GridNorth)
+        marker.setNorthMode(QgsLayoutNorthArrowHandler.NorthMode.GridNorth)
         map.setMapRotation(35)
         self.assertEqual(marker.northArrowRotation(), 35)
 
@@ -275,12 +290,9 @@ class TestQgsLayoutMarker(QgisTestCase, LayoutItemTestCase):
         style = QgsMarkerSymbol.createSimple(props)
         marker.setSymbol(style)
         layout.addLayoutItem(marker)
-        checker = QgsLayoutChecker(
-            'layout_marker_render_north', layout)
-        checker.setControlPathPrefix("layout_marker")
-        myTestResult, myMessage = checker.testLayout()
-        assert myTestResult, myMessage
+
+        self.assertTrue(self.render_layout_check("layout_marker_render_north", layout))
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
